@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -21,16 +21,16 @@
 #include "BankRomCheat.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-BankRomCheat::BankRomCheat(OSystem& os, const string& name, const string& code)
+BankRomCheat::BankRomCheat(OSystem& os, string_view name, string_view code)
   : Cheat(os, name, code)
 {
   if(myCode.length() == 7)
-    myCode = "0" + code;
+    myCode = "0" + string{code};
 
-  bank = unhex(myCode.substr(0, 2));
-  address = 0xf000 + unhex(myCode.substr(2, 3));
-  value = static_cast<uInt8>(unhex(myCode.substr(5, 2)));
-  count = static_cast<uInt8>(unhex(myCode.substr(7, 1)) + 1);
+  bank = BSPF::stoi<16>(myCode.substr(0, 2));
+  address = 0xf000 + BSPF::stoi<16>(myCode.substr(2, 3));
+  value = static_cast<uInt8>(BSPF::stoi<16>(myCode.substr(5, 2)));
+  count = static_cast<uInt8>(BSPF::stoi<16>(myCode.substr(7, 1)) + 1);
 
   // Back up original data; we need this if the cheat is ever disabled
   for(int i = 0; i < count; ++i)
@@ -51,7 +51,7 @@ bool BankRomCheat::disable()
   myOSystem.console().cartridge().bank(bank);
 
   for(int i = 0; i < count; ++i)
-		myOSystem.console().cartridge().patch(address + i, savedRom[i]);
+    myOSystem.console().cartridge().patch(address + i, savedRom[i]);
 
   myOSystem.console().cartridge().bank(oldBank);
 
