@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -25,7 +25,6 @@
 #include "Font.hxx"
 #include "InputTextDialog.hxx"
 #include "OSystem.hxx"
-#include "Props.hxx"
 #include "Widget.hxx"
 
 #include "CheatCodeDialog.hxx"
@@ -83,18 +82,18 @@ CheatCodeDialog::CheatCodeDialog(OSystem& osystem, DialogContainer& parent,
 
   // Inputbox which will pop up when adding/editing a cheat
   StringList labels;
-  labels.push_back("Name       ");
-  labels.push_back("Code (hex) ");
+  labels.emplace_back("Name       ");
+  labels.emplace_back("Code (hex) ");
   myCheatInput = make_unique<InputTextDialog>(this, font, labels, "Cheat code");
   myCheatInput->setTarget(this);
 
   // Add filtering for each textfield
-  EditableWidget::TextFilter f0 = [](char c) {
+  const EditableWidget::TextFilter f0 = [](char c) {
     return isprint(c) && c != '\"' && c != ':';
   };
   myCheatInput->setTextFilter(f0, 0);
 
-  EditableWidget::TextFilter f1 = [](char c) {
+  const EditableWidget::TextFilter f1 = [](char c) {
     return (c >= 'a' && c <= 'f') || (c >= '0' && c <= '9');
   };
   myCheatInput->setTextFilter(f1, 1);
@@ -111,7 +110,7 @@ CheatCodeDialog::CheatCodeDialog(OSystem& osystem, DialogContainer& parent,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-CheatCodeDialog::~CheatCodeDialog()
+CheatCodeDialog::~CheatCodeDialog()  // NOLINT (we need an empty d'tor)
 {
 }
 
@@ -128,14 +127,14 @@ void CheatCodeDialog::loadConfig()
   for(const auto& c: list)
   {
     l.push_back(c->name());
-    b.push_back(bool(c->enabled()));
+    b.push_back(c->enabled());
   }
   myCheatList->setList(l, b);
 
   // Redraw the list, auto-selecting the first item if possible
-  myCheatList->setSelected(l.size() > 0 ? 0 : -1);
+  myCheatList->setSelected(!l.empty() ? 0 : -1);
 
-  const bool enabled = (list.size() > 0);
+  const bool enabled = !list.empty();
   myEditButton->setEnabled(enabled);
   myRemoveButton->setEnabled(enabled);
 }
@@ -233,7 +232,7 @@ void CheatCodeDialog::handleCommand(CommandSender* sender, int cmd,
     {
       const string& name = myCheatInput->getResult(0);
       const string& code = myCheatInput->getResult(1);
-      if(instance().cheat().isValidCode(code))
+      if(CheatManager::isValidCode(code))
       {
         myCheatInput->close();
         instance().cheat().add(name, code);
@@ -250,7 +249,7 @@ void CheatCodeDialog::handleCommand(CommandSender* sender, int cmd,
       const string& code = myCheatInput->getResult(1);
       const bool enable = myCheatList->getSelectedState();
       const int idx = myCheatList->getSelected();
-      if(instance().cheat().isValidCode(code))
+      if(CheatManager::isValidCode(code))
       {
         myCheatInput->close();
         instance().cheat().add(name, code, enable, idx);
@@ -273,7 +272,7 @@ void CheatCodeDialog::handleCommand(CommandSender* sender, int cmd,
     {
       const string& name = myCheatInput->getResult(0);
       const string& code = myCheatInput->getResult(1);
-      if(instance().cheat().isValidCode(code))
+      if(CheatManager::isValidCode(code))
       {
         myCheatInput->close();
         instance().cheat().addOneShot(name, code);
