@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -16,7 +16,6 @@
 //============================================================================
 
 #include "OSystem.hxx"
-#include "Console.hxx"
 #include "Cheat.hxx"
 #include "Settings.hxx"
 #include "CheetahCheat.hxx"
@@ -33,10 +32,10 @@ CheatManager::CheatManager(OSystem& osystem)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool CheatManager::add(const string& name, const string& code,
+bool CheatManager::add(string_view name, string_view code,
                        bool enable, int idx)
 {
-  shared_ptr<Cheat> cheat = createCheat(name, code);
+  const shared_ptr<Cheat> cheat = createCheat(name, code);
   if(!cheat)
     return false;
 
@@ -79,7 +78,7 @@ void CheatManager::remove(int idx)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void CheatManager::addPerFrame(const string& name, const string& code, bool enable)
+void CheatManager::addPerFrame(string_view name, string_view code, bool enable)
 {
   // The actual cheat will always be in the main list; we look there first
   shared_ptr<Cheat> cheat;
@@ -93,8 +92,8 @@ void CheatManager::addPerFrame(const string& name, const string& code, bool enab
   }
 
   // Make sure there are no duplicates
-  bool found = false;
-  uInt32 i;
+  bool found{false};
+  uInt32 i{0};
   for(i = 0; i < myPerFrameList.size(); ++i)
   {
     if(myPerFrameList[i]->code() == cheat->code())
@@ -117,16 +116,16 @@ void CheatManager::addPerFrame(const string& name, const string& code, bool enab
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void CheatManager::addOneShot(const string& name, const string& code)
+void CheatManager::addOneShot(string_view name, string_view code)
 {
   // Evaluate this cheat once, and then immediately discard it
-  shared_ptr<Cheat> cheat = createCheat(name, code);
+  const shared_ptr<Cheat> cheat = createCheat(name, code);
   if(cheat)
     cheat->evaluate();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-shared_ptr<Cheat> CheatManager::createCheat(const string& name, const string& code) const
+shared_ptr<Cheat> CheatManager::createCheat(string_view name, string_view code) const
 {
   if(!isValidCode(code))
     return nullptr;
@@ -136,14 +135,14 @@ shared_ptr<Cheat> CheatManager::createCheat(const string& name, const string& co
   {
     case 4:  return make_shared<RamCheat>(myOSystem, name, code);
     case 6:  return make_shared<CheetahCheat>(myOSystem, name, code);
-    case 7:  return make_shared<BankRomCheat>(myOSystem, name, code);
+    case 7:  [[fallthrough]];
     case 8:  return make_shared<BankRomCheat>(myOSystem, name, code);
     default: return nullptr;
   }
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void CheatManager::parse(const string& cheats)
+void CheatManager::parse(string_view cheats)
 {
   StringList s;
   string::size_type lastPos = cheats.find_first_not_of(',', 0);
@@ -198,7 +197,7 @@ void CheatManager::parse(const string& cheats)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void CheatManager::enable(const string& code, bool enable)
+void CheatManager::enable(string_view code, bool enable)
 {
   for(const auto& cheat: myCheatList)
   {
@@ -225,7 +224,7 @@ void CheatManager::loadCheatDatabase()
   // Loop reading cheats
   while(getline(in, line))
   {
-    if(line.length() == 0)
+    if(line.empty())
       continue;
 
     const string::size_type one = line.find('\"', 0);
@@ -256,14 +255,14 @@ void CheatManager::saveCheatDatabase()
 
   stringstream out;
   for(const auto& [md5, cheat]: myCheatMap)
-    out << "\"" << md5 << "\" " << "\"" << cheat << "\"" << endl;
+    out << "\"" << md5 << "\" " << "\"" << cheat << "\"\n";
 
   try         { myOSystem.cheatFile().write(out); }
   catch(...)  { return; }
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void CheatManager::loadCheats(const string& md5sum)
+void CheatManager::loadCheats(string_view md5sum)
 {
   myPerFrameList.clear();
   myCheatList.clear();
@@ -272,11 +271,11 @@ void CheatManager::loadCheats(const string& md5sum)
   // Set up any cheatcodes that was on the command line
   // (and remove the key from the settings, so they won't get set again)
   const string& cheats = myOSystem.settings().getString("cheat");
-  if(cheats != "")
+  if(!cheats.empty())
     myOSystem.settings().setValue("cheat", "");
 
   const auto& iter = myCheatMap.find(md5sum);
-  if(iter == myCheatMap.end() && cheats == "")
+  if(iter == myCheatMap.end() && cheats.empty())
     return;
 
   // Remember the cheats for this ROM
@@ -287,7 +286,7 @@ void CheatManager::loadCheats(const string& md5sum)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void CheatManager::saveCheats(const string& md5sum)
+void CheatManager::saveCheats(string_view md5sum)
 {
   ostringstream cheats;
   for(uInt32 i = 0; i < myCheatList.size(); ++i)
@@ -299,7 +298,7 @@ void CheatManager::saveCheats(const string& md5sum)
       cheats << ",";
   }
 
-  bool changed = cheats.str() != myCurrentCheat;
+  const bool changed = cheats.view() != myCurrentCheat;
 
   // Only update the list if absolutely necessary
   if(changed)
@@ -311,8 +310,8 @@ void CheatManager::saveCheats(const string& md5sum)
       myCheatMap.erase(iter);
 
     // Add new entry only if there are any cheats defined
-    if(cheats.str() != "")
-      myCheatMap.emplace(md5sum, cheats.str());
+    if(!cheats.view().empty())
+      myCheatMap.emplace(md5sum, cheats.view());
   }
 
   // Update the dirty flag
@@ -322,7 +321,7 @@ void CheatManager::saveCheats(const string& md5sum)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool CheatManager::isValidCode(const string& code) const
+bool CheatManager::isValidCode(string_view code)
 {
   for(const auto c: code)
     if(!isxdigit(c))
