@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -21,11 +21,11 @@
 #include "CheetahCheat.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-CheetahCheat::CheetahCheat(OSystem& os, const string& name, const string& code)
+CheetahCheat::CheetahCheat(OSystem& os, string_view name, string_view code)
   : Cheat(os, name, code),
-    address{static_cast<uInt16>(0xf000 + unhex(code.substr(0, 3)))},
-    value{static_cast<uInt8>(unhex(code.substr(3, 2)))},
-    count{static_cast<uInt8>(unhex(code.substr(5, 1)) + 1)}
+    address{static_cast<uInt16>(0xf000 + BSPF::stoi<16>(code.substr(0, 3)))},
+    value{static_cast<uInt8>(BSPF::stoi<16>(code.substr(3, 2)))},
+    count{static_cast<uInt8>(BSPF::stoi<16>(code.substr(5, 1)) + 1)}
 {
   // Back up original data; we need this if the cheat is ever disabled
   for(int i = 0; i < count; ++i)
