@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -23,10 +23,10 @@
 #include "RamCheat.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-RamCheat::RamCheat(OSystem& os, const string& name, const string& code)
+RamCheat::RamCheat(OSystem& os, string_view name, string_view code)
   : Cheat(os, name, code),
-    address{static_cast<uInt16>(unhex(myCode.substr(0, 2)))},
-    value{static_cast<uInt8>(unhex(myCode.substr(2, 2)))}
+    address{static_cast<uInt16>(BSPF::stoi<16>(myCode.substr(0, 2)))},
+    value{static_cast<uInt8>(BSPF::stoi<16>(myCode.substr(2, 2)))}
 {
 }
 
@@ -55,5 +55,5 @@ bool RamCheat::disable()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void RamCheat::evaluate()
 {
-  myOSystem.console().system().poke(address, value);
+  myOSystem.console().system().pokeOob(address, value);
 }
