@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -38,7 +38,7 @@ namespace {
         throw runtime_error("unreachable");
     }
   }
-}
+} // namespace
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 FBSurfaceSDL2::FBSurfaceSDL2(FBBackendSDL2& backend,
@@ -48,6 +48,7 @@ FBSurfaceSDL2::FBSurfaceSDL2(FBBackendSDL2& backend,
   : myBackend{backend},
     myInterpolationMode{inter}
 {
+  //cerr << width << " x " << height << '\n';
   createSurface(width, height, staticData);
 }
 
@@ -233,6 +234,7 @@ void FBSurfaceSDL2::createSurface(uInt32 width, uInt32 height,
 
   mySurface = SDL_CreateRGBSurface(0, width, height,
       pf.BitsPerPixel, pf.Rmask, pf.Gmask, pf.Bmask, pf.Amask);
+  //SDL_SetSurfaceBlendMode(mySurface, SDL_BLENDMODE_ADD); // default: SDL_BLENDMODE_BLEND
 
   // We start out with the src and dst rectangles containing the same
   // dimensions, indicating no scaling or re-positioning
@@ -249,9 +251,10 @@ void FBSurfaceSDL2::createSurface(uInt32 width, uInt32 height,
 
   myIsStatic = data != nullptr;
   if(myIsStatic)
-    SDL_memcpy(mySurface->pixels, data, mySurface->w * mySurface->h * 4);
+    SDL_memcpy(mySurface->pixels, data,
+               static_cast<size_t>(mySurface->w) * mySurface->h * 4);
 
-  reload();
+  reload();  // NOLINT
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -278,8 +281,12 @@ void FBSurfaceSDL2::applyAttributes()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FBSurfaceSDL2::setScalingInterpolation(ScalingInterpolation interpolation)
 {
-  if (interpolation == ScalingInterpolation::sharp
-      && mySrcGUIR.h() >= myDstGUIR.h())
+  if (interpolation == ScalingInterpolation::sharp &&
+      (
+        static_cast<int>(mySrcGUIR.h()) >= myBackend.scaleY(myDstGUIR.h()) ||
+        static_cast<int>(mySrcGUIR.w()) >= myBackend.scaleX(myDstGUIR.w())
+      )
+  )
     interpolation = ScalingInterpolation::blur;
 
   if (interpolation == myInterpolationMode) return;
