@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -65,9 +65,10 @@ HighScoresManager::HighScoresManager(OSystem& osystem)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void HighScoresManager::setRepository(shared_ptr<CompositeKeyValueRepositoryAtomic> repo)
+void HighScoresManager::setRepository(
+    shared_ptr<CompositeKeyValueRepositoryAtomic> repo)
 {
-  myHighscoreRepository = repo;
+  myHighscoreRepository = std::move(repo);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -76,7 +77,7 @@ Int16 HighScoresManager::peek(uInt16 addr) const
   if (myOSystem.hasConsole())
   {
     if(addr < 0x100U || myOSystem.console().cartridge().internalRamSize() == 0)
-      return myOSystem.console().system().peek(addr);
+      return myOSystem.console().system().peekOob(addr);
     else
       return myOSystem.console().cartridge().internalRamGetValue(addr);
   }
@@ -84,7 +85,7 @@ Int16 HighScoresManager::peek(uInt16 addr) const
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const json HighScoresManager::properties(const Properties& props) const
+json HighScoresManager::properties(const Properties& props)
 {
   const string& property = props.get(PropType::Cart_Highscore);
 
@@ -94,7 +95,6 @@ const json HighScoresManager::properties(const Properties& props) const
   return json::parse(property);
 }
 
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 json HighScoresManager::properties(json& jprops) const
 {
@@ -113,7 +113,6 @@ json HighScoresManager::properties(json& jprops) const
   return jprops = properties(props);
 }
 
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool HighScoresManager::enabled() const
 {
@@ -123,17 +122,16 @@ bool HighScoresManager::enabled() const
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-uInt32 HighScoresManager::numVariations(const json& jprops) const
+uInt32 HighScoresManager::numVariations(const json& jprops)
 {
   return min(getPropInt(jprops, VARIATIONS_COUNT, DEFAULT_VARIATION), MAX_VARIATIONS);
 }
 
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool HighScoresManager::get(const Properties& props, uInt32& numVariationsR,
                             ScoresProps& info) const
 {
-  json jprops = properties(props);
+  const json jprops = properties(props);
 
   numVariationsR = numVariations(jprops);
 
@@ -158,7 +156,7 @@ bool HighScoresManager::get(const Properties& props, uInt32& numVariationsR,
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void HighScoresManager::set(Properties& props, uInt32 numVariations,
-                            const ScoresProps& info) const
+                            const ScoresProps& info)
 {
   json jprops = json::object();
 
@@ -206,85 +204,79 @@ void HighScoresManager::set(Properties& props, uInt32 numVariations,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-uInt32 HighScoresManager::numDigits(const json& jprops) const
+uInt32 HighScoresManager::numDigits(const json& jprops)
 {
   return min(getPropInt(jprops, SCORE_DIGITS, DEFAULT_DIGITS), MAX_SCORE_DIGITS);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-uInt32 HighScoresManager::trailingZeroes(const json& jprops) const
+uInt32 HighScoresManager::trailingZeroes(const json& jprops)
 {
   return min(getPropInt(jprops, SCORE_TRAILING_ZEROES, DEFAULT_TRAILING), MAX_TRAILING);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool HighScoresManager::scoreBCD(const json& jprops) const
+bool HighScoresManager::scoreBCD(const json& jprops)
 {
   return getPropBool(jprops, SCORE_BCD, DEFAULT_SCORE_BCD);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool HighScoresManager::scoreInvert(const json& jprops) const
+bool HighScoresManager::scoreInvert(const json& jprops)
 {
   return getPropBool(jprops, SCORE_INVERTED, DEFAULT_SCORE_REVERSED);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool HighScoresManager::varBCD(const json& jprops) const
+bool HighScoresManager::varBCD(const json& jprops)
 {
   return getPropBool(jprops, VARIATIONS_BCD, DEFAULT_VARS_BCD);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool HighScoresManager::varZeroBased(const json& jprops) const
+bool HighScoresManager::varZeroBased(const json& jprops)
 {
   return getPropBool(jprops, VARIATIONS_ZERO_BASED, DEFAULT_VARS_ZERO_BASED);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const string HighScoresManager::specialLabel(const json& jprops) const
+string HighScoresManager::specialLabel(const json& jprops)
 {
   return getPropStr(jprops, SPECIAL_LABEL);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool HighScoresManager::specialBCD(const json& jprops) const
+bool HighScoresManager::specialBCD(const json& jprops)
 {
   return getPropBool(jprops, SPECIAL_BCD, DEFAULT_SPECIAL_BCD);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool HighScoresManager::specialZeroBased(const json& jprops) const
+bool HighScoresManager::specialZeroBased(const json& jprops)
 {
   return getPropBool(jprops, SPECIAL_ZERO_BASED, DEFAULT_SPECIAL_ZERO_BASED);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const string HighScoresManager::notes(const json& jprops) const
+string HighScoresManager::notes(const json& jprops)
 {
   return getPropStr(jprops, NOTES);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-uInt16 HighScoresManager::varAddress(const json& jprops) const
+uInt16 HighScoresManager::varAddress(const json& jprops)
 {
   return getPropAddr(jprops, VARIATIONS_ADDRESS, DEFAULT_ADDRESS);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-uInt16 HighScoresManager::specialAddress(const json& jprops) const
+uInt16 HighScoresManager::specialAddress(const json& jprops)
 {
   return getPropAddr(jprops, SPECIAL_ADDRESS, DEFAULT_ADDRESS);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-uInt32 HighScoresManager::numAddrBytes(Int32 digits, Int32 trailing) const
-{
-  return (digits - trailing + 1) / 2;
-}
-
-// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-uInt32 HighScoresManager::numAddrBytes(const json& jprops) const
+uInt32 HighScoresManager::numAddrBytes(const json& jprops)
 {
   return numAddrBytes(numDigits(jprops), trailingZeroes(jprops));
 }
@@ -298,7 +290,7 @@ Int32 HighScoresManager::numVariations() const
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const string HighScoresManager::specialLabel() const
+string HighScoresManager::specialLabel() const
 {
   json jprops;
 
@@ -321,7 +313,7 @@ Int32 HighScoresManager::variation(uInt16 addr, bool varBCD, bool zeroBased,
 Int32 HighScoresManager::variation() const
 {
   json jprops;
-  uInt16 addr = varAddress(properties(jprops));
+  const uInt16 addr = varAddress(properties(jprops));
 
   if(addr == DEFAULT_ADDRESS) {
     if(numVariations() == 1)
@@ -369,7 +361,7 @@ Int32 HighScoresManager::score(uInt32 numAddrBytes, uInt32 trailingZeroes,
 Int32 HighScoresManager::score() const
 {
   json jprops;
-  uInt32 numBytes = numAddrBytes(properties(jprops));
+  const uInt32 numBytes = numAddrBytes(properties(jprops));
   const ScoreAddresses scoreAddr = getPropScoreAddr(jprops);
 
   if(static_cast<uInt32>(scoreAddr.size()) < numBytes)
@@ -378,7 +370,7 @@ Int32 HighScoresManager::score() const
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const string HighScoresManager::formattedScore(Int32 score, Int32 width) const
+string HighScoresManager::formattedScore(Int32 score, Int32 width) const
 {
   if(score <= 0)
     return "";
@@ -402,6 +394,7 @@ const string HighScoresManager::formattedScore(Int32 score, Int32 width) const
   return buf.str();
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 string HighScoresManager::md5Props() const
 {
   json jprops;
@@ -421,9 +414,10 @@ string HighScoresManager::md5Props() const
 
   buf << specialAddress(jprops) << specialBCD(jprops) << specialZeroBased(jprops);
 
-  return MD5::hash(buf.str());
+  return MD5::hash(buf.view());
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool HighScoresManager::scoreInvert() const
 {
   json jprops;
@@ -438,7 +432,7 @@ Int32 HighScoresManager::special() const
     return NO_VALUE;
 
   json jprops;
-  uInt16 addr = specialAddress(properties(jprops));
+  const uInt16 addr = specialAddress(properties(jprops));
 
   if (addr == DEFAULT_ADDRESS)
     return NO_VALUE;
@@ -454,7 +448,7 @@ Int32 HighScoresManager::special() const
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const string HighScoresManager::notes() const
+string HighScoresManager::notes() const
 {
   json jprops;
 
@@ -462,13 +456,14 @@ const string HighScoresManager::notes() const
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-Int32 HighScoresManager::convert(Int32 val, uInt32 maxVal, bool isBCD, bool zeroBased) const
+Int32 HighScoresManager::convert(Int32 val, uInt32 maxVal, bool isBCD,
+                                 bool zeroBased)
 {
   //maxVal += zeroBased ? 0 : 1;
   maxVal -= zeroBased ? 1 : 0;
   const Int32 bits = isBCD
-    ? ceil(log(maxVal) / log(10) * 4)
-    : ceil(log(maxVal) / log(2));
+    ? ceil(log(maxVal) / BSPF::ln10 * 4)
+    : ceil(log(maxVal) / BSPF::ln2);
 
   // limit to maxVal's bits
   val %= 1 << bits;
@@ -485,30 +480,29 @@ Int32 HighScoresManager::convert(Int32 val, uInt32 maxVal, bool isBCD, bool zero
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool HighScoresManager::getPropBool(const json& jprops, const string& key,
-                                    bool defVal) const
+bool HighScoresManager::getPropBool(const json& jprops, string_view key,
+                                    bool defVal)
 {
   return jprops.contains(key) ? jprops.at(key).get<bool>() : defVal;
 }
 
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-uInt32 HighScoresManager::getPropInt(const json& jprops, const string& key,
-                                     uInt32 defVal) const
+uInt32 HighScoresManager::getPropInt(const json& jprops, string_view key,
+                                     uInt32 defVal)
 {
   return jprops.contains(key) ? jprops.at(key).get<uInt32>() : defVal;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const string HighScoresManager::getPropStr(const json& jprops, const string& key,
-                                           const string& defVal) const
+string HighScoresManager::getPropStr(const json& jprops, string_view key,
+                                     string_view defVal)
 {
-  return jprops.contains(key) ? jprops.at(key).get<string>() : defVal;
+  return jprops.contains(key) ? jprops.at(key).get<string>() : string{defVal};
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-uInt16 HighScoresManager::getPropAddr(const json& jprops, const string& key,
-                                      uInt16 defVal) const
+uInt16 HighScoresManager::getPropAddr(const json& jprops, string_view key,
+                                      uInt16 defVal)
 {
   const string str = getPropStr(jprops, key);
 
@@ -516,7 +510,7 @@ uInt16 HighScoresManager::getPropAddr(const json& jprops, const string& key,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const HSM::ScoreAddresses HighScoresManager::getPropScoreAddr(const json& jprops) const
+HSM::ScoreAddresses HighScoresManager::getPropScoreAddr(const json& jprops)
 {
   ScoreAddresses scoreAddr{};
 
@@ -543,18 +537,16 @@ const HSM::ScoreAddresses HighScoresManager::getPropScoreAddr(const json& jprops
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-uInt16 HighScoresManager::fromHexStr(const string& addr) const
+uInt16 HighScoresManager::fromHexStr(string_view addr)
 {
-  string naked = addr;
+  if(const auto pos = addr.find("0x") != std::string::npos)
+    addr = addr.substr(pos + 1);
 
-  if(const int pos = naked.find("0x") != std::string::npos)
-    naked = naked.substr(pos + 1);
-
-  return stringToIntBase16(naked);
+  return static_cast<uInt16>(BSPF::stoi<16>(addr));
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-Int32 HighScoresManager::fromBCD(uInt8 bcd) const
+Int32 HighScoresManager::fromBCD(uInt8 bcd)
 {
   // verify if score is legit
   if ((bcd & 0xF0) >= 0xA0 || (bcd & 0xF) >= 0xA)
@@ -578,7 +570,7 @@ string HighScoresManager::hash(const ScoresData& data) const
       << data.scores[r].date;
   }
 
-  return MD5::hash(buf.str());
+  return MD5::hash(buf.view());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -665,7 +657,7 @@ void HighScoresManager::loadHighScores(ScoresData& data)
     clearHighScores(data);
     buf << "Error: Invalid high scores data for variation " << data.variation << ".";
   }
-  myOSystem.frameBuffer().showTextMessage(buf.str());
+  myOSystem.frameBuffer().showTextMessage(buf.view());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -701,12 +693,12 @@ bool HighScoresManager::load(const json& hsData, ScoresData& data)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void HighScoresManager::clearHighScores(ScoresData& data)
 {
-  for(uInt32 r = 0; r < NUM_RANKS; ++r)
+  for(auto& s: data.scores)
   {
-    data.scores[r].score = 0;
-    data.scores[r].special = 0;
-    data.scores[r].name = "";
-    data.scores[r].date = "";
+    s.score = 0;
+    s.special = 0;
+    s.name = "";
+    s.date = "";
   }
 }
 
