@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -44,7 +44,7 @@ PhysicalKeyboardHandler::PhysicalKeyboardHandler(OSystem& system, EventHandler&
   : myOSystem{system},
     myHandler{handler}
 {
-  Int32 version = myOSystem.settings().getInt("event_ver");
+  const Int32 version = myOSystem.settings().getInt("event_ver");
   bool updateDefaults = false;
 
   // Compare if event list version has changed so that key maps became invalid
@@ -70,10 +70,28 @@ PhysicalKeyboardHandler::PhysicalKeyboardHandler(OSystem& system, EventHandler&
 #ifdef DEBUGGER_SUPPORT
   setDefaultMapping(Event::NoType, EventMode::kPromptMode, updateDefaults);
 #endif
+#ifdef DEBUG_BUILD
+  verifyDefaultMapping(DefaultCommonMapping, EventMode::kEmulationMode, "EmulationMode");
+  verifyDefaultMapping(DefaultMenuMapping, EventMode::kMenuMode, "MenuMode");
+#endif
 }
 
+#ifdef DEBUG_BUILD
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void PhysicalKeyboardHandler::loadSerializedMappings(const string& serializedMapping, EventMode mode)
+void PhysicalKeyboardHandler::verifyDefaultMapping(
+  PhysicalKeyboardHandler::EventMappingArray mapping, EventMode mode, string_view name)
+{
+  for(const auto& item1 : mapping)
+    for(const auto& item2 : mapping)
+      if(item1.event != item2.event && item1.key == item2.key && item1.mod == item2.mod)
+        cerr << "ERROR! Duplicate hotkey mapping found: " << name << ", "
+          << myKeyMap.getDesc(KeyMap::Mapping(mode, item1.key, item1.mod)) << "\n";
+}
+#endif
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void PhysicalKeyboardHandler::loadSerializedMappings(
+    string_view serializedMapping, EventMode mode)
 {
   json mapping;
 
@@ -145,7 +163,7 @@ void PhysicalKeyboardHandler::setDefaultKey(EventMapping map, Event::Type event,
   {
     // if there is no existing mapping for the event and
     //  the default mapping for the event is unused, set default key for event
-    if (myKeyMap.getEventMapping(map.event, mode).size() == 0 &&
+    if (myKeyMap.getEventMapping(map.event, mode).empty() &&
         !isMappingUsed(mode, map))
     {
       addMapping(map.event, mode, map.key, static_cast<StellaMod>(map.mod));
@@ -217,68 +235,65 @@ void PhysicalKeyboardHandler::setDefaultMapping(Event::Type event, EventMode mod
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void PhysicalKeyboardHandler::defineControllerMappings(
-    const Controller::Type type, Controller::Jack port, const Properties& properties)
+    Controller::Type type, Controller::Jack port, const Properties& properties,
+    Controller::Type qtType1, Controller::Type qtType2)
 {
-
-  //const string& test = myOSystem.settings().getString("aq");
-  // determine controller events to use
-  switch(type)
+  // Determine controller events to use
+  if(type == Controller::Type::QuadTari)
   {
-    case Controller::Type::QuadTari:
-      if(port == Controller::Jack::Left)
-      {
-        myLeftMode = getMode(properties, PropType::Controller_Left1);
-        myLeft2ndMode = getMode(properties, PropType::Controller_Left2);
-      }
-      else
-      {
-        myRightMode = getMode(properties, PropType::Controller_Right1);
-        myRight2ndMode = getMode(properties, PropType::Controller_Right2);
-      }
-      break;
-
-    default:
+    if(port == Controller::Jack::Left)
     {
-      const EventMode mode = getMode(type);
-
-      if(port == Controller::Jack::Left)
-        myLeftMode = mode;
-      else
-        myRightMode = mode;
-      break;
+      myLeftMode = getMode(qtType1);
+      myLeft2ndMode = getMode(qtType2);
     }
+    else
+    {
+      myRightMode = getMode(qtType1);
+      myRight2ndMode = getMode(qtType2);
+    }
+  }
+  else
+  {
+    const EventMode mode = getMode(type);
+
+    if(port == Controller::Jack::Left)
+      myLeftMode = mode;
+    else
+      myRightMode = mode;
   }
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-EventMode PhysicalKeyboardHandler::getMode(const Properties& properties, const PropType propType)
+EventMode PhysicalKeyboardHandler::getMode(const Properties& properties,
+                                           PropType propType)
 {
   const string& propName = properties.get(propType);
 
   if(!propName.empty())
     return getMode(Controller::getType(propName));
 
-  return getMode(Controller::Type::Joystick);
+  return EventMode::kJoystickMode;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-EventMode PhysicalKeyboardHandler::getMode(const Controller::Type type)
+EventMode PhysicalKeyboardHandler::getMode(Controller::Type type)
 {
   switch(type)
   {
-    case Controller::Type::Keyboard:
-    case Controller::Type::KidVid:
+    using enum Controller::Type;
+    case Keyboard:
+    case KidVid:
       return EventMode::kKeyboardMode;
 
-    case Controller::Type::Paddles:
-    case Controller::Type::PaddlesIAxDr:
-    case Controller::Type::PaddlesIAxis:
+    case Paddles:
+    case PaddlesIAxDr:
+    case PaddlesIAxis:
       return EventMode::kPaddlesMode;
 
-    case Controller::Type::CompuMate:
+    case CompuMate:
       return EventMode::kCompuMateMode;
 
-    case Controller::Type::Driving:
+    case Driving:
       return EventMode::kDrivingMode;
 
     default:
@@ -377,7 +392,7 @@ void PhysicalKeyboardHandler::enableCommonMappings()
 {
   for (int i = Event::NoType + 1; i < Event::LastType; i++)
   {
-    const Event::Type event = static_cast<Event::Type>(i);
+    const auto event = static_cast<Event::Type>(i);
 
     if (isCommonEvent(event))
       enableMapping(event, EventMode::kCommonMode);
@@ -393,19 +408,17 @@ void PhysicalKeyboardHandler::enableMappings(const Event::EventSet& events,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void PhysicalKeyboardHandler::enableMapping(const Event::Type event,
-                                            EventMode mode)
+void PhysicalKeyboardHandler::enableMapping(Event::Type event, EventMode mode)
 {
   // copy from controller mode into emulation mode
-  KeyMap::MappingArray mappings = myKeyMap.getEventMapping(event, mode);
+  const KeyMap::MappingArray mappings = myKeyMap.getEventMapping(event, mode);
 
   for (const auto& mapping : mappings)
     myKeyMap.add(event, EventMode::kEmulationMode, mapping.key, mapping.mod);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-EventMode PhysicalKeyboardHandler::getEventMode(const Event::Type event,
-                                                const EventMode mode) const
+EventMode PhysicalKeyboardHandler::getEventMode(Event::Type event, EventMode mode)
 {
   if (mode == EventMode::kEmulationMode)
   {
@@ -429,41 +442,42 @@ EventMode PhysicalKeyboardHandler::getEventMode(const Event::Type event,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool PhysicalKeyboardHandler::isJoystickEvent(const Event::Type event) const
+bool PhysicalKeyboardHandler::isJoystickEvent(Event::Type event)
 {
-  return LeftJoystickEvents.find(event) != LeftJoystickEvents.end()
-    || QTJoystick3Events.find(event) != QTJoystick3Events.end()
-    || RightJoystickEvents.find(event) != RightJoystickEvents.end()
-    || QTJoystick4Events.find(event) != QTJoystick4Events.end();
+  return LeftJoystickEvents.contains(event)
+    || QTJoystick3Events.contains(event)
+    || RightJoystickEvents.contains(event)
+    || QTJoystick4Events.contains(event);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool PhysicalKeyboardHandler::isPaddleEvent(const Event::Type event) const
+bool PhysicalKeyboardHandler::isPaddleEvent(Event::Type event)
 {
-  return LeftPaddlesEvents.find(event) != LeftPaddlesEvents.end()
-    || QTPaddles3Events.find(event) != QTPaddles3Events.end()
-    || RightPaddlesEvents.find(event) != RightPaddlesEvents.end()
-    || QTPaddles4Events.find(event) != QTPaddles4Events.end();
+  return LeftPaddlesEvents.contains(event)
+    || QTPaddles3Events.contains(event)
+    || RightPaddlesEvents.contains(event)
+    || QTPaddles4Events.contains(event);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool PhysicalKeyboardHandler::isDrivingEvent(const Event::Type event) const
+bool PhysicalKeyboardHandler::isKeyboardEvent(Event::Type event)
 {
-  return LeftDrivingEvents.find(event) != LeftDrivingEvents.end()
-    || RightDrivingEvents.find(event) != RightDrivingEvents.end();
+  return LeftKeyboardEvents.contains(event)
+    || RightKeyboardEvents.contains(event);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool PhysicalKeyboardHandler::isKeyboardEvent(const Event::Type event) const
+bool PhysicalKeyboardHandler::isDrivingEvent(Event::Type event)
 {
-  return LeftKeyboardEvents.find(event) != LeftKeyboardEvents.end()
-    || RightKeyboardEvents.find(event) != RightKeyboardEvents.end();
+  return LeftDrivingEvents.contains(event)
+    || RightDrivingEvents.contains(event);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool PhysicalKeyboardHandler::isCommonEvent(const Event::Type event) const
+bool PhysicalKeyboardHandler::isCommonEvent(Event::Type event)
 {
-  return !(isJoystickEvent(event) || isPaddleEvent(event) || isKeyboardEvent(event));
+  return !(isJoystickEvent(event) || isPaddleEvent(event)
+    || isKeyboardEvent(event) || isDrivingEvent(event));
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -599,7 +613,7 @@ void PhysicalKeyboardHandler::toggleModKeys(bool toggle)
   ostringstream ss;
   ss << "Modifier key combos ";
   ss << (modCombo ? "enabled" : "disabled");
-  myOSystem.frameBuffer().showTextMessage(ss.str());
+  myOSystem.frameBuffer().showTextMessage(ss.view());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -626,6 +640,7 @@ PhysicalKeyboardHandler::DefaultCommonMapping = {
   #endif
   { Event::OptionsMenuMode,          KBDK_TAB },
   { Event::CmdMenuMode,              KBDK_BACKSLASH },
+  { Event::ToggleBezel,              KBDK_B, KBDM_CTRL },
   { Event::TimeMachineMode,          KBDK_T, KBDM_SHIFT },
   { Event::DebuggerMode,             KBDK_GRAVE },
   { Event::PlusRomsSetupMode,        KBDK_P, KBDM_SHIFT | KBDM_CTRL | MOD3 },
@@ -644,7 +659,7 @@ PhysicalKeyboardHandler::DefaultCommonMapping = {
   { Event::VCenterIncrease,          KBDK_PAGEDOWN, MOD3 },
   { Event::VSizeAdjustDecrease,      KBDK_PAGEDOWN, KBDM_SHIFT | MOD3 },
   { Event::VSizeAdjustIncrease,      KBDK_PAGEUP, KBDM_SHIFT | MOD3 },
-  { Event::ToggleCorrectAspectRatio, KBDK_C, KBDM_CTRL },
+  { Event::ToggleCorrectAspectRatio, KBDK_C, KBDM_SHIFT | KBDM_CTRL },
   { Event::VolumeDecrease,           KBDK_LEFTBRACKET, MOD3 },
   { Event::VolumeIncrease,           KBDK_RIGHTBRACKET, MOD3 },
   { Event::SoundToggle,              KBDK_RIGHTBRACKET, KBDM_CTRL },
@@ -662,6 +677,8 @@ PhysicalKeyboardHandler::DefaultCommonMapping = {
   { Event::PhosphorDecrease,         KBDK_4, KBDM_SHIFT | MOD3 },
   { Event::PhosphorIncrease,         KBDK_4, MOD3 },
   { Event::TogglePhosphor,           KBDK_P, MOD3 },
+  //{ Event::PhosphorModeDecrease,     KBDK_P, KBDM_SHIFT | KBDM_CTRL | MOD3 },
+  { Event::PhosphorModeIncrease,     KBDK_P, KBDM_CTRL | MOD3 },
   { Event::ScanlinesDecrease,        KBDK_5, KBDM_SHIFT | MOD3 },
   { Event::ScanlinesIncrease,        KBDK_5, MOD3 },
   { Event::PreviousScanlineMask,     KBDK_6, KBDM_SHIFT | MOD3 },
@@ -709,7 +726,7 @@ PhysicalKeyboardHandler::DefaultCommonMapping = {
   { Event::ToggleFrameStats,         KBDK_L, MOD3 },
   { Event::ToggleTimeMachine,        KBDK_T, MOD3 },
 
-  #ifdef PNG_SUPPORT
+  #ifdef IMAGE_SUPPORT
   { Event::ToggleContSnapshots,      KBDK_S, MOD3 | KBDM_CTRL },
   { Event::ToggleContSnapshotsFrame, KBDK_S, KBDM_SHIFT | MOD3 | KBDM_CTRL },
   #endif
@@ -836,6 +853,7 @@ PhysicalKeyboardHandler::DefaultMenuMapping = {
   {Event::UITabPrev,                KBDK_TAB, KBDM_SHIFT | KBDM_CTRL},
   {Event::UITabNext,                KBDK_TAB, KBDM_CTRL},
 
+  {Event::ToggleUIPalette,          KBDK_T, MOD3},
   {Event::ToggleFullScreen,         KBDK_RETURN, MOD3},
 
 #ifdef BSPF_MACOS
@@ -962,11 +980,9 @@ PhysicalKeyboardHandler::FixedPromptMapping = {
   {Event::UIDown,                   KBDK_DOWN, KBDM_SHIFT},
   {Event::UILeft,                   KBDK_DOWN},
   {Event::UIRight,                  KBDK_UP},
-
 };
 #endif // DEBUGGER_SUPPORT
 
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 PhysicalKeyboardHandler::EventMappingArray PhysicalKeyboardHandler::DefaultJoystickMapping = {
   {Event::LeftJoystickUp,           KBDK_UP},
