@@ -8,15 +8,14 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //============================================================================
 
-#include <cstdio>
-
+#include "FSNode.hxx"
 #include "SqliteDatabase.hxx"
 #include "Logger.hxx"
 #include "SqliteError.hxx"
@@ -25,7 +24,7 @@
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 SqliteDatabase::SqliteDatabase(const string& databaseDirectory,
                                const string& databaseName)
-  : myDatabaseFile{databaseDirectory + databaseName + ".sqlite3"}
+  : myDatabaseFile{FSNode(databaseDirectory).getPath() + databaseName + ".sqlite3"}
 {
 }
 
@@ -51,14 +50,14 @@ void SqliteDatabase::initialize()
     if (!dbInitialized && tries == 1) {
       Logger::info("sqlite DB " + myDatabaseFile + " seems to be corrupt, removing and retrying...");
 
-      remove(myDatabaseFile.c_str());
+      std::ignore = remove(myDatabaseFile.c_str());
       if (myHandle) sqlite3_close_v2(myHandle);
     }
   }
 
   if (!dbInitialized) {
     if (myHandle) {
-      string emsg = sqlite3_errmsg(myHandle);
+      const string emsg = sqlite3_errmsg(myHandle);
 
       sqlite3_close_v2(myHandle);
       myHandle = nullptr;
@@ -88,9 +87,9 @@ void SqliteDatabase::initialize()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void SqliteDatabase::exec(const string& sql)
+void SqliteDatabase::exec(string_view sql)
 {
-  if (sqlite3_exec(myHandle, sql.c_str(), nullptr, nullptr, nullptr) != SQLITE_OK)
+  if (sqlite3_exec(myHandle, string{sql}.c_str(), nullptr, nullptr, nullptr) != SQLITE_OK)
     throw SqliteError(myHandle);
 }
 
@@ -106,7 +105,7 @@ Int32 SqliteDatabase::getUserVersion() const
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void SqliteDatabase::setUserVersion(Int32 version)
+void SqliteDatabase::setUserVersion(Int32 version) const
 {
   SqliteStatement(*this, "PRAGMA user_version = %i", static_cast<int>(version))
     .step();
