@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -121,25 +121,25 @@ void RiotDebug::saveOldState()
 uInt8 RiotDebug::swcha(int newVal)
 {
   if(newVal > -1)
-    mySystem.poke(0x280, newVal);
+    mySystem.pokeOob(0x280, newVal);
 
-  return mySystem.peek(0x280);
+  return mySystem.peekOob(0x280);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 uInt8 RiotDebug::swchb(int newVal)
 {
   if(newVal > -1)
-    mySystem.poke(0x282, newVal);
+    mySystem.pokeOob(0x282, newVal);
 
-  return mySystem.peek(0x282);
+  return mySystem.peekOob(0x282);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 uInt8 RiotDebug::swacnt(int newVal)
 {
   if(newVal > -1)
-    mySystem.poke(0x281, newVal);
+    mySystem.pokeOob(0x281, newVal);
 
   return mySystem.m6532().myDDRA;
 }
@@ -148,7 +148,7 @@ uInt8 RiotDebug::swacnt(int newVal)
 uInt8 RiotDebug::swbcnt(int newVal)
 {
   if(newVal > -1)
-    mySystem.poke(0x283, newVal);
+    mySystem.pokeOob(0x283, newVal);
 
   return mySystem.m6532().myDDRB;
 }
@@ -159,7 +159,7 @@ uInt8 RiotDebug::inpt(int x)
   static constexpr std::array<TIARegister, 6> _inpt = {
     INPT0, INPT1, INPT2, INPT3, INPT4, INPT5
   };
-  return mySystem.peek(_inpt[x]);
+  return mySystem.peekOob(_inpt[x]);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -177,7 +177,7 @@ bool RiotDebug::vblank(int bit)
 uInt8 RiotDebug::tim1T(int newVal)
 {
   if(newVal > -1)
-    mySystem.poke(0x294, newVal);
+    mySystem.pokeOob(0x294, newVal);
 
   return mySystem.m6532().myOutTimer[0];
 }
@@ -186,7 +186,7 @@ uInt8 RiotDebug::tim1T(int newVal)
 uInt8 RiotDebug::tim8T(int newVal)
 {
   if(newVal > -1)
-    mySystem.poke(0x295, newVal);
+    mySystem.pokeOob(0x295, newVal);
 
   return mySystem.m6532().myOutTimer[1];
 }
@@ -195,7 +195,7 @@ uInt8 RiotDebug::tim8T(int newVal)
 uInt8 RiotDebug::tim64T(int newVal)
 {
   if(newVal > -1)
-    mySystem.poke(0x296, newVal);
+    mySystem.pokeOob(0x296, newVal);
 
   return mySystem.m6532().myOutTimer[2];
 }
@@ -204,7 +204,7 @@ uInt8 RiotDebug::tim64T(int newVal)
 uInt8 RiotDebug::tim1024T(int newVal)
 {
   if(newVal > -1)
-    mySystem.poke(0x297, newVal);
+    mySystem.pokeOob(0x297, newVal);
 
   return mySystem.m6532().myOutTimer[3];
 }
@@ -257,6 +257,16 @@ int RiotDebug::timReadCycles() const
   return mySystem.m6532().myTimReadCycles;
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+bool RiotDebug::switches(int newVal)
+{
+  uInt8& switches = myConsole.switches().mySwitches;
+  if(newVal > -1)
+    switches = newVal;
+
+  return switches;
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool RiotDebug::diffP0(int newVal)
 {
@@ -363,47 +373,47 @@ string RiotDebug::switchesString()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 string RiotDebug::toString()
 {
-  const RiotState& state    = static_cast<const RiotState&>(getState());
-  const RiotState& oldstate = static_cast<const RiotState&>(getOldState());
+  const auto& state    = static_cast<const RiotState&>(getState());
+  const auto& oldstate = static_cast<const RiotState&>(getOldState());
 
   ostringstream buf;
-  buf << "280/SWCHA(R)=" << myDebugger.invIfChanged(state.SWCHA_R, oldstate.SWCHA_R)
-      << " 280/SWCHA(W)=" << myDebugger.invIfChanged(state.SWCHA_W, oldstate.SWCHA_W)
-      << " 281/SWACNT=" << myDebugger.invIfChanged(state.SWACNT, oldstate.SWACNT)
-      << endl
-      << "282/SWCHB(R)=" << myDebugger.invIfChanged(state.SWCHB_R, oldstate.SWCHB_R)
-      << " 282/SWCHB(W)=" << myDebugger.invIfChanged(state.SWCHB_W, oldstate.SWCHB_W)
-      << " 283/SWBCNT=" << myDebugger.invIfChanged(state.SWBCNT, oldstate.SWBCNT)
-      << endl
+  buf << "280/SWCHA(R)=" << Debugger::invIfChanged(state.SWCHA_R, oldstate.SWCHA_R)
+      << " 280/SWCHA(W)=" << Debugger::invIfChanged(state.SWCHA_W, oldstate.SWCHA_W)
+      << " 281/SWACNT=" << Debugger::invIfChanged(state.SWACNT, oldstate.SWACNT)
+      << '\n'
+      << "282/SWCHB(R)=" << Debugger::invIfChanged(state.SWCHB_R, oldstate.SWCHB_R)
+      << " 282/SWCHB(W)=" << Debugger::invIfChanged(state.SWCHB_W, oldstate.SWCHB_W)
+      << " 283/SWBCNT=" << Debugger::invIfChanged(state.SWBCNT, oldstate.SWBCNT)
+      << '\n'
 
       // These are squirrely: some symbol files will define these as
       // 0x284-0x287. Doesn't actually matter, these registers repeat
       // every 16 bytes.
-      << "294/TIM1T=" << myDebugger.invIfChanged(state.TIM1T, oldstate.TIM1T)
-      << " 295/TIM8T=" << myDebugger.invIfChanged(state.TIM8T, oldstate.TIM8T)
-      << " 296/TIM64T=" << myDebugger.invIfChanged(state.TIM64T, oldstate.TIM64T)
-      << " 297/T1024T=" << myDebugger.invIfChanged(state.T1024T, oldstate.T1024T)
-      << endl
+      << "294/TIM1T=" << Debugger::invIfChanged(state.TIM1T, oldstate.TIM1T)
+      << " 295/TIM8T=" << Debugger::invIfChanged(state.TIM8T, oldstate.TIM8T)
+      << " 296/TIM64T=" << Debugger::invIfChanged(state.TIM64T, oldstate.TIM64T)
+      << " 297/T1024T=" << Debugger::invIfChanged(state.T1024T, oldstate.T1024T)
+      << " Divider=" << Debugger::invIfChanged(state.TIMDIV, oldstate.TIMDIV)
+      << '\n'
 
-      << "0x284/INTIM=" << myDebugger.invIfChanged(state.INTIM, oldstate.INTIM)
-      << " 285/TIMINT=" << myDebugger.invIfChanged(state.TIMINT, oldstate.TIMINT)
-      << " Timer_Clocks=" << myDebugger.invIfChanged(state.TIMCLKS, oldstate.TIMCLKS)
-      << " INTIM_Clocks=" << myDebugger.invIfChanged(state.INTIMCLKS, oldstate.INTIMCLKS)
-      << " Divider=" << myDebugger.invIfChanged(state.TIMDIV, oldstate.TIMDIV)
-      << endl
+      << "0x284/INTIM=" << Debugger::invIfChanged(state.INTIM, oldstate.INTIM)
+      << " 285/TIMINT=" << Debugger::invIfChanged(state.TIMINT, oldstate.TIMINT)
+      << " Timer_Clocks=" << Debugger::invIfChanged(state.TIMCLKS, oldstate.TIMCLKS)
+      << " INTIM_Clocks=" << Debugger::invIfChanged(state.INTIMCLKS, oldstate.INTIMCLKS)
+      << '\n'
 
       << "Left/P0diff: " << diffP0String() << "   Right/P1diff: " << diffP1String()
-      << endl
+      << '\n'
       << "TVType: " << tvTypeString() << "   Switches: " << switchesString()
-      << endl
+      << '\n'
 
       // Yes, the fire buttons are in the TIA, but we might as well
       // show them here for convenience.
       << "Left/P0 stick:  " << dirP0String()
-      << ((mySystem.peek(0x03c) & 0x80) ? "" : "(button) ")
-      << endl
+      << ((mySystem.peekOob(0x03c) & 0x80) ? "" : "(button) ")
+      << '\n'
       << "Right/P1 stick: " << dirP1String()
-      << ((mySystem.peek(0x03d) & 0x80) ? "" : "(button) ");
+      << ((mySystem.peekOob(0x03d) & 0x80) ? "" : "(button) ");
 
   return buf.str();
 }
