@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -30,15 +30,13 @@ AtariVoxWidget::AtariVoxWidget(GuiObject* boss, const GUI::Font& font,
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void AtariVoxWidget::eraseCurrent()
 {
-  AtariVox& avox = static_cast<AtariVox&>(controller());
-
+  auto& avox = static_cast<AtariVox&>(controller());
   avox.eraseCurrent();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool AtariVoxWidget::isPageUsed(uInt32 page)
 {
-  const AtariVox& avox = static_cast<AtariVox&>(controller());
-
+  const auto& avox = static_cast<AtariVox&>(controller());
   return avox.isPageUsed(page);
 }
