@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -23,7 +23,6 @@
 #include "TIADebug.hxx"
 #include "Widget.hxx"
 #include "Base.hxx"
-using Common::Base;
 
 #include "AudioWidget.hxx"
 
@@ -102,8 +101,8 @@ void AudioWidget::loadConfig()
 
   const Debugger& dbg = instance().debugger();
   TIADebug& tia = dbg.tiaDebug();
-  const TiaState& state    = static_cast<const TiaState&>(tia.getState());
-  const TiaState& oldstate = static_cast<const TiaState&>(tia.getOldState());
+  const auto& state    = static_cast<const TiaState&>(tia.getState());
+  const auto& oldstate = static_cast<const TiaState&>(tia.getOldState());
 
   // AUDF0/1
   alist.clear();  vlist.clear();  changed.clear();
@@ -153,7 +152,7 @@ void AudioWidget::handleVolume()
   stringstream s;
 
   s << getEffectiveVolume() << "% (eff. volume)";
-  myAudEffV->setLabel(s.str());
+  myAudEffV->setLabel(s.view());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
