@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -18,7 +18,6 @@
 #include "CartBUS.hxx"
 #include "DataGridWidget.hxx"
 #include "PopUpWidget.hxx"
-#include "EditTextWidget.hxx"
 #include "CartBUSWidget.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -99,8 +98,7 @@ CartridgeBUSWidget::CartridgeBUSWidget(
   myDatastreamPointers2->setTarget(this);
   myDatastreamPointers2->setEditable(false);
 
-  uInt32 row;
-  for(row = 0; row < 4; ++row)
+  for(uInt32 row = 0; row < 4; ++row)
   {
     myDatastreamLabels[row] =
     new StaticTextWidget(_boss, _font, DS_X - _font.getStringWidth("xx "),
@@ -369,7 +367,8 @@ void CartridgeBUSWidget::loadConfig()
   for(int i = 0; i < 3; ++i)
   {
     alist.push_back(0);  vlist.push_back(myCart.myMusicCounters[i]);
-    changed.push_back(myCart.myMusicCounters[i] != uInt32(myOldState.mcounters[i]));
+    changed.push_back(myCart.myMusicCounters[i] !=
+      static_cast<uInt32>(myOldState.mcounters[i]));
   }
   myMusicCounters->setList(alist, vlist, changed);
 
@@ -377,7 +376,8 @@ void CartridgeBUSWidget::loadConfig()
   for(int i = 0; i < 3; ++i)
   {
     alist.push_back(0);  vlist.push_back(myCart.myMusicFrequencies[i]);
-    changed.push_back(myCart.myMusicFrequencies[i] != uInt32(myOldState.mfreqs[i]));
+    changed.push_back(myCart.myMusicFrequencies[i] !=
+      static_cast<uInt32>(myOldState.mfreqs[i]));
   }
   myMusicFrequencies->setList(alist, vlist, changed);
 
@@ -385,7 +385,8 @@ void CartridgeBUSWidget::loadConfig()
   for(int i = 0; i < 3; ++i)
   {
     alist.push_back(0);  vlist.push_back(myCart.getWaveform(i) >> 5);
-    changed.push_back((myCart.getWaveform(i) >> 5) != uInt32(myOldState.mwaves[i]));
+    changed.push_back((myCart.getWaveform(i) >> 5) !=
+      static_cast<uInt32>(myOldState.mwaves[i]));
   }
   myMusicWaveforms->setList(alist, vlist, changed);
 
@@ -393,7 +394,8 @@ void CartridgeBUSWidget::loadConfig()
   for(int i = 0; i < 3; ++i)
   {
     alist.push_back(0);  vlist.push_back(myCart.getWaveformSize(i));
-    changed.push_back((myCart.getWaveformSize(i)) != uInt32(myOldState.mwavesizes[i]));
+    changed.push_back((myCart.getWaveformSize(i)) !=
+      static_cast<uInt32>(myOldState.mwavesizes[i]));
   }
   myMusicWaveformSizes->setList(alist, vlist, changed);
 
@@ -401,7 +403,8 @@ void CartridgeBUSWidget::loadConfig()
   {
     alist.clear();  vlist.clear();  changed.clear();
     alist.push_back(0);  vlist.push_back(myCart.getSample());
-    changed.push_back((myCart.getSample()) != uInt32(myOldState.samplepointer[0]));
+    changed.push_back((myCart.getSample()) !=
+      static_cast<uInt32>(myOldState.samplepointer[0]));
     mySamplePointer->setList(alist, vlist, changed);
   }
 
@@ -449,7 +452,7 @@ string CartridgeBUSWidget::bankState()
 
   if (myCart.myBUSSubtype == CartridgeBUS::BUSSubtype::BUS0)
   {
-    static constexpr std::array<const char*, 6> spot = {
+    static constexpr std::array<string_view, 6> spot = {
       "$FFF6", "$FFF7", "$FFF8", "$FFF9", "$FFFA", "$FFFB"
     };
     buf << "Bank = " << std::dec << myCart.getBank()
@@ -457,7 +460,7 @@ string CartridgeBUSWidget::bankState()
   }
   else
   {
-    static constexpr std::array<const char*, 7> spot = {
+    static constexpr std::array<string_view, 7> spot = {
       "$FFF5", "$FFF6", "$FFF7", "$FFF8", "$FFF9", "$FFFA", "$FFFB"
     };
     buf << "Bank = " << std::dec << myCart.getBank()
