@@ -8,17 +8,15 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //============================================================================
 
-#include "OSystem.hxx"
 #include "DataGridWidget.hxx"
 #include "PopUpWidget.hxx"
-#include "EditTextWidget.hxx"
 #include "CartCDFWidget.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -111,8 +109,7 @@ CartridgeCDFWidget::CartridgeCDFWidget(
   myJumpStreamPointers->setTarget(this);
   myJumpStreamPointers->setEditable(false);
 
-  uInt32 row;
-  for(row = 0; row < 8; ++row)
+  for(uInt32 row = 0; row < 8; ++row)
   {
     myDatastreamLabels[row] =
     new StaticTextWidget(_boss, _font, DS_X - _font.getStringWidth("xx "),
@@ -208,7 +205,7 @@ CartridgeCDFWidget::CartridgeCDFWidget(
 
   xpos = HBORDER + INDENT;  ypos += myLineHeight + VGAP;
 
-  int lwidth2 = _font.getStringWidth("Sample Pointer ");
+  const int lwidth2 = _font.getStringWidth("Sample Pointer ");
   new StaticTextWidget(boss, _font, xpos, ypos, "Sample Pointer");
 
   mySamplePointer = new DataGridWidget(boss, _nfont, xpos + lwidth2, ypos - 2, 1, 1, 8, 32,
@@ -286,7 +283,8 @@ void CartridgeCDFWidget::loadConfig()
   {
     alist.clear();  vlist.clear();  changed.clear();
     alist.push_back(0);  vlist.push_back(myCart.myRAM[myCart.myFastFetcherOffset]);
-    changed.push_back((myCart.myRAM[myCart.myFastFetcherOffset]) != uInt32(myOldState.fastfetchoffset[0]));
+    changed.push_back((myCart.myRAM[myCart.myFastFetcherOffset]) !=
+      static_cast<uInt32>(myOldState.fastfetchoffset[0]));
     myFastFetcherOffset->setList(alist, vlist, changed);
   }
 
@@ -361,7 +359,8 @@ void CartridgeCDFWidget::loadConfig()
   for(int i = 0; i < 3; ++i)
   {
     alist.push_back(0);  vlist.push_back(myCart.myMusicCounters[i]);
-    changed.push_back(myCart.myMusicCounters[i] != uInt32(myOldState.mcounters[i]));
+    changed.push_back(myCart.myMusicCounters[i] !=
+      static_cast<uInt32>(myOldState.mcounters[i]));
   }
   myMusicCounters->setList(alist, vlist, changed);
 
@@ -369,7 +368,8 @@ void CartridgeCDFWidget::loadConfig()
   for(int i = 0; i < 3; ++i)
   {
     alist.push_back(0);  vlist.push_back(myCart.myMusicFrequencies[i]);
-    changed.push_back(myCart.myMusicFrequencies[i] != uInt32(myOldState.mfreqs[i]));
+    changed.push_back(myCart.myMusicFrequencies[i] !=
+      static_cast<uInt32>(myOldState.mfreqs[i]));
   }
   myMusicFrequencies->setList(alist, vlist, changed);
 
@@ -377,7 +377,8 @@ void CartridgeCDFWidget::loadConfig()
   for(int i = 0; i < 3; ++i)
   {
     alist.push_back(0);  vlist.push_back(myCart.getWaveform(i) >> 5);
-    changed.push_back((myCart.getWaveform(i) >> 5) != uInt32(myOldState.mwaves[i]));
+    changed.push_back((myCart.getWaveform(i) >> 5) !=
+      static_cast<uInt32>(myOldState.mwaves[i]));
   }
   myMusicWaveforms->setList(alist, vlist, changed);
 
@@ -385,13 +386,15 @@ void CartridgeCDFWidget::loadConfig()
   for(int i = 0; i < 3; ++i)
   {
     alist.push_back(0);  vlist.push_back(myCart.getWaveformSize(i));
-    changed.push_back((myCart.getWaveformSize(i)) != uInt32(myOldState.mwavesizes[i]));
+    changed.push_back((myCart.getWaveformSize(i)) !=
+      static_cast<uInt32>(myOldState.mwavesizes[i]));
   }
   myMusicWaveformSizes->setList(alist, vlist, changed);
 
   alist.clear();  vlist.clear();  changed.clear();
   alist.push_back(0);  vlist.push_back(myCart.getSample());
-  changed.push_back((myCart.getSample()) != uInt32(myOldState.samplepointer[0]));
+  changed.push_back((myCart.getSample()) !=
+    static_cast<uInt32>(myOldState.samplepointer[0]));
   mySamplePointer->setList(alist, vlist, changed);
 
   myFastFetch->setState((myCart.myMode & 0x0f) == 0);
@@ -434,7 +437,7 @@ string CartridgeCDFWidget::bankState()
 {
   ostringstream& buf = buffer();
 
-  static constexpr std::array<const char*, 8> spot = {
+  static constexpr std::array<string_view, 8> spot = {
     "$FFF4", "$FFF5", "$FFF6", "$FFF7", "$FFF8", "$FFF9", "$FFFA", "$FFFB"
   };
 
@@ -514,20 +517,12 @@ string CartridgeCDFWidget::describeCDFVersion(CartridgeCDF::CDFSubtype subtype)
 {
   switch(subtype)
   {
-    case CartridgeCDF::CDFSubtype::CDF0:
-      return "CDF (v0)";
-
-    case CartridgeCDF::CDFSubtype::CDF1:
-      return "CDF (v1)";
-
-    case CartridgeCDF::CDFSubtype::CDFJ:
-      return "CDFJ";
-
-    case CartridgeCDF::CDFSubtype::CDFJplus:
-      return "CDFJ+";
-
-    default:
-      throw runtime_error("unreachable");
+    using enum CartridgeCDF::CDFSubtype;
+    case CDF0:      return "CDF (v0)";
+    case CDF1:      return "CDF (v1)";
+    case CDFJ:      return "CDFJ";
+    case CDFJplus:  return "CDFJ+";
+    default:        throw runtime_error("unreachable");
   }
 }
 
