@@ -8,15 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //============================================================================
 
-#include <sstream>
-
 #include "OSystem.hxx"
 #include "GuiObject.hxx"
 #include "Debugger.hxx"
@@ -205,7 +203,7 @@ void CpuWidget::handleCommand(CommandSender* sender, int cmd, int data, int id)
           // event the rest of the debugger widgets
           ostringstream command;
           command << "pc #" << value;
-          instance().debugger().run(command.str());
+          instance().debugger().run(command.view());
           break;
         }
 
@@ -299,8 +297,8 @@ void CpuWidget::loadConfig()
   const Debugger& dbg = instance().debugger();
   const CartDebug& cart = dbg.cartDebug();
   CpuDebug& cpu = dbg.cpuDebug();
-  const CpuState& state    = static_cast<const CpuState&>(cpu.getState());
-  const CpuState& oldstate = static_cast<const CpuState&>(cpu.getOldState());
+  const auto& state    = static_cast<const CpuState&>(cpu.getState());
+  const auto& oldstate = static_cast<const CpuState&>(cpu.getOldState());
 
   // Add PC to its own DataGridWidget
   alist.push_back(kPCRegAddr);
