@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -57,7 +57,7 @@ DataGridWidget::DataGridWidget(GuiObject* boss, const GUI::Font& font,
     _valueList.push_back(0);
     _valueStringList.push_back(EmptyString);
     _toolTipList.push_back(EmptyString);
-    _changedList.push_back(0);
+    _changedList.push_back(false);
     _hiliteList.push_back(false);
   }
 
@@ -113,7 +113,7 @@ void DataGridWidget::setList(const IntArray& alist, const IntArray& vlist,
   cerr << "alist.size() = "     << alist.size()
        << ", vlist.size() = "   << vlist.size()
        << ", changed.size() = " << changed.size()
-       << ", _rows*_cols = "    << _rows * _cols << endl << endl;
+       << ", _rows*_cols = "    << _rows * _cols << "\n\n";
   */
   const size_t size = vlist.size();  // assume the alist is the same size
 
@@ -133,7 +133,6 @@ void DataGridWidget::setList(const IntArray& alist, const IntArray& vlist,
   _changedList = changed;
 
   // An efficiency thing
-  string temp;
   for(size_t i = 0; i < size; ++i)
     _valueStringList.push_back(Common::Base::toString(_valueList[i], _base));
 
@@ -142,7 +141,7 @@ void DataGridWidget::setList(const IntArray& alist, const IntArray& vlist,
        << ", _valueList.size() = "   << _valueList.size()
        << ", _changedList.size() = " << _changedList.size()
        << ", _valueStringList.size() = " << _valueStringList.size()
-       << ", _rows*_cols = "    << _rows * _cols << endl << endl;
+       << ", _rows*_cols = "    << _rows * _cols << "\n\n";
   */
   enableEditMode(false);
 
@@ -259,8 +258,7 @@ void DataGridWidget::handleMouseDown(int x, int y, MouseButton b, int clickCount
 
   resetSelection();
   // First check whether the selection changed
-  int newSelectedItem;
-  newSelectedItem = findItem(x, y);
+  int newSelectedItem = findItem(x, y);
   if (newSelectedItem > static_cast<int>(_valueList.size()) - 1)
     newSelectedItem = -1;
 
@@ -309,7 +307,7 @@ void DataGridWidget::handleMouseWheel(int x, int y, int direction)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-int DataGridWidget::findItem(int x, int y)
+int DataGridWidget::findItem(int x, int y) const
 {
   int row = (y - 1) / _rowHeight;
   if(row >= _rows) row = _rows - 1;
@@ -375,12 +373,12 @@ bool DataGridWidget::handleKeyDown(StellaKey key, StellaMod mod)
         break;
 
       case KBDK_DOWN:
-        if (_currentRow < int(_rows) - 1)
+        if (_currentRow < _rows - 1)
         {
           _currentRow++;
           dirty = true;
         }
-        else if(_currentCol < int(_cols) - 1)
+        else if(_currentCol < _cols - 1)
         {
           _currentRow = 0;
           _currentCol++;
@@ -403,12 +401,12 @@ bool DataGridWidget::handleKeyDown(StellaKey key, StellaMod mod)
         break;
 
       case KBDK_RIGHT:
-        if (_currentCol < int(_cols) - 1)
+        if (_currentCol < _cols - 1)
         {
           _currentCol++;
           dirty = true;
         }
-        else if(_currentRow < int(_rows) - 1)
+        else if(_currentRow < _rows - 1)
         {
           _currentCol = 0;
           _currentRow++;
@@ -429,7 +427,7 @@ bool DataGridWidget::handleKeyDown(StellaKey key, StellaMod mod)
       case KBDK_PAGEDOWN:
         if(StellaModTest::isShift(mod) && _scrollBar)
           handleMouseWheel(0, 0, +1);
-        else if (_currentRow < int(_rows) - 1)
+        else if (_currentRow < _rows - 1)
         {
           _currentRow = _rows - 1;
           dirty = true;
@@ -445,7 +443,7 @@ bool DataGridWidget::handleKeyDown(StellaKey key, StellaMod mod)
         break;
 
       case KBDK_END:
-        if (_currentCol < int(_cols) - 1)
+        if (_currentCol < _cols - 1)
         {
           _currentCol = _cols - 1;
           dirty = true;
@@ -584,7 +582,7 @@ void DataGridWidget::handleCommand(CommandSender* sender, int cmd,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void DataGridWidget::setToolTip(int column, int row, const string& text)
+void DataGridWidget::setToolTip(int column, int row, string_view text)
 {
   if(row >= 0 && row < _rows && column >= 0 && column < _cols)
     _toolTipList[row * _cols + column] = text;
@@ -714,11 +712,13 @@ void DataGridWidget::drawWidget(bool hilite)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Common::Rect DataGridWidget::getEditRect() const
 {
-  const int rowoffset = _currentRow * _rowHeight;
-  const int coloffset = _currentCol * _colWidth + 4;
+  const uInt32 rowoffset = _currentRow * _rowHeight;
+  const uInt32 coloffset = _currentCol * _colWidth + 4;
 
-  return Common::Rect(1 + coloffset, rowoffset,
-                      _colWidth + coloffset - 5, _rowHeight + rowoffset);
+  return {
+    1 + coloffset, rowoffset,
+    _colWidth + coloffset - 5, _rowHeight + rowoffset
+  };
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -758,8 +758,8 @@ void DataGridWidget::endEditMode()
   enableEditMode(false);
 
   // Update the both the string representation and the real data
-  if(editString().size() > 0 && !(editString()[0] == '$' ||
-        editString()[0] == '#' || editString()[0] == '\\'))
+  if(!editString().empty() && editString()[0] != '$' &&
+     editString()[0] != '#' && editString()[0] != '\\')
   {
     switch(_base)
     {
@@ -778,7 +778,7 @@ void DataGridWidget::endEditMode()
       case Common::Base::Fmt::_10:
         editString().insert(0, 1, '#');
         break;
-      case Common::Base::Fmt::_DEFAULT:
+      case Common::Base::Fmt::DEFAULT:
       default:  // TODO - properly handle all other cases
         break;
     }
