@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -72,7 +72,7 @@ DebuggerDialog::DebuggerDialog(OSystem& osystem, DialogContainer& parent,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-DebuggerDialog::~DebuggerDialog()
+DebuggerDialog::~DebuggerDialog()  // NOLINT (we need an empty d'tor)
 {
 }
 
@@ -137,94 +137,96 @@ void DebuggerDialog::handleKeyDown(StellaKey key, StellaMod mod, bool repeated)
     }
   }
 
-  // handle emulation keys second (can be remapped)
-  const Event::Type event = instance().eventHandler().eventForKey(EventMode::kEmulationMode, key, mod);
-  switch (event)
+  // Do not handle emulation events which have the same mapping as menu events
+  if(!instance().eventHandler().checkEventForKey(EventMode::kMenuMode, key, mod))
   {
-    case Event::ExitMode:
-      // make consistent, exit debugger on key UP
-      if(!repeated)
-        myExitPressed = true;
-      return;
+    // handle emulation keys second (can be remapped)
+    const Event::Type event = instance().eventHandler().eventForKey(EventMode::kEmulationMode, key, mod);
+    switch(event)
+    {
+      case Event::ExitMode:
+        // make consistent, exit debugger on key UP
+        if(!repeated)
+          myExitPressed = true;
+        return;
 
-    // events which can be handled 1:1
-    case Event::ToggleP0Collision:
-    case Event::ToggleP0Bit:
-    case Event::ToggleP1Collision:
-    case Event::ToggleP1Bit:
-    case Event::ToggleM0Collision:
-    case Event::ToggleM0Bit:
-    case Event::ToggleM1Collision:
-    case Event::ToggleM1Bit:
-    case Event::ToggleBLCollision:
-    case Event::ToggleBLBit:
-    case Event::TogglePFCollision:
-    case Event::TogglePFBit:
-    case Event::ToggleFixedColors:
-    case Event::ToggleCollisions:
-    case Event::ToggleBits:
+        // events which can be handled 1:1
+      case Event::ToggleP0Collision:
+      case Event::ToggleP0Bit:
+      case Event::ToggleP1Collision:
+      case Event::ToggleP1Bit:
+      case Event::ToggleM0Collision:
+      case Event::ToggleM0Bit:
+      case Event::ToggleM1Collision:
+      case Event::ToggleM1Bit:
+      case Event::ToggleBLCollision:
+      case Event::ToggleBLBit:
+      case Event::TogglePFCollision:
+      case Event::TogglePFBit:
+      case Event::ToggleFixedColors:
+      case Event::ToggleCollisions:
+      case Event::ToggleBits:
 
-    case Event::ToggleTimeMachine:
+      case Event::ToggleTimeMachine:
 
-    case Event::SaveState:
-    case Event::SaveAllStates:
-    case Event::PreviousState :
-    case Event::NextState:
-    case Event::LoadState:
-    case Event::LoadAllStates:
+      case Event::SaveState:
+      case Event::SaveAllStates:
+      case Event::PreviousState:
+      case Event::NextState:
+      case Event::LoadState:
+      case Event::LoadAllStates:
 
-    case Event::ConsoleColor:
-    case Event::ConsoleBlackWhite:
-    case Event::ConsoleColorToggle:
-    case Event::Console7800Pause:
-    case Event::ConsoleLeftDiffA:
-    case Event::ConsoleLeftDiffB:
-    case Event::ConsoleLeftDiffToggle:
-    case Event::ConsoleRightDiffA:
-    case Event::ConsoleRightDiffB:
-    case Event::ConsoleRightDiffToggle:
-      if(!repeated)
-        instance().eventHandler().handleEvent(event);
-      return;
+      case Event::ConsoleColor:
+      case Event::ConsoleBlackWhite:
+      case Event::ConsoleColorToggle:
+      case Event::Console7800Pause:
+      case Event::ConsoleLeftDiffA:
+      case Event::ConsoleLeftDiffB:
+      case Event::ConsoleLeftDiffToggle:
+      case Event::ConsoleRightDiffA:
+      case Event::ConsoleRightDiffB:
+      case Event::ConsoleRightDiffToggle:
+        if(!repeated)
+          instance().eventHandler().handleEvent(event);
+        return;
 
-    // events which need special handling in debugger
-    case Event::TakeSnapshot:
-      if(!repeated)
-        instance().debugger().parser().run("saveSnap");
-      return;
+        // events which need special handling in debugger
+      case Event::TakeSnapshot:
+        if(!repeated)
+          instance().debugger().parser().run("saveSnap");
+        return;
 
-    case Event::Rewind1Menu:
-      doRewind();
-      return;
+      case Event::Rewind1Menu:
+        doRewind();
+        return;
 
-    case Event::Rewind10Menu:
-      doRewind10();
-      return;
+      case Event::Rewind10Menu:
+        doRewind10();
+        return;
 
-    case Event::RewindAllMenu:
-      doRewindAll();
-      return;
+      case Event::RewindAllMenu:
+        doRewindAll();
+        return;
 
-    case Event::Unwind1Menu:
-      doUnwind();
-      return;
+      case Event::Unwind1Menu:
+        doUnwind();
+        return;
 
-    case Event::Unwind10Menu:
-      doUnwind10();
-      return;
+      case Event::Unwind10Menu:
+        doUnwind10();
+        return;
 
-    case Event::UnwindAllMenu:
-      doUnwindAll();
-      return;
+      case Event::UnwindAllMenu:
+        doUnwindAll();
+        return;
 
-    default:
-      break;
+      default:
+        break;
+    }
   }
-
   Dialog::handleKeyDown(key, mod);
 }
 
-
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DebuggerDialog::handleKeyUp(StellaKey key, StellaMod mod)
 {
@@ -377,8 +379,8 @@ void DebuggerDialog::doExitRom()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void DebuggerDialog::createFont()
 {
-  string fontSize = instance().settings().getString("dbg.fontsize");
-  int fontStyle = instance().settings().getInt("dbg.fontstyle");
+  const string fontSize = instance().settings().getString("dbg.fontsize");
+  const int fontStyle = instance().settings().getInt("dbg.fontstyle");
 
   if(fontSize == "large")
   {
@@ -434,7 +436,7 @@ void DebuggerDialog::createFont()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void DebuggerDialog::showFatalMessage(const string& msg)
+void DebuggerDialog::showFatalMessage(string_view msg)
 {
   myFatalError = make_unique<GUI::MessageBox>(this, *myLFont, msg, _w-20, _h-20,
                                               kDDExitFatalCmd, "Exit ROM", "Continue", "Fatal error");
@@ -475,22 +477,22 @@ void DebuggerDialog::addTabArea()
 
   // The TIA tab
   tabID = myTab->addTab("TIA");
-  TiaWidget* tia = new TiaWidget(myTab, *myLFont, *myNFont,
-                                 2, 2, widWidth, widHeight);
+  auto* tia = new TiaWidget(myTab, *myLFont, *myNFont,
+                            2, 2, widWidth, widHeight);
   myTab->setParentWidget(tabID, tia);
   addToFocusList(tia->getFocusList(), myTab, tabID);
 
   // The input/output tab (includes RIOT and INPTx from TIA)
   tabID = myTab->addTab("I/O");
-  RiotWidget* riot = new RiotWidget(myTab, *myLFont, *myNFont,
-                                    2, 2, widWidth, widHeight);
+  auto* riot = new RiotWidget(myTab, *myLFont, *myNFont,
+                              2, 2, widWidth, widHeight);
   myTab->setParentWidget(tabID, riot);
   addToFocusList(riot->getFocusList(), myTab, tabID);
 
   // The Audio tab
   tabID = myTab->addTab("Audio");
-  AudioWidget* aud = new AudioWidget(myTab, *myLFont, *myNFont,
-                                     2, 2, widWidth, widHeight);
+  auto* aud = new AudioWidget(myTab, *myLFont, *myNFont,
+                              2, 2, widWidth, widHeight);
   myTab->setParentWidget(tabID, aud);
   addToFocusList(aud->getFocusList(), myTab, tabID);
 
@@ -624,7 +626,7 @@ void DebuggerDialog::addRomArea()
   wid1.push_back(myRewindButton);
   wid1.push_back(myUnwindButton);
 
-  DataGridOpsWidget* ops = new DataGridOpsWidget(this, *myLFont, xpos, ypos);
+  auto* ops = new DataGridOpsWidget(this, *myLFont, xpos, ypos);
 
   const int max_w = xpos - r.x() - 10;
   xpos = r.x() + 10;  ypos = 5;
@@ -713,8 +715,10 @@ void DebuggerDialog::addRomArea()
 Common::Rect DebuggerDialog::getTiaBounds() const
 {
   // The area showing the TIA image (NTSC and PAL supported, up to 274 lines without scaling)
-  return Common::Rect(0, 0, 320, std::max(static_cast<int>(FrameManager::Metrics::baseHeightPAL),
-                                          static_cast<int>(_h * 0.35)));
+  return {
+    0, 0, 320,
+    std::max<uInt32>(FrameManager::Metrics::baseHeightPAL, _h * 0.35)
+  };
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -722,7 +726,10 @@ Common::Rect DebuggerDialog::getRomBounds() const
 {
   // The ROM area is the full area to the right of the tabs
   const Common::Rect& status = getStatusBounds();
-  return Common::Rect(status.x() + status.w() + 1, 0, _w, _h);
+  return {
+    status.x() + status.w() + 1, 0,
+    static_cast<uInt32>(_w), static_cast<uInt32>(_h)
+  };
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -733,11 +740,12 @@ Common::Rect DebuggerDialog::getStatusBounds() const
   // 30% of any space above 1030 pixels will be allocated to this area
   const Common::Rect& tia = getTiaBounds();
 
-  return Common::Rect(
+  return {
       tia.x() + tia.w() + 1,
       0,
-      tia.x() + tia.w() + 225 + (_w > 1030 ? int(0.35 * (_w - 1030)) : 0),
-      tia.y() + tia.h());
+      tia.x() + tia.w() + 225 + (_w > 1030 ? static_cast<int>(0.35 * (_w - 1030)) : 0),
+      tia.y() + tia.h()
+  };
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -747,6 +755,8 @@ Common::Rect DebuggerDialog::getTabBounds() const
   const Common::Rect& tia    = getTiaBounds();
   const Common::Rect& status = getStatusBounds();
 
-  return Common::Rect(0, tia.y() + tia.h() + 1,
-                      status.x() + status.w() + 1, _h);
+  return {
+    0, tia.y() + tia.h() + 1,
+    status.x() + status.w() + 1, static_cast<uInt32>(_h)
+  };
 }
