@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -21,7 +21,6 @@
 #include "InputTextDialog.hxx"
 #include "OSystem.hxx"
 #include "Debugger.hxx"
-#include "CartDebug.hxx"
 #include "Font.hxx"
 #include "FBSurface.hxx"
 #include "Widget.hxx"
@@ -31,7 +30,7 @@
 RamWidget::RamWidget(GuiObject* boss, const GUI::Font& lfont, const GUI::Font& nfont,
                      int x, int y, int w, int h,
                      uInt32 ramsize, uInt32 numrows, uInt32 pagesize,
-                     const string& helpAnchor)
+                     string_view helpAnchor)
   : Widget(boss, lfont, x, y, w, h),
     CommandSender(boss),
     _nfont{nfont},
@@ -121,7 +120,7 @@ RamWidget::RamWidget(GuiObject* boss, const GUI::Font& lfont, const GUI::Font& n
                          TextAlign::Left);
   }
 
-  uInt32 row;
+  uInt32 row{0};
   for(row = 0; row < myNumRows; ++row)
   {
     myRamLabels[row] =
@@ -177,8 +176,12 @@ RamWidget::RamWidget(GuiObject* boss, const GUI::Font& lfont, const GUI::Font& n
   myLabel->setEditable(false, true);
 
   // Inputbox which will pop up when searching RAM
-  StringList labels = { "Value" };
+  const StringList labels = { "Value" };
   myInputBox = make_unique<InputTextDialog>(boss, lfont, nfont, labels, " ");
+  myInputBox->setTextFilter([](char c) {
+      return (c >= 'a' && c <= 'f') || (c >= '0' && c <= '9');
+    }
+  );
   myInputBox->setTarget(this);
 
   // Start with these buttons disabled
@@ -190,7 +193,7 @@ RamWidget::RamWidget(GuiObject* boss, const GUI::Font& lfont, const GUI::Font& n
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-RamWidget::~RamWidget()
+RamWidget::~RamWidget()  // NOLINT (we need an empty d'tor)
 {
 }
 
@@ -288,7 +291,7 @@ void RamWidget::handleCommand(CommandSender* sender, int cmd, int data, int id)
     case kSValEntered:
     {
       const string& result = doSearch(myInputBox->getResult());
-      if(result != "")
+      if(!result.empty())
         myInputBox->setMessage(result);
       else
         myInputBox->close();
@@ -298,7 +301,7 @@ void RamWidget::handleCommand(CommandSender* sender, int cmd, int data, int id)
     case kCValEntered:
     {
       const string& result = doCompare(myInputBox->getResult());
-      if(result != "")
+      if(!result.empty())
         myInputBox->setMessage(result);
       else
         myInputBox->close();
@@ -389,11 +392,11 @@ void RamWidget::showInputBox(int cmd)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-string RamWidget::doSearch(const string& str)
+string RamWidget::doSearch(string_view str)
 {
   bool comparisonSearch = true;
 
-  if(str.length() == 0)
+  if(str.empty())
   {
     // An empty field means return all memory locations
     comparisonSearch = false;
@@ -446,12 +449,12 @@ string RamWidget::doSearch(const string& str)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-string RamWidget::doCompare(const string& str)
+string RamWidget::doCompare(string_view str)
 {
   bool comparativeSearch = false;
   int searchVal = 0, offset = 0;
 
-  if(str.length() == 0)
+  if(str.empty())
     return "Enter an absolute or comparative value";
 
   // Do some pre-processing on the string
@@ -471,7 +474,7 @@ string RamWidget::doCompare(const string& str)
     if(str[0] == '-')
       negative = true;
 
-    string tmp = str;
+    string tmp{str};
     tmp.erase(0, 1);  // remove the operator
     offset = instance().debugger().stringToValue(tmp);
     if(negative)
@@ -543,7 +546,7 @@ void RamWidget::showSearchResults()
   // Only update the search results for the bank currently being shown
   BoolArray temp;
   const uInt32 start = myCurrentRamBank * myPageSize;
-  if(mySearchState.size() == 0 || start > mySearchState.size())
+  if(mySearchState.empty() || start > mySearchState.size())
   {
     for(uInt32 i = 0; i < myPageSize; ++i)
       temp.push_back(false);
