@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -36,21 +36,28 @@ RomListSettings::RomListSettings(GuiObject* boss, const GUI::Font& font)
   WidgetArray wid;
 
   // Set PC to current line
-  ButtonWidget* setPC =
+  auto* setPC =
     new ButtonWidget(this, font, xpos, ypos, buttonWidth, buttonHeight,
                      "Set PC @ current line", RomListWidget::kSetPCCmd);
   wid.push_back(setPC);
 
   // RunTo PC on current line
   ypos += buttonHeight + 4;
-  ButtonWidget* runtoPC =
+  auto* runtoPC =
     new ButtonWidget(this, font, xpos, ypos, buttonWidth, buttonHeight,
                      "RunTo PC @ current line", RomListWidget::kRuntoPCCmd);
   wid.push_back(runtoPC);
 
+  // Toggle timer
+  ypos += buttonHeight + 4;
+  auto* setTimer =
+    new ButtonWidget(this, font, xpos, ypos, buttonWidth, buttonHeight,
+      "Set timer @ current line", RomListWidget::kSetTimerCmd);
+  wid.push_back(setTimer);
+
   // Re-disassemble
   ypos += buttonHeight + 4;
-  ButtonWidget* disasm =
+  auto* disasm =
     new ButtonWidget(this, font, xpos, ypos, buttonWidth, buttonHeight,
                      "Disassemble @ current line", RomListWidget::kDisassembleCmd);
   wid.push_back(disasm);
@@ -150,10 +157,7 @@ void RomListSettings::handleCommand(CommandSender* sender, int cmd, int data, in
   {
     case RomListWidget::kSetPCCmd:
     case RomListWidget::kRuntoPCCmd:
-    {
-      sendCommand(cmd, _item, -1);
-      break;
-    }
+    case RomListWidget::kSetTimerCmd:
     case RomListWidget::kDisassembleCmd:
     {
       sendCommand(cmd, _item, -1);
