@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -33,7 +33,8 @@
 RomListWidget::RomListWidget(GuiObject* boss, const GUI::Font& lfont,
                              const GUI::Font& nfont,
                              int x, int y, int w, int h)
-  : EditableWidget(boss, nfont, x, y, 16, 16)
+  : EditableWidget(boss, nfont, x, y, 16, 16),
+    _rows{h / _lineHeight}
 {
   _flags = Widget::FLAG_ENABLED | Widget::FLAG_CLEARBG | Widget::FLAG_RETAIN_FOCUS;
   _bgcolor = kWidColor;
@@ -44,14 +45,12 @@ RomListWidget::RomListWidget(GuiObject* boss, const GUI::Font& lfont,
   _editMode = false;
   _dyText = -1; // fixes the vertical position of selected text
 
-  _cols = w / _fontWidth;
-  _rows = h / _lineHeight;
-
   // Set real dimensions
   _w = w - ScrollBarWidget::scrollBarWidth(_font);
   _h = h + 2;
 
   // Create scrollbar and attach to the list
+  // NOLINTNEXTLINE: we want to initialize here, not in the member list
   myScrollBar = new ScrollBarWidget(boss, lfont, _x + _w, _y,
                                     ScrollBarWidget::scrollBarWidth(_font), _h);
   myScrollBar->setTarget(this);
@@ -63,7 +62,7 @@ RomListWidget::RomListWidget(GuiObject* boss, const GUI::Font& lfont,
   const int fontWidth = lfont.getMaxCharWidth(),
             numchars = w / fontWidth;
 
-  _labelWidth = std::max(14, int(0.45 * (numchars - 8 - 8 - 9 - 2))) * fontWidth - 1;
+  _labelWidth = std::max(14, static_cast<int>(0.45 * (numchars - 8 - 8 - 9 - 2))) * fontWidth - 1;
   _bytesWidth = 9 * fontWidth;
 
   ///////////////////////////////////////////////////////
@@ -73,12 +72,12 @@ RomListWidget::RomListWidget(GuiObject* boss, const GUI::Font& lfont,
   // rowheight is determined by largest item on a line,
   // possibly meaning that number of rows will change
   _lineHeight = std::max(_lineHeight, CheckboxWidget::boxSize(_font));
-  _rows = h / _lineHeight;
+  _rows = h / _lineHeight;  // NOLINT: must be initialized after _lineHeight
 
   // Create a CheckboxWidget for each row in the list
   for(int i = 0; i < _rows; ++i)
   {
-    CheckboxWidget* t = new CheckboxWidget(boss, lfont, _x + 2, ypos, "",
+    auto* t = new CheckboxWidget(boss, lfont, _x + 2, ypos, "",
         CheckboxWidget::kCheckActionCmd);
     t->setTarget(this);
     t->setID(i);
@@ -90,7 +89,7 @@ RomListWidget::RomListWidget(GuiObject* boss, const GUI::Font& lfont,
   }
 
   // Add filtering
-  EditableWidget::TextFilter f = [&](char c)
+  const EditableWidget::TextFilter f = [&](char c)
   {
     switch(_base)
     {
@@ -109,7 +108,7 @@ RomListWidget::RomListWidget(GuiObject* boss, const GUI::Font& lfont,
       case Common::Base::Fmt::_10:
         return (c >= '0' && c <= '9') || c == ' ';
 
-      case Common::Base::Fmt::_DEFAULT:
+      case Common::Base::Fmt::DEFAULT:
       default:  // TODO - properly handle all other cases
         return false;
     }
@@ -254,8 +253,7 @@ void RomListWidget::handleMouseDown(int x, int y, MouseButton b, int clickCount)
   else
   {
     // First check whether the selection changed
-    int newSelectedItem;
-    newSelectedItem = findItem(x, y);
+    int newSelectedItem = findItem(x, y);
     if (newSelectedItem > static_cast<int>(myDisasm->list.size()) - 1)
       newSelectedItem = -1;
 
@@ -490,7 +488,7 @@ string RomListWidget::getToolTip(const Common::Point& pos) const
 
     if(idx.x < 2 || bytes.length() < 8)
       // 1 or 2 hex bytes, get one hex byte
-      valStr = bytes.substr((idx.x / 3) * 3, 2);
+      valStr = bytes.substr((static_cast<size_t>(idx.x) / 3) * 3, 2);
     else
       // 3 hex bytes, get two rightmost hex bytes
       valStr = bytes.substr(6, 2) + bytes.substr(3, 2);
@@ -632,20 +630,25 @@ void RomListWidget::drawWidget(bool hilite)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Common::Rect RomListWidget::getLineRect() const
 {
-  const int yoffset = std::max(0, (_selectedItem - _currentPos) * _lineHeight),
-            xoffset = CheckboxWidget::boxSize(_font) + 10;
+  const uInt32
+      yoffset = std::max(0, (_selectedItem - _currentPos) * _lineHeight),
+      xoffset = CheckboxWidget::boxSize(_font) + 10;
 
-  return Common::Rect(2 + xoffset, 1 + yoffset,
-                      _w - (xoffset - 15), _lineHeight + yoffset);
+  return {
+    2 + xoffset, 1 + yoffset,
+    _w - (xoffset - 15), _lineHeight + yoffset
+  };
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Common::Rect RomListWidget::getEditRect() const
 {
-  const int yoffset = std::max(0, (_selectedItem - _currentPos) * _lineHeight);
+  const uInt32 yoffset = std::max(0, (_selectedItem - _currentPos) * _lineHeight);
 
-  return Common::Rect(2 + _w - _bytesWidth, 1 + yoffset + 1,
-                      _w, _lineHeight + yoffset + 1);
+  return {
+    static_cast<uInt32>(2 + _w - _bytesWidth), 1 + yoffset + 1,
+    static_cast<uInt32>(_w), _lineHeight + yoffset + 1
+  };
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -654,7 +657,7 @@ void RomListWidget::startEditMode()
   if (isEditable() && !_editMode && _selectedItem >= 0)
   {
     // Does this line represent an editable area?
-    if(myDisasm->list[_selectedItem].bytes == "")
+    if(myDisasm->list[_selectedItem].bytes.empty())
       return;
 
     _editMode = true;
