@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -25,8 +25,6 @@
 #include "Font.hxx"
 #include "DataGridWidget.hxx"
 #include "EditTextWidget.hxx"
-#include "PopUpWidget.hxx"
-#include "ContextMenu.hxx"
 #include "RomListWidget.hxx"
 #include "RomWidget.hxx"
 
@@ -36,11 +34,9 @@ RomWidget::RomWidget(GuiObject* boss, const GUI::Font& lfont, const GUI::Font& n
   : Widget(boss, lfont, x, y, w, h),
     CommandSender(boss)
 {
-  WidgetArray wid;
-
   // Show current bank state
   int xpos = x, ypos = y + 7;
-  StaticTextWidget* t = new StaticTextWidget(boss, lfont, xpos, ypos, "Info ");
+  auto* t = new StaticTextWidget(boss, lfont, xpos, ypos, "Info ");
 
   xpos += t->getRight();
   myBank = new EditTextWidget(boss, nfont, xpos, ypos-2,
@@ -60,8 +56,8 @@ void RomWidget::loadConfig()
 {
   const Debugger& dbg = instance().debugger();
   CartDebug& cart = dbg.cartDebug();
-  const CartState& state = static_cast<const CartState&>(cart.getState());
-  const CartState& oldstate = static_cast<const CartState&>(cart.getOldState());
+  const auto& state = static_cast<const CartState&>(cart.getState());
+  const auto& oldstate = static_cast<const CartState&>(cart.getOldState());
 
   // Fill romlist the current bank of source or disassembly
   myListIsDirty |= cart.disassemblePC(myListIsDirty);
@@ -94,7 +90,7 @@ void RomWidget::handleCommand(CommandSender* sender, int cmd, int data, int id)
     case RomListWidget::kRomChangedCmd:
       // 'data' is the line in the disassemblylist to be accessed
       // 'id' is the base to use for the data to be changed
-      patchROM(data, myRomList->getText(), Common::Base::Fmt{id});
+      patchROM(data, myRomList->getText(), Common::Base::Fmt(id));
       break;
 
     case RomListWidget::kSetPCCmd:
@@ -107,6 +103,11 @@ void RomWidget::handleCommand(CommandSender* sender, int cmd, int data, int id)
       runtoPC(data);
       break;
 
+    case RomListWidget::kSetTimerCmd:
+      // 'data' is the line in the disassemblylist to be accessed
+      setTimer(data);
+      break;
+
     case RomListWidget::kDisassembleCmd:
       // 'data' is the line in the disassemblylist to be accessed
       disassemble(data);
@@ -165,7 +166,7 @@ void RomWidget::toggleBreak(int disasm_line)
 
   if (address != 0)
   {
-    Debugger& debugger = instance().debugger();
+    const Debugger& debugger = instance().debugger();
 
     debugger.toggleBreakPoint(address, debugger.cartDebug().getBank(address));
   }
@@ -180,7 +181,7 @@ void RomWidget::setPC(int disasm_line)
   {
     ostringstream command;
     command << "pc #" << address;
-    instance().debugger().run(command.str());
+    instance().debugger().run(command.view());
   }
 }
 
@@ -193,7 +194,21 @@ void RomWidget::runtoPC(int disasm_line)
   {
     ostringstream command;
     command << "runtopc #" << address;
-    const string& msg = instance().debugger().run(command.str());
+    const string& msg = instance().debugger().run(command.view());
+    instance().frameBuffer().showTextMessage(msg);
+  }
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void RomWidget::setTimer(int disasm_line)
+{
+  const uInt16 address = getAddress(disasm_line);
+
+  if(address != 0)
+  {
+    ostringstream command;
+    command << "timer #" << address << " " << instance().debugger().cartDebug().getBank(address);
+    const string& msg = instance().debugger().run(command.view());
     instance().frameBuffer().showTextMessage(msg);
   }
 }
@@ -214,7 +229,7 @@ void RomWidget::disassemble(int disasm_line)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void RomWidget::patchROM(int disasm_line, const string& bytes,
+void RomWidget::patchROM(int disasm_line, string_view bytes,
                          Common::Base::Fmt base)
 {
   const uInt16 address = getAddress(disasm_line);
@@ -229,7 +244,7 @@ void RomWidget::patchROM(int disasm_line, const string& bytes,
 
     Common::Base::setFormat(base);
     command << "rom #" << address << " " << bytes;
-    instance().debugger().run(command.str());
+    instance().debugger().run(command.view());
 
     // Restore previous base
     Common::Base::setFormat(oldbase);
