@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -29,15 +29,13 @@ SaveKeyWidget::SaveKeyWidget(GuiObject* boss, const GUI::Font& font,
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void SaveKeyWidget::eraseCurrent()
 {
-  SaveKey& skey = static_cast<SaveKey&>(controller());
-
+  auto& skey = static_cast<SaveKey&>(controller());
   skey.eraseCurrent();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool SaveKeyWidget::isPageUsed(uInt32 page)
 {
-  const SaveKey& skey = static_cast<SaveKey&>(controller());
-
+  const auto& skey = static_cast<SaveKey&>(controller());
   return skey.isPageUsed(page);
 }
