@@ -8,17 +8,15 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //============================================================================
 
-#include "OSystem.hxx"
 #include "Widget.hxx"
 #include "Dialog.hxx"
-#include "Debugger.hxx"
 #include "FBSurface.hxx"
 #include "Font.hxx"
 #include "ToggleBitWidget.hxx"
@@ -38,8 +36,8 @@ ToggleBitWidget::ToggleBitWidget(GuiObject* boss, const GUI::Font& font,
   int size = _rows * _cols;
   while(size--)
   {
-    _offList.push_back("0");
-    _onList.push_back("1");
+    _offList.emplace_back("0");
+    _onList.emplace_back("1");
     _stateList.push_back(false);
     _changedList.push_back(false);
   }
