@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -16,15 +16,14 @@
 //============================================================================
 
 #include "System.hxx"
-#include "TIA.hxx"
 #include "Cart3EPlus.hxx"
 
 //  - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Cartridge3EPlus::Cartridge3EPlus(const ByteBuffer& image, size_t size,
-                                 const string& md5, const Settings& settings,
+                                 string_view md5, const Settings& settings,
                                  size_t bsSize)
   : Cartridge3E(image, size, md5, settings,
-                bsSize == 0 ? BSPF::nextMultipleOf(size, 1_KB) : bsSize)
+                bsSize == 0 ? std::max(4_KB, BSPF::nextMultipleOf(size, 1_KB)) : bsSize)
 {
   myBankShift = BANK_SHIFT;
   myRamSize = RAM_SIZE;
@@ -47,13 +46,13 @@ bool Cartridge3EPlus::checkSwitchBank(uInt16 address, uInt8 value)
 {
   // Switch banks if necessary
   if(address == 0x003F) {
-    // Switch ROM bank into segment 0
+    // Switch ROM bank into segment
     bank(value & 0b111111, value >> 6);
     return true;
   }
   else if(address == 0x003E)
   {
-    // Switch RAM bank into segment 0
+    // Switch RAM bank into segment
     bank((value & 0b111111) + romBankCount(), value >> 6);
     return true;
   }
