@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -20,7 +20,7 @@
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 CartridgeFA::CartridgeFA(const ByteBuffer& image, size_t size,
-                         const string& md5, const Settings& settings,
+                         string_view md5, const Settings& settings,
                          size_t bsSize)
   : CartridgeEnhanced(image, size, md5, settings, bsSize)
 {
@@ -31,8 +31,10 @@ CartridgeFA::CartridgeFA(const ByteBuffer& image, size_t size,
 bool CartridgeFA::checkSwitchBank(uInt16 address, uInt8)
 {
   // Switch banks if necessary
-  if((address >= 0x1FF8) && (address <= 0x1FFA))
+  if((address >= 0x1FF8) && (address <= 0x1FFA)/* && (mySystem->getDataBusState() & 1) */)
   {
+    //if((mySystem->getDataBusState() & 1) == 0)
+    //cerr << std::hex << address << ": " << (mySystem->getDataBusState() & 1) << ", ";
     bank(address - 0x1FF8);
     return true;
   }
