@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -20,18 +20,18 @@
 
 #include "Console.hxx"
 #include "EventHandler.hxx"
-#include "Event.hxx"
 #include "OSystem.hxx"
 #include "Settings.hxx"
 #include "TIA.hxx"
 #include "Sound.hxx"
 #include "AudioSettings.hxx"
 #include "MediaFactory.hxx"
+#include "PNGLibrary.hxx"
 
 #include "FBSurface.hxx"
 #include "TIASurface.hxx"
+#include "Bezel.hxx"
 #include "FrameBuffer.hxx"
-#include "PaletteHandler.hxx"
 #include "StateManager.hxx"
 #include "RewindManager.hxx"
 
@@ -49,7 +49,6 @@
   #include "Stella14x28tFont.hxx"
   #include "Stella16x32tFont.hxx"
   #include "ConsoleFont.hxx"
-  #include "ConsoleBFont.hxx"
   #include "Launcher.hxx"
   #include "OptionsMenu.hxx"
   #include "CommandMenu.hxx"
@@ -59,6 +58,8 @@
   #include "TimeMachine.hxx"
 #endif
 
+static constexpr int MESSAGE_TIME = 120; // display message for 2 seconds
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 FrameBuffer::FrameBuffer(OSystem& osystem)
   : myOSystem{osystem}
@@ -66,7 +67,7 @@ FrameBuffer::FrameBuffer(OSystem& osystem)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-FrameBuffer::~FrameBuffer()
+FrameBuffer::~FrameBuffer()  // NOLINT (we need an empty d'tor)
 {
 }
 
@@ -123,6 +124,8 @@ void FrameBuffer::initialize()
 
   // Create a TIA surface; we need it for rendering TIA images
   myTIASurface = make_unique<TIASurface>(myOSystem);
+  // Create a bezel surface for TIA overlays
+  myBezel = make_unique<Bezel>(myOSystem);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -170,10 +173,12 @@ void FrameBuffer::setupFonts()
   else
   {
     constexpr int NUM_FONTS = 7;
-    FontDesc FONT_DESC[NUM_FONTS] = {GUI::consoleDesc, GUI::consoleMediumDesc, GUI::stellaMediumDesc,
-      GUI::stellaLargeDesc, GUI::stella12x24tDesc, GUI::stella14x28tDesc, GUI::stella16x32tDesc};
-    const string& dialogFont = myOSystem.settings().getString("dialogfont");
-    FontDesc fd = getFontDesc(dialogFont);
+    const FontDesc FONT_DESC[NUM_FONTS] = {
+      GUI::consoleDesc, GUI::consoleMediumDesc, GUI::stellaMediumDesc,
+      GUI::stellaLargeDesc, GUI::stella12x24tDesc, GUI::stella14x28tDesc,
+      GUI::stella16x32tDesc};
+    const string_view dialogFont = myOSystem.settings().getString("dialogfont");
+    const FontDesc fd = getFontDesc(dialogFont);
 
     // The general font used in all UI elements
     myFont = make_unique<GUI::Font>(fd);                                //  default: 9x18
@@ -196,17 +201,17 @@ void FrameBuffer::setupFonts()
     const int zoom_h = (fd.height * 4 * 2) / GUI::stellaMediumDesc.height;
     const int zoom_w = (fd.maxwidth * 4 * 2) / GUI::stellaMediumDesc.maxwidth;
     // round to 25% steps, >= 200%
-    myTIAMinZoom = std::max(std::max(zoom_w, zoom_h) / 4.F, 2.F);
+    myTIAMinZoom = std::max(std::max(zoom_w, zoom_h) / 4., 2.);
   }
 
   // The font used by the ROM launcher
-  const string& lf = myOSystem.settings().getString("launcherfont");
+  const string_view lf = myOSystem.settings().getString("launcherfont");
 
   myLauncherFont = make_unique<GUI::Font>(getFontDesc(lf));       //  8x13
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-FontDesc FrameBuffer::getFontDesc(const string& name) const
+FontDesc FrameBuffer::getFontDesc(string_view name)
 {
   if(name == "small")
     return GUI::consoleDesc;        //  8x13
@@ -226,7 +231,7 @@ FontDesc FrameBuffer::getFontDesc(const string& name) const
 #endif
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-FBInitStatus FrameBuffer::createDisplay(const string& title, BufferType type,
+FBInitStatus FrameBuffer::createDisplay(string_view title, BufferType type,
                                         Common::Size size, bool honourHiDPI)
 {
   ++myInitializedCount;
@@ -273,10 +278,13 @@ FBInitStatus FrameBuffer::createDisplay(const string& title, BufferType type,
 
   if(myBufferType == BufferType::Emulator)
   {
+    myBezel->load(); // make sure we have the correct bezel size
+
     // Determine possible TIA windowed zoom levels
-    float currentTIAZoom = myOSystem.settings().getFloat("tia.zoom");
+    const auto currentTIAZoom =
+      static_cast<double>(myOSystem.settings().getFloat("tia.zoom"));
     myOSystem.settings().setValue("tia.zoom",
-                                  BSPF::clampw(currentTIAZoom, supportedTIAMinZoom(), supportedTIAMaxZoom()));
+      BSPF::clamp(currentTIAZoom, supportedTIAMinZoom(), supportedTIAMaxZoom()));
   }
 
 #ifdef GUI_SUPPORT  // TODO: put message stuff in its own class
@@ -311,7 +319,7 @@ FBInitStatus FrameBuffer::createDisplay(const string& title, BufferType type,
   myVidModeHandler.setImageSize(size);
 
   // Initialize video subsystem
-  string pre_about = myBackend->about();
+  const string pre_about = myBackend->about();
   const FBInitStatus status = applyVideoMode();
 
   // Only set phosphor once when ROM is started
@@ -320,16 +328,29 @@ FBInitStatus FrameBuffer::createDisplay(const string& title, BufferType type,
     // Phosphor mode can be enabled either globally or per-ROM
     int p_blend = 0;
     bool enable = false;
+    const int phosphorMode = PhosphorHandler::toPhosphorMode(
+      myOSystem.settings().getString(PhosphorHandler::SETTING_MODE));
 
-    if(myOSystem.settings().getString("tv.phosphor") == "always")
+    switch(phosphorMode)
     {
-      p_blend = myOSystem.settings().getInt("tv.phosblend");
-      enable = true;
-    }
-    else
-    {
-      p_blend = BSPF::stringToInt(myOSystem.console().properties().get(PropType::Display_PPBlend));
-      enable = myOSystem.console().properties().get(PropType::Display_Phosphor) == "YES";
+      case PhosphorHandler::Always:
+        enable = true;
+        p_blend = myOSystem.settings().getInt(PhosphorHandler::SETTING_BLEND);
+        myOSystem.console().tia().enableAutoPhosphor(false);
+        break;
+
+      case PhosphorHandler::Auto_on:
+      case PhosphorHandler::Auto:
+        enable = false;
+        p_blend = myOSystem.settings().getInt(PhosphorHandler::SETTING_BLEND);
+        myOSystem.console().tia().enableAutoPhosphor(true, phosphorMode == PhosphorHandler::Auto_on);
+        break;
+
+      default: // PhosphorHandler::ByRom
+        enable = myOSystem.console().properties().get(PropType::Display_Phosphor) == "YES";
+        p_blend = BSPF::stoi(myOSystem.console().properties().get(PropType::Display_PPBlend));
+        myOSystem.console().tia().enableAutoPhosphor(false);
+        break;
     }
     myTIASurface->enablePhosphor(enable, p_blend);
   }
@@ -344,7 +365,7 @@ FBInitStatus FrameBuffer::createDisplay(const string& title, BufferType type,
   }
   else
   {
-    string post_about = myBackend->about();
+    const string post_about = myBackend->about();
     if(post_about != pre_about)
       Logger::info(post_about);
   }
@@ -383,16 +404,16 @@ void FrameBuffer::update(UpdateMode mode)
     case EventHandlerState::PAUSE:
     {
       // Show a pause message immediately and then every 7 seconds
-      bool shade = myOSystem.settings().getBool("pausedim");
+      const bool shade = myOSystem.settings().getBool("pausedim");
 
-      if(myPausedCount-- <= 0)
+      if(myMsg.counter < MESSAGE_TIME && myPausedCount-- <= 0)
       {
         myPausedCount = static_cast<uInt32>(7 * myOSystem.frameRate());
         showTextMessage("Paused", MessagePosition::MiddleCenter);
-        myTIASurface->render(shade);
+        renderTIA(false, shade);
       }
       if(rerender)
-        myTIASurface->render(shade);
+        renderTIA(false, shade);
       break;  // EventHandlerState::PAUSE
     }
 
@@ -403,14 +424,12 @@ void FrameBuffer::update(UpdateMode mode)
       redraw |= myOSystem.optionsMenu().needsRedraw();
       if(redraw)
       {
-        clear();
-        myTIASurface->render(true);
+        renderTIA(true, true);
         myOSystem.optionsMenu().draw(forceRedraw);
       }
       else if(rerender)
       {
-        clear();
-        myTIASurface->render(true);
+        renderTIA(true, true);
         myOSystem.optionsMenu().render();
       }
       break;  // EventHandlerState::OPTIONSMENU
@@ -422,14 +441,12 @@ void FrameBuffer::update(UpdateMode mode)
       redraw |= myOSystem.commandMenu().needsRedraw();
       if(redraw)
       {
-        clear();
-        myTIASurface->render(true);
+        renderTIA(true, true);
         myOSystem.commandMenu().draw(forceRedraw);
       }
       else if(rerender)
       {
-        clear();
-        myTIASurface->render(true);
+        renderTIA(true, true);
         myOSystem.commandMenu().render();
       }
       break;  // EventHandlerState::CMDMENU
@@ -441,14 +458,12 @@ void FrameBuffer::update(UpdateMode mode)
       redraw |= myOSystem.highscoresMenu().needsRedraw();
       if(redraw)
       {
-        clear();
-        myTIASurface->render(true);
+        renderTIA(true, true);
         myOSystem.highscoresMenu().draw(forceRedraw);
       }
       else if(rerender)
       {
-        clear();
-        myTIASurface->render(true);
+        renderTIA(true, true);
         myOSystem.highscoresMenu().render();
       }
       break;  // EventHandlerState::HIGHSCORESMENU
@@ -460,8 +475,7 @@ void FrameBuffer::update(UpdateMode mode)
       redraw |= myOSystem.messageMenu().needsRedraw();
       if(redraw)
       {
-        clear();
-        myTIASurface->render(true);
+        renderTIA(true, true);
         myOSystem.messageMenu().draw(forceRedraw);
       }
       break;  // EventHandlerState::MESSAGEMENU
@@ -473,8 +487,7 @@ void FrameBuffer::update(UpdateMode mode)
       redraw |= myOSystem.plusRomsMenu().needsRedraw();
       if(redraw)
       {
-        clear();
-        myTIASurface->render(true);
+        renderTIA(true, true);
         myOSystem.plusRomsMenu().draw(forceRedraw);
       }
       break;  // EventHandlerState::PLUSROMSMENU
@@ -486,14 +499,12 @@ void FrameBuffer::update(UpdateMode mode)
       redraw |= myOSystem.timeMachine().needsRedraw();
       if(redraw)
       {
-        clear();
-        myTIASurface->render();
+        renderTIA();
         myOSystem.timeMachine().draw(forceRedraw);
       }
       else if(rerender)
       {
-        clear();
-        myTIASurface->render();
+        renderTIA();
         myOSystem.timeMachine().render();
       }
       break;  // EventHandlerState::TIMEMACHINE
@@ -512,27 +523,27 @@ void FrameBuffer::update(UpdateMode mode)
         success = r.unwindStates(1);
 
         // Determine playback speed, the faster the more the states are apart
-        const Int64 frameCycles = 76 * std::max<Int32>(myOSystem.console().tia().scanlinesLastFrame(), 240);
+        const Int64 frameCycles = static_cast<Int64>(76) * std::max<Int32>(myOSystem.console().tia().scanlinesLastFrame(), 240);
         const Int64 intervalFrames = r.getInterval() / frameCycles;
         const Int64 stateFrames = (r.getCurrentCycles() - prevCycles) / frameCycles;
 
         //frames = intervalFrames + std::sqrt(std::max(stateFrames - intervalFrames, 0));
         frames = std::round(std::sqrt(stateFrames));
 
-        // Mute sound if saved states were removed or states are too far apart
-        myOSystem.sound().mute(stateFrames > intervalFrames ||
+        // Pause sound if saved states were removed or states are too far apart
+        myOSystem.sound().pause(stateFrames > intervalFrames ||
             frames > static_cast<Int32>(myOSystem.audioSettings().bufferSize() / 2 + 1));
       }
       redraw |= success;
       if(redraw)
-        myTIASurface->render();
+        renderTIA(false);
 
       // Stop playback mode at the end of the state buffer
       // and switch to Time Machine or Pause mode
       if(!success)
       {
         frames = 0;
-        myOSystem.sound().mute(true);
+        myOSystem.sound().pause(true);
         myOSystem.eventHandler().enterMenuMode(EventHandlerState::TIMEMACHINE);
       }
       break;  // EventHandlerState::PLAYBACK
@@ -587,8 +598,7 @@ void FrameBuffer::updateInEmulationMode(float framesPerSecond)
   // We don't worry about selective rendering here; the rendering
   // always happens at the full framerate
 
-  clear();  // TODO - test this: it may cause slowdowns on older systems
-  myTIASurface->render();
+  renderTIA();
 
   // Show frame statistics
   if(myStatsMsg.enabled)
@@ -607,7 +617,8 @@ void FrameBuffer::updateInEmulationMode(float framesPerSecond)
 
 #ifdef GUI_SUPPORT
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FrameBuffer::createMessage(const string& message, MessagePosition position, bool force)
+void FrameBuffer::createMessage(string_view message, MessagePosition position,
+                                bool force)
 {
   // Only show messages if they've been enabled
   if(myMsg.surface == nullptr || !(force || myOSystem.settings().getBool("uimessages")))
@@ -616,9 +627,10 @@ void FrameBuffer::createMessage(const string& message, MessagePosition position,
   const int fontHeight = font().getFontHeight();
   const int VBORDER = fontHeight / 4;
 
-  myMsg.counter = std::min(uInt32(myOSystem.frameRate()) * 2, 120u); // Show message for 2 seconds
+  // Show message for 2 seconds
+  myMsg.counter = std::min(static_cast<Int32>(myOSystem.frameRate()) * 2, MESSAGE_TIME);
   if(myMsg.counter == 0)
-    myMsg.counter = 120;
+    myMsg.counter = MESSAGE_TIME;
 
   // Precompute the message coordinates
   myMsg.text      = message;
@@ -634,8 +646,8 @@ void FrameBuffer::createMessage(const string& message, MessagePosition position,
 #endif
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FrameBuffer::showTextMessage(const string& message, MessagePosition position,
-                                  bool force)
+void FrameBuffer::showTextMessage(string_view message,
+                                  MessagePosition position, bool force)
 {
 #ifdef GUI_SUPPORT
   const int fontWidth = font().getMaxCharWidth();
@@ -650,7 +662,7 @@ void FrameBuffer::showTextMessage(const string& message, MessagePosition positio
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FrameBuffer::showGaugeMessage(const string& message, const string& valueText,
+void FrameBuffer::showGaugeMessage(string_view message, string_view valueText,
                                    float value, float minValue, float maxValue)
 {
 #ifdef GUI_SUPPORT
@@ -698,7 +710,7 @@ void FrameBuffer::drawFrameStats(float framesPerSecond)
   myStatsMsg.surface->invalidate();
 
   // draw scanlines
-  const ColorId color = myOSystem.console().tia().frameBufferScanlinesLastFrame() !=
+  ColorId color = myOSystem.console().tia().frameBufferScanlinesLastFrame() !=
     myLastScanlines ? kDbgColorRed : myStatsMsg.color;
 
   ss
@@ -709,7 +721,7 @@ void FrameBuffer::drawFrameStats(float framesPerSecond)
     << "Hz => "
     << info.DisplayFormat;
 
-  myStatsMsg.surface->drawString(f, ss.str(), xPos, yPos,
+  myStatsMsg.surface->drawString(f, ss.view(), xPos, yPos,
                                  myStatsMsg.w, color, TextAlign::Left, 0, true, kBGColor);
 
   yPos += dy;
@@ -720,23 +732,40 @@ void FrameBuffer::drawFrameStats(float framesPerSecond)
     << "fps @ "
     << std::fixed << std::setprecision(0) << 100 *
       (myOSystem.settings().getBool("turbo")
-        ? 20.0F
+        ? 50.0F
         : myOSystem.settings().getFloat("speed"))
     << "% speed";
 
-  myStatsMsg.surface->drawString(f, ss.str(), xPos, yPos,
+  myStatsMsg.surface->drawString(f, ss.view(), xPos, yPos,
       myStatsMsg.w, myStatsMsg.color, TextAlign::Left, 0, true, kBGColor);
 
   yPos += dy;
   ss.str("");
 
   ss << info.BankSwitch;
-  if (myOSystem.settings().getBool("dev.settings")) ss << "| Developer";
+  int xPosEnd =
+    myStatsMsg.surface->drawString(f, ss.view(), xPos, yPos,
+                                   myStatsMsg.w, myStatsMsg.color, TextAlign::Left, 0, true, kBGColor);
 
-  myStatsMsg.surface->drawString(f, ss.str(), xPos, yPos,
-      myStatsMsg.w, myStatsMsg.color, TextAlign::Left, 0, true, kBGColor);
+  if(myOSystem.settings().getBool("dev.settings"))
+  {
+    xPosEnd = myStatsMsg.surface->drawString(f, "| ", xPosEnd, yPos,
+                                  myStatsMsg.w, color, TextAlign::Left, 0, true, kBGColor);
+    ss.str("");
+    color = myStatsMsg.color;
+    if(myOSystem.console().vsyncCorrect())
+      ss << "Developer";
+    else
+    {
+      color = kDbgColorRed;
+      ss << "VSYNC!";
+    }
+    myStatsMsg.surface->drawString(f, ss.view(), xPosEnd, yPos,
+        myStatsMsg.w, color, TextAlign::Left, 0, true, kBGColor);
+  }
 
-  myStatsMsg.surface->setDstPos(imageRect().x() + 10, imageRect().y() + 8);
+  myStatsMsg.surface->setDstPos(imageRect().x() + imageRect().w() / 64,
+                                imageRect().y() + imageRect().h() / 64);
   myStatsMsg.surface->setDstSize(myStatsMsg.w * hidpiScaleFactor(),
                                  myStatsMsg.h * hidpiScaleFactor());
   myStatsMsg.surface->render();
@@ -804,13 +833,13 @@ inline bool FrameBuffer::drawMessage()
   {
   #ifdef DEBUG_BUILD
     cerr << "m";
-    //cerr << "--- draw message ---" << endl;
+    //cerr << "--- draw message ---\n";
   #endif
 
     // Draw the bounded box and text
     const Common::Rect& dst = myMsg.surface->dstRect();
     const int fontWidth = font().getMaxCharWidth(),
-      fontHeight = font().getFontHeight();
+              fontHeight = font().getFontHeight();
     const int VBORDER = fontHeight / 4;
     const int HBORDER = fontWidth * 1.25 / 2.0;
     constexpr int BORDER = 1;
@@ -861,6 +890,9 @@ inline bool FrameBuffer::drawMessage()
         myMsg.x = imageRect().w() - dst.w() - 5;
         myMsg.y = imageRect().h() - dst.h() - 5;
         break;
+
+      default:
+        break;  // Not supposed to get here
     }
 
     myMsg.surface->setDstPos(myMsg.x + imageRect().x(), myMsg.y + imageRect().y());
@@ -925,7 +957,7 @@ shared_ptr<FBSurface> FrameBuffer::allocateSurface(
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FrameBuffer::deallocateSurface(shared_ptr<FBSurface> surface)
+void FrameBuffer::deallocateSurface(const shared_ptr<FBSurface>& surface)
 {
   if(surface)
     mySurfaceList.remove(surface);
@@ -940,6 +972,17 @@ void FrameBuffer::resetSurfaces()
   update(UpdateMode::REDRAW); // force full update
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void FrameBuffer::renderTIA(bool doClear, bool shade)
+{
+  if(doClear)
+    clear();  // TODO - test this: it may cause slowdowns on older systems
+
+  myTIASurface->render(shade);
+  if(myBezel)
+    myBezel->render();
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FrameBuffer::setTIAPalette(const PaletteArray& rgb_palette)
 {
@@ -967,11 +1010,13 @@ void FrameBuffer::setTIAPalette(const PaletteArray& rgb_palette)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FrameBuffer::setUIPalette()
 {
+  const Settings& settings = myOSystem.settings();
+  const string& key = settings.getBool("altuipalette") ? "uipalette2" : "uipalette";
   // Set palette for UI (upper area of full palette)
   const UIPaletteArray& ui_palette =
-     (myOSystem.settings().getString("uipalette") == "classic") ? ourClassicUIPalette :
-     (myOSystem.settings().getString("uipalette") == "light")   ? ourLightUIPalette :
-     (myOSystem.settings().getString("uipalette") == "dark")    ? ourDarkUIPalette :
+     (settings.getString(key) == "classic") ? ourClassicUIPalette :
+     (settings.getString(key) == "light")   ? ourLightUIPalette :
+     (settings.getString(key) == "dark")    ? ourDarkUIPalette :
       ourStandardUIPalette;
 
   for(size_t i = 0, j = myFullPalette.size() - ui_palette.size();
@@ -989,9 +1034,12 @@ void FrameBuffer::setUIPalette()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FrameBuffer::stateChanged(EventHandlerState state)
 {
-  // Make sure any onscreen messages are removed
-  hideMessage();
-
+  // Prevent removing state change messages
+  if(myMsg.counter < MESSAGE_TIME - 1)
+  {
+    // Make sure any onscreen messages are removed
+    hideMessage();
+  }
   update(); // update immediately
 }
 
@@ -1117,7 +1165,7 @@ void FrameBuffer::toggleFullscreen(bool toggle)
             msg << "enabled (" << myBackend->refreshRate() << " Hz, ";
           else
             msg << "disabled (";
-          msg << "Zoom " << myActiveVidMode.zoom * 100 << "%)";
+          msg << "Zoom " << round(myActiveVidMode.zoom * 100) << "%)";
         }
         else
         {
@@ -1126,7 +1174,7 @@ void FrameBuffer::toggleFullscreen(bool toggle)
           else
             msg << "disabled";
         }
-        showTextMessage(msg.str());
+        showTextMessage(msg.view());
       }
       break;
     }
@@ -1159,7 +1207,7 @@ void FrameBuffer::toggleAdaptRefresh(bool toggle)
     msg << (isAdaptRefresh ? "enabled" : "disabled");
     msg << " (" << myBackend->refreshRate() << " Hz)";
 
-    showTextMessage(msg.str());
+    showTextMessage(msg.view());
   }
 }
 #endif
@@ -1185,7 +1233,7 @@ void FrameBuffer::changeOverscan(int direction)
       val << (overscan > 0 ? "+" : "" ) << overscan << "%";
     else
       val << "Off";
-    myOSystem.frameBuffer().showGaugeMessage("Overscan", val.str(), overscan, 0, 10);
+    myOSystem.frameBuffer().showGaugeMessage("Overscan", val.view(), overscan, 0, 10);
   }
 }
 
@@ -1199,7 +1247,7 @@ void FrameBuffer::switchVideoMode(int direction)
   if(!fullScreen())
   {
     // Windowed TIA modes support variable zoom levels
-    float zoom = myOSystem.settings().getFloat("tia.zoom");
+    auto zoom = static_cast<double>(myOSystem.settings().getFloat("tia.zoom"));
     if(direction == +1)       zoom += ZOOM_STEPS;
     else if(direction == -1)  zoom -= ZOOM_STEPS;
 
@@ -1213,7 +1261,7 @@ void FrameBuffer::switchVideoMode(int direction)
     // is irrelevant
     if(direction == +1 || direction == -1)
     {
-      bool stretch = myOSystem.settings().getBool("tia.fs_stretch");
+      const bool stretch = myOSystem.settings().getBool("tia.fs_stretch");
       myOSystem.settings().setValue("tia.fs_stretch", !stretch);
     }
   }
@@ -1229,6 +1277,43 @@ void FrameBuffer::switchVideoMode(int direction)
   }
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void FrameBuffer::toggleBezel(bool toggle)
+{
+  bool enabled = myOSystem.settings().getBool("bezel.show");
+
+  if(toggle && myBufferType == BufferType::Emulator)
+  {
+    if(!fullScreen() && !myOSystem.settings().getBool("bezel.windowed"))
+    {
+      myOSystem.frameBuffer().showTextMessage("Bezels in windowed mode are not enabled");
+      return;
+    }
+    else
+    {
+      enabled = !enabled;
+      myOSystem.settings().setValue("bezel.show", enabled);
+      if(!myBezel->load() && enabled)
+      {
+        myOSystem.settings().setValue("bezel.show", !enabled);
+        return;
+      }
+      else
+      {
+        // Determine possible TIA windowed zoom levels
+        const auto currentTIAZoom =
+          static_cast<double>(myOSystem.settings().getFloat("tia.zoom"));
+        myOSystem.settings().setValue("tia.zoom",
+          BSPF::clamp(currentTIAZoom, supportedTIAMinZoom(), supportedTIAMaxZoom()));
+
+        saveCurrentWindowPosition();
+        applyVideoMode();
+      }
+    }
+  }
+  myOSystem.frameBuffer().showTextMessage(enabled ? "Bezel enabled" : "Bezel disabled");
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 FBInitStatus FrameBuffer::applyVideoMode()
 {
@@ -1243,15 +1328,21 @@ FBInitStatus FrameBuffer::applyVideoMode()
 
   const bool inTIAMode = myOSystem.eventHandler().inTIAMode();
 
+#ifdef IMAGE_SUPPORT
+  if(inTIAMode)
+    myBezel->load();
+#endif
+
   // Build the new mode based on current settings
-  const VideoModeHandler::Mode& mode = myVidModeHandler.buildMode(s, inTIAMode);
+  const VideoModeHandler::Mode& mode
+    = myVidModeHandler.buildMode(s, inTIAMode, myBezel->info());
   if(mode.imageR.size() > mode.screenS)
     return FBInitStatus::FailTooLarge;
 
   // Changing the video mode can take some time, during which the last
   // sound played may get 'stuck'
-  // So we mute the sound until the operation completes
-  const bool oldMuteState = myOSystem.sound().mute(true);
+  // So we pause the sound until the operation completes
+  const bool oldPauseState = myOSystem.sound().pause(true);
   FBInitStatus status = FBInitStatus::FailNotSupported;
 
   if(myBackend->setVideoMode(mode,
@@ -1274,6 +1365,8 @@ FBInitStatus FrameBuffer::applyVideoMode()
           myActiveVidMode.stretch == VideoModeHandler::Mode::Stretch::Fill);
       else
         myOSystem.settings().setValue("tia.zoom", myActiveVidMode.zoom);
+
+      myBezel->apply();
     }
 
     resetSurfaces();
@@ -1284,24 +1377,25 @@ FBInitStatus FrameBuffer::applyVideoMode()
     Logger::error("ERROR: Couldn't initialize video subsystem");
 
   // Restore sound settings
-  myOSystem.sound().mute(oldMuteState);
+  myOSystem.sound().pause(oldPauseState);
 
   return status;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-float FrameBuffer::maxWindowZoom() const
+double FrameBuffer::maxWindowZoom() const
 {
   const int display = displayId(BufferType::Emulator);
-  float multiplier = 1;
+  double multiplier = 1;
 
   for(;;)
   {
-    // Figure out the zoomed size of the window
-    const uInt32 width  = TIAConstants::viewableWidth * multiplier;
-    const uInt32 height = TIAConstants::viewableHeight * multiplier;
+    // Figure out the zoomed size of the window (incl. the bezel)
+    const uInt32 width  = static_cast<double>(TIAConstants::viewableWidth)  * myBezel->ratioW() * multiplier;
+    const uInt32 height = static_cast<double>(TIAConstants::viewableHeight) * myBezel->ratioH() * multiplier;
 
-    if((width > myAbsDesktopSize[display].w) || (height > myAbsDesktopSize[display].h))
+    if((width > myAbsDesktopSize[display].w) ||
+       (height > myAbsDesktopSize[display].h))
       break;
 
     multiplier += ZOOM_STEPS;
@@ -1365,7 +1459,7 @@ bool FrameBuffer::grabMouseAllowed()
   const bool alwaysUseMouse = BSPF::equalsIgnoreCase("always", myOSystem.settings().getString("usemouse"));
 
   // Disable grab while cursor is shown in emulation
-  bool cursorHidden = !(myOSystem.settings().getInt("cursor") & 1);
+  const bool cursorHidden = !(myOSystem.settings().getInt("cursor") & 1);
 
   return emulation && (analog || usesLightgun || alwaysUseMouse) && cursorHidden;
 }
@@ -1407,7 +1501,7 @@ void FrameBuffer::toggleGrabMouse(bool toggle)
     kBGColor          Normal background color (non-text)
     kBGColorLo        Disabled background color dark (non-text)
     kBGColorHi        Disabled background color light (non-text)
-    kShadowColor      Item is disabled
+    kShadowColor      Item is disabled (unused)
     *** Text colors ***
     kTextColor        Normal text color
     kTextColorHi      Highlighted text color
@@ -1495,6 +1589,6 @@ UIPaletteArray FrameBuffer::ourDarkUIPalette = {
     0x3c3c3c, 0x646464,                                         // scrollbar
     0x7f2020, 0xc0c0c0, 0xe00000, 0xc00000,                     // debugger
     0x989898, 0x0059a3, 0x3c3c3c, 0x000000, 0x3c3c3c,           // slider
-    0x000000, 0x989898, 0x202020                                // other
+    0x000000, 0x404040, 0xc0c0c0                                // other
   }
 };
