@@ -8,16 +8,13 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //============================================================================
 
-#include <cassert>
-#include <functional>
-
 #include "bspf.hxx"
 #include "Logger.hxx"
 
@@ -39,7 +36,6 @@
   #include "PlusRomsMenu.hxx"
   #include "Launcher.hxx"
   #include "TimeMachine.hxx"
-  #include "Widget.hxx"
 #endif
 
 #include "FSNode.hxx"
@@ -54,20 +50,19 @@
 #include "PropsSet.hxx"
 #include "EventHandler.hxx"
 #include "PNGLibrary.hxx"
+#include "JPGLibrary.hxx"
 #include "Console.hxx"
 #include "Random.hxx"
 #include "StateManager.hxx"
 #include "TimerManager.hxx"
 #ifdef GUI_SUPPORT
-#include "HighScoresManager.hxx"
+  #include "HighScoresManager.hxx"
 #endif
 #include "Version.hxx"
 #include "TIA.hxx"
 #include "DispatchResult.hxx"
 #include "EmulationWorker.hxx"
 #include "AudioSettings.hxx"
-#include "repository/KeyValueRepositoryNoop.hxx"
-#include "repository/CompositeKeyValueRepositoryNoop.hxx"
 #include "M6532.hxx"
 
 #include "OSystem.hxx"
@@ -90,8 +85,8 @@ OSystem::OSystem()
   #ifdef CHEATCODE_SUPPORT
     myFeatures += "Cheats ";
   #endif
-  #ifdef PNG_SUPPORT
-    myFeatures += "PNG ";
+  #ifdef IMAGE_SUPPORT
+    myFeatures += "Images ";
   #endif
   #ifdef ZIP_SUPPORT
     myFeatures += "ZIP";
@@ -101,7 +96,7 @@ OSystem::OSystem()
   ostringstream info;
   info << "Build " << STELLA_BUILD << ", using " << MediaFactory::backendName()
        << " [" << BSPF::ARCH << "]";
-  myBuildInfo = info.str();
+  myBuildInfo = info.view();
 
   mySettings = MediaFactory::createSettings();
 
@@ -128,22 +123,22 @@ bool OSystem::initialize(const Settings::Options& options)
   loadConfig(options);
 
   ostringstream buf;
-  buf << "Stella " << STELLA_VERSION << endl
-      << "  Features: " << myFeatures << endl
-      << "  " << myBuildInfo << endl << endl
+  buf << "Stella " << STELLA_VERSION << '\n'
+      << "  Features: " << myFeatures << '\n'
+      << "  " << myBuildInfo << "\n\n"
       << "Base directory:     '"
-      << myBaseDir.getShortPath() << "'" << endl
+      << myBaseDir.getShortPath() << "'\n"
       << "State directory:    '"
-      << myStateDir.getShortPath() << "'" << endl
+      << myStateDir.getShortPath() << "'\n"
       << "NVRam directory:    '"
-      << myNVRamDir.getShortPath() << "'" << endl
+      << myNVRamDir.getShortPath() << "'\n"
       << "Persistence:        '"
-      << describePresistence() << "'" << endl
+      << describePresistence() << "'\n"
       << "Cheat file:         '"
-      << myCheatFile.getShortPath() << "'" << endl
+      << myCheatFile.getShortPath() << "'\n"
       << "Palette file:       '"
-      << myPaletteFile.getShortPath() << "'" << endl;
-  Logger::info(buf.str());
+      << myPaletteFile.getShortPath() << "'\n";
+  Logger::info(buf.view());
 
   // NOTE: The framebuffer MUST be created before any other object!!!
   // Get relevant information about the video hardware
@@ -175,7 +170,7 @@ bool OSystem::initialize(const Settings::Options& options)
   createSound();
 
   // Create random number generator
-  myRandom = make_unique<Random>(uInt32(TimerManager::getTicks()));
+  myRandom = make_unique<Random>(static_cast<uInt32>(TimerManager::getTicks()));
 
 #ifdef CHEATCODE_SUPPORT
   myCheatManager = make_unique<CheatManager>(*this);
@@ -196,18 +191,20 @@ bool OSystem::initialize(const Settings::Options& options)
   myHighScoresManager->setRepository(getHighscoreRepository());
 #endif
 
-#ifdef PNG_SUPPORT
+#ifdef IMAGE_SUPPORT
   // Create PNG handler
   myPNGLib = make_unique<PNGLibrary>(*this);
+  // Create JPG handler
+  myJPGLib = make_unique<JPGLibrary>(*this);
 #endif
 
   // Detect serial port for AtariVox-USB
   // If a previously set port is defined, use it;
   // otherwise use the first one found (if any)
-  const string& avoxport = mySettings->getString("avoxport");
+  const string_view avoxport = mySettings->getString("avoxport");
   const StringList ports = MediaFactory::createSerialPort()->portNames();
 
-  if(avoxport.empty() && ports.size() > 0)
+  if(avoxport.empty() && !ports.empty())
     mySettings->setValue("avoxport", ports[0]);
 
   return true;
@@ -223,11 +220,11 @@ void OSystem::loadConfig(const Settings::Options& options)
                      ourOverrideBaseDirWithApp, ourOverrideBaseDir);
 
   // Get fully-qualified pathnames, and make directories when needed
-  myBaseDir = FilesystemNode(baseDir);
+  myBaseDir = FSNode(baseDir);
   if(!myBaseDir.isDirectory())
     myBaseDir.makeDir();
 
-  myHomeDir = FilesystemNode(homeDir);
+  myHomeDir = FSNode(homeDir);
   if(!myHomeDir.isDirectory())
     myHomeDir.makeDir();
 
@@ -242,7 +239,7 @@ void OSystem::loadConfig(const Settings::Options& options)
   string userDir = mySettings->getString("userdir");
   if(userDir.empty())
     userDir = homeDir;
-  myUserDir = FilesystemNode(userDir);
+  myUserDir = FSNode(userDir);
   if(!myUserDir.isDirectory())
     myUserDir.makeDir();
 
@@ -272,9 +269,9 @@ void OSystem::saveConfig()
 void OSystem::setConfigPaths()
 {
   // Make sure all required directories actually exist
-  const auto buildDirIfRequired = [](FilesystemNode& path,
-                                     const FilesystemNode& initialPath,
-                                     const string& pathToAppend = EmptyString)
+  const auto buildDirIfRequired = [](FSNode& path,
+                                     const FSNode& initialPath,
+                                     string_view pathToAppend = EmptyString)
   {
     path = initialPath;
     if(pathToAppend != EmptyString)
@@ -289,32 +286,14 @@ void OSystem::setConfigPaths()
   buildDirIfRequired(myCfgDir, myBaseDir, "cfg");
 #endif
 
-#ifdef PNG_SUPPORT
-  const string& ssSaveDir = mySettings->getString("snapsavedir");
-  if(ssSaveDir == EmptyString)
-    mySnapshotSaveDir = userDir();
-  else
-    mySnapshotSaveDir = FilesystemNode(ssSaveDir);
-  if(!mySnapshotSaveDir.isDirectory())
-    mySnapshotSaveDir.makeDir();
-
-  const string& ssLoadDir = mySettings->getString("snaploaddir");
-  if(ssLoadDir == EmptyString)
-    mySnapshotLoadDir = userDir();
-  else
-    mySnapshotLoadDir = FilesystemNode(ssLoadDir);
-  if(!mySnapshotLoadDir.isDirectory())
-    mySnapshotLoadDir.makeDir();
-#endif
-
   myCheatFile = myBaseDir;  myCheatFile /= "stella.cht";
   myPaletteFile = myBaseDir;  myPaletteFile /= "stella.pal";
 
 #if 0
   // Debug code
-  auto dbgPath = [](const string& desc, const FilesystemNode& location)
+  auto dbgPath = [](string_view desc, const FSNode& location)
   {
-    cerr << desc << ": " << location << endl;
+    cerr << desc << ": " << location << '\n';
   };
   dbgPath("base dir  ", myBaseDir);
   dbgPath("state dir ", myStateDir);
@@ -322,17 +301,62 @@ void OSystem::setConfigPaths()
   dbgPath("cfg dir   ", myCfgDir);
   dbgPath("ssave dir ", mySnapshotSaveDir);
   dbgPath("sload dir ", mySnapshotLoadDir);
+  dbgPath("bezel dir ", myBezelDir);
   dbgPath("cheat file", myCheatFile);
   dbgPath("pal file  ", myPaletteFile);
 #endif
 }
 
+#ifdef IMAGE_SUPPORT
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void OSystem::setUserDir(const string& path)
+const FSNode& OSystem::snapshotSaveDir()
+{
+  const string_view ssSaveDir = mySettings->getString("snapsavedir");
+  if(ssSaveDir == EmptyString)
+    mySnapshotSaveDir = userDir();
+  else
+    mySnapshotSaveDir = FSNode(ssSaveDir);
+  if(!mySnapshotSaveDir.isDirectory())
+    mySnapshotSaveDir.makeDir();
+
+  return mySnapshotSaveDir;
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+const FSNode& OSystem::snapshotLoadDir()
+{
+  const string_view ssLoadDir = mySettings->getString("snaploaddir");
+  if(ssLoadDir == EmptyString)
+    mySnapshotLoadDir = userDir();
+  else
+    mySnapshotLoadDir = FSNode(ssLoadDir);
+  if(!mySnapshotLoadDir.isDirectory())
+    mySnapshotLoadDir.makeDir();
+
+  return mySnapshotLoadDir;
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+const FSNode& OSystem::bezelDir()
+{
+  const string_view bezelDir = mySettings->getString("bezel.dir");
+  if(bezelDir == EmptyString)
+    myBezelDir = userDir();
+  else
+    myBezelDir = FSNode(bezelDir);
+  if(!myBezelDir.isDirectory())
+    myBezelDir.makeDir();
+
+  return myBezelDir;
+}
+#endif
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void OSystem::setUserDir(string_view path)
 {
   mySettings->setValue("userdir", path);
 
-  myUserDir = FilesystemNode(path);
+  myUserDir = FSNode(path);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -349,7 +373,7 @@ bool OSystem::checkUserPalette(bool outputError) const
     if(size != 128 * 3 * 2 + 8 * 3)
     {
       if(outputError)
-        cerr << "ERROR: invalid palette file " << paletteFile() << endl;
+        cerr << "ERROR: invalid palette file " << paletteFile() << '\n';
 
       return false;
     }
@@ -413,8 +437,7 @@ void OSystem::createSound()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-string OSystem::createConsole(const FilesystemNode& rom, const string& md5sum,
-                              bool newrom)
+string OSystem::createConsole(const FSNode& rom, string_view md5sum, bool newrom)
 {
   bool showmessage = false;
 
@@ -447,7 +470,7 @@ string OSystem::createConsole(const FilesystemNode& rom, const string& md5sum,
   catch(const runtime_error& e)
   {
     buf << "ERROR: " << e.what();
-    Logger::error(buf.str());
+    Logger::error(buf.view());
     return buf.str();
   }
 
@@ -471,9 +494,10 @@ string OSystem::createConsole(const FilesystemNode& rom, const string& md5sum,
     }
     myConsole->initializeAudio();
 
-    string saveOnExit = settings().getString("saveonexit");
-    bool devSettings = settings().getBool("dev.settings");
-    bool activeTM = settings().getBool(devSettings ? "dev.timemachine" : "plr.timemachine");
+    const string saveOnExit = settings().getString("saveonexit");
+    const bool devSettings = settings().getBool("dev.settings");
+    const bool activeTM = settings().getBool(
+      devSettings ? "dev.timemachine" : "plr.timemachine");
 
     if (saveOnExit == "all" && activeTM)
       myEventHandler->handleEvent(Event::LoadAllStates);
@@ -481,41 +505,51 @@ string OSystem::createConsole(const FilesystemNode& rom, const string& md5sum,
     if(showmessage)
     {
       const string& id = myConsole->cartridge().multiCartID();
-      if(id == "")
+      if(id.empty())
         myFrameBuffer->showTextMessage("New console created");
       else
         myFrameBuffer->showTextMessage("Multicart " +
           myConsole->cartridge().detectedType() + ", loading ROM" + id);
     }
-    buf << "Game console created:" << endl
-        << "  ROM file: " << myRomFile.getShortPath() << endl;
-    FilesystemNode propsFile(myRomFile.getPathWithExt(".pro"));
+    buf << "Game console created:\n"
+        << "  ROM file: " << myRomFile.getShortPath() << '\n';
+    const FSNode propsFile(myRomFile.getPathWithExt(".pro"));
     if(propsFile.exists())
-      buf << "  PRO file: " << propsFile.getShortPath() << endl;
-    buf << endl << getROMInfo(*myConsole);
-    Logger::info(buf.str());
+      buf << "  PRO file: " << propsFile.getShortPath() << '\n';
+    buf << '\n' << getROMInfo(*myConsole);
+    Logger::info(buf.view());
 
     myFrameBuffer->setCursorState();
 
     myEventHandler->handleConsoleStartupEvents();
     myConsole->riot().update();
 
-    #ifdef DEBUGGER_SUPPORT
-      if(mySettings->getBool("debug"))
-        myEventHandler->enterDebugMode();
-    #endif
+  #ifdef DEBUGGER_SUPPORT
+    if(mySettings->getBool("debug"))
+      myEventHandler->enterDebugMode();
+  #endif
 
-    if(!showmessage &&
-       settings().getBool(devSettings ? "dev.detectedinfo" : "plr.detectedinfo"))
+    if(!showmessage)
     {
-      ostringstream msg;
+      if(settings().getBool(devSettings ? "dev.detectedinfo" : "plr.detectedinfo"))
+      {
+        ostringstream msg;
 
-      msg << myConsole->leftController().name() << "/" << myConsole->rightController().name()
-        << " - " << myConsole->cartridge().detectedType()
-        << (myConsole->cartridge().isPlusROM() ? " PlusROM " : "")
-        << " - " << myConsole->getFormatString();
-      myFrameBuffer->showTextMessage(msg.str());
+        msg << myConsole->leftController().name() << "/" << myConsole->rightController().name()
+          << " - " << myConsole->cartridge().detectedType()
+          << (myConsole->cartridge().isPlusROM() ? " PlusROM " : "")
+          << " - " << myConsole->getFormatString();
+        myFrameBuffer->showTextMessage(msg.view());
+      }
+      else if(!myLauncherUsed)
+      {
+        ostringstream msg;
+
+        msg << "Stella " << STELLA_VERSION;
+        myFrameBuffer->showTextMessage(msg.view());
+      }
     }
+
     // Check for first PlusROM start
     if(myConsole->cartridge().isPlusROM())
     {
@@ -523,9 +557,9 @@ string OSystem::createConsole(const FilesystemNode& rom, const string& md5sum,
       {
         // Make sure there always is an id
         constexpr int ID_LEN = 32;
-        const char* HEX_DIGITS = "0123456789ABCDEF";
+        constexpr string_view HEX_DIGITS{ "0123456789ABCDEF" };
         char id_chr[ID_LEN] = { 0 };
-        Random rnd;
+        const Random rnd;
 
         for(char& c : id_chr)
           c = HEX_DIGITS[rnd.next() % 16];
@@ -548,11 +582,13 @@ string OSystem::createConsole(const FilesystemNode& rom, const string& md5sum,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool OSystem::reloadConsole(bool nextrom)
+optional<string> OSystem::reloadConsole(bool nextrom)
 {
   mySettings->setValue("romloadprev", !nextrom);
 
-  return createConsole(myRomFile, myRomMD5, false) == EmptyString;
+  const string result = createConsole(myRomFile, myRomMD5, false);
+
+  return result == EmptyString ? std::nullopt : optional<string>(result);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -563,12 +599,12 @@ bool OSystem::hasConsole() const
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool OSystem::createLauncher(const string& startdir)
+bool OSystem::createLauncher(string_view startdir)
 {
   closeConsole();
 
   if(mySound)
-    mySound->close();
+    mySound->pause(true);
 
   mySettings->setValue("tmpromdir", startdir);
   bool status = false;
@@ -602,7 +638,7 @@ bool OSystem::launcherLostFocus()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-string OSystem::getROMInfo(const FilesystemNode& romfile)
+string OSystem::getROMInfo(const FSNode& romfile)
 {
   unique_ptr<Console> console;
   try
@@ -634,7 +670,7 @@ void OSystem::resetFps()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-unique_ptr<Console> OSystem::openConsole(const FilesystemNode& romfile, string& md5)
+unique_ptr<Console> OSystem::openConsole(const FSNode& romfile, string& md5)
 {
   unique_ptr<Console> console;
 
@@ -649,10 +685,10 @@ unique_ptr<Console> OSystem::openConsole(const FilesystemNode& romfile, string&
     myPropSet->getMD5(md5, props);
 
     // Local helper method
-    const auto CMDLINE_PROPS_UPDATE = [&](const string& name, PropType prop)
+    const auto CMDLINE_PROPS_UPDATE = [&](string_view name, PropType prop)
     {
-      const string& s = mySettings->getString(name);
-      if(s != "") props.set(prop, s);
+      const string_view s = mySettings->getString(name);
+      if(!s.empty()) props.set(prop, s);
     };
 
     CMDLINE_PROPS_UPDATE("bs", PropType::Cart_Type);
@@ -662,9 +698,9 @@ unique_ptr<Console> OSystem::openConsole(const FilesystemNode& romfile, string&
     // Now create the cartridge
     string cartmd5 = md5;
     const string& type = props.get(PropType::Cart_Type);
-    const Cartridge::messageCallback callback = [&os = *this](const string& msg)
+    const Cartridge::messageCallback callback = [&os = *this](string_view msg)
     {
-      bool devSettings = os.settings().getBool("dev.settings");
+      const bool devSettings = os.settings().getBool("dev.settings");
 
       if(os.settings().getBool(devSettings ? "dev.extaccess" : "plr.extaccess"))
         os.frameBuffer().showTextMessage(msg);
@@ -699,12 +735,12 @@ unique_ptr<Console> OSystem::openConsole(const FilesystemNode& romfile, string&
     CMDLINE_PROPS_UPDATE("rq1", PropType::Controller_Right1);
     CMDLINE_PROPS_UPDATE("rq2", PropType::Controller_Right2);
     const string& bc = mySettings->getString("bc");
-    if(bc != "") {
+    if(!bc.empty()) {
       props.set(PropType::Controller_Left, bc);
       props.set(PropType::Controller_Right, bc);
     }
     const string& aq = mySettings->getString("aq");
-    if(aq != "")
+    if(!aq.empty())
     {
       props.set(PropType::Controller_Left1, aq);
       props.set(PropType::Controller_Left2, aq);
@@ -723,6 +759,7 @@ unique_ptr<Console> OSystem::openConsole(const FilesystemNode& romfile, string&
     CMDLINE_PROPS_UPDATE("ppblend", PropType::Display_PPBlend);
     CMDLINE_PROPS_UPDATE("pxcenter", PropType::Controller_PaddlesXCenter);
     CMDLINE_PROPS_UPDATE("pycenter", PropType::Controller_PaddlesYCenter);
+    CMDLINE_PROPS_UPDATE("bezelname", PropType::Bezel_Name);
 
     // Finally, create the cart with the correct properties
     if(cart)
@@ -746,7 +783,7 @@ void OSystem::closeConsole()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-ByteBuffer OSystem::openROM(const FilesystemNode& rom, string& md5, size_t& size)
+ByteBuffer OSystem::openROM(const FSNode& rom, string& md5, size_t& size)
 {
   // This method has a documented side-effect:
   // It not only loads a ROM and creates an array with its contents,
@@ -759,7 +796,7 @@ ByteBuffer OSystem::openROM(const FilesystemNode& rom, string& md5, size_t& size
     // If we get to this point, we know we have a valid file to open
     // Now we make sure that the file has a valid properties entry
     // To save time, only generate an MD5 if we really need one
-    if(md5 == "")
+    if(md5.empty())
       md5 = MD5::hash(image, size);
 
     // Make sure to load a per-ROM properties entry, if one exists
@@ -770,7 +807,7 @@ ByteBuffer OSystem::openROM(const FilesystemNode& rom, string& md5, size_t& size
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-string OSystem::getROMMD5(const FilesystemNode& rom) const
+string OSystem::getROMMD5(const FSNode& rom)
 {
   size_t size = 0;
   const ByteBuffer image = openROM(rom, size, false);  // ignore error message
@@ -779,8 +816,8 @@ string OSystem::getROMMD5(const FilesystemNode& rom) const
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-ByteBuffer OSystem::openROM(const FilesystemNode& rom, size_t& size,
-                            bool showErrorMessage) const
+ByteBuffer OSystem::openROM(const FSNode& rom, size_t& size,
+                            bool showErrorMessage)
 {
   // First check if this is a valid ROM filename
   const bool isValidROM = rom.isFile() && Bankswitch::isValidRomName(rom);
@@ -826,12 +863,12 @@ string OSystem::getROMInfo(const Console& console)
   const ConsoleInfo& info = console.about();
   ostringstream buf;
 
-  buf << "  Cart Name:       " << info.CartName << endl
-      << "  Cart MD5:        " << info.CartMD5 << endl
-      << "  Controller 0:    " << info.Control0 << endl
-      << "  Controller 1:    " << info.Control1 << endl
-      << "  Display Format:  " << info.DisplayFormat << endl
-      << "  Bankswitch Type: " << info.BankSwitch << endl;
+  buf << "  Cart Name:       " << info.CartName << '\n'
+      << "  Cart MD5:        " << info.CartMD5 << '\n'
+      << "  Controller 0:    " << info.Control0 << '\n'
+      << "  Controller 1:    " << info.Control1 << '\n'
+      << "  Display Format:  " << info.DisplayFormat << '\n'
+      << "  Bankswitch Type: " << info.BankSwitch << '\n';
 
   return buf.str();
 }
@@ -879,10 +916,11 @@ double OSystem::dispatchEmulation(EmulationWorker& emulationWorker)
 
   // Handle the dispatch result
   switch (dispatchResult.getStatus()) {
-    case DispatchResult::Status::ok:
+    using enum DispatchResult::Status;
+    case ok:
       break;
 
-    case DispatchResult::Status::debugger:
+    case debugger:
       #ifdef DEBUGGER_SUPPORT
        myDebugger->start(
           dispatchResult.getMessage(),
@@ -894,11 +932,11 @@ double OSystem::dispatchEmulation(EmulationWorker& emulationWorker)
 
       break;
 
-    case DispatchResult::Status::fatal:
+    case fatal:
       #ifdef DEBUGGER_SUPPORT
         myDebugger->startWithFatalError(dispatchResult.getMessage());
       #else
-        cerr << dispatchResult.getMessage() << endl;
+        cerr << dispatchResult.getMessage() << '\n';
       #endif
         break;
 
@@ -931,6 +969,7 @@ void OSystem::mainLoop()
     const bool wasEmulation = myEventHandler->state() == EventHandlerState::EMULATION;
 
     myEventHandler->poll(TimerManager::getTicks());
+
     if(myQuitLoop) break;  // Exit if the user wants to quit
 
     if (!wasEmulation && myEventHandler->state() == EventHandlerState::EMULATION) {
@@ -938,7 +977,7 @@ void OSystem::mainLoop()
       virtualTime = high_resolution_clock::now();
     }
 
-    double timesliceSeconds;
+    double timesliceSeconds;  // NOLINT
 
     if (myEventHandler->state() == EventHandlerState::EMULATION)
       // Dispatch emulation and render frame (if applicable)
@@ -988,5 +1027,5 @@ void OSystem::mainLoop()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-string OSystem::ourOverrideBaseDir = "";
+string OSystem::ourOverrideBaseDir;
 bool OSystem::ourOverrideBaseDirWithApp = false;
