@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -59,29 +59,30 @@ AboutDialog::AboutDialog(OSystem& osystem, DialogContainer& parent,
   wid.push_back(myNextButton);
 
   xpos = _w - buttonWidth - HBORDER;
-  ButtonWidget* b =
-    new ButtonWidget(this, font, xpos, ypos, buttonWidth, buttonHeight,
-                     "Close", GuiObject::kCloseCmd);
+  auto* b = new ButtonWidget(this, font, xpos, ypos,
+      buttonWidth, buttonHeight, "Close", GuiObject::kCloseCmd);
   wid.push_back(b);
   addCancelWidget(b);
 
   xpos = HBORDER;  ypos = _th + VBORDER + (buttonHeight - fontHeight) / 2;
-  int bwidth = font.getStringWidth("What's New" + ELLIPSIS) + fontWidth * 2.5;
+  const int bwidth = font.getStringWidth("What's New" + ELLIPSIS) + fontWidth * 2.5;
 
-  myTitle = new StaticTextWidget(this, font, xpos + bwidth, ypos, _w - (xpos + bwidth) * 2,
+  myTitle = new StaticTextWidget(this, font, xpos + bwidth, ypos,
+                                 _w - (xpos + bwidth) * 2,
                                  fontHeight, "", TextAlign::Center);
   myTitle->setTextColor(kTextColorEm);
 
   myWhatsNewButton =
-    new ButtonWidget(this, font, _w - HBORDER - bwidth, ypos - (buttonHeight - fontHeight) / 2,
+    new ButtonWidget(this, font, _w - HBORDER - bwidth,
+                     ypos - (buttonHeight - fontHeight) / 2,
                      bwidth, buttonHeight, "What's New" + ELLIPSIS, kWhatsNew);
   wid.push_back(myWhatsNewButton);
 
   xpos = HBORDER * 2;  ypos += lineHeight + VGAP * 2;
   for(int i = 0; i < myLinesPerPage; i++)
   {
-    StaticTextWidget* s = new StaticTextWidget(this, font, xpos, ypos, _w - xpos * 2,
-                                               fontHeight, "", TextAlign::Left, kNone);
+    auto* s = new StaticTextWidget(this, font, xpos, ypos, _w - xpos * 2,
+                                   fontHeight, "", TextAlign::Left, kNone);
     s->setID(i);
     myDesc.push_back(s);
     myDescStr.emplace_back("");
@@ -94,7 +95,7 @@ AboutDialog::AboutDialog(OSystem& osystem, DialogContainer& parent,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-AboutDialog::~AboutDialog()
+AboutDialog::~AboutDialog()  // NOLINT (we need an empty d'tor)
 {
 }
 
@@ -111,7 +112,7 @@ AboutDialog::~AboutDialog()
 void AboutDialog::updateStrings(int page, int lines, string& title)
 {
   int i = 0;
-  const auto ADD_ATEXT = [&](const string& d) { myDescStr[i] = d; i++; };
+  const auto ADD_ATEXT = [&](string_view d) { myDescStr[i] = d; i++; };
   const auto ADD_ALINE = [&]() { ADD_ATEXT(""); };
 
   switch(page)
@@ -122,7 +123,7 @@ void AboutDialog::updateStrings(int page, int lines, string& title)
       ADD_ATEXT(string("\\C\\c2Features: ") + instance().features());
       ADD_ATEXT(string("\\C\\c2") + instance().buildInfo());
       ADD_ALINE();
-      ADD_ATEXT("\\CCopyright (c) 1995-2022 The Stella Team");
+      ADD_ATEXT("\\CCopyright (c) 1995-2024 The Stella Team");
       ADD_ATEXT("\\C(https://stella-emu.github.io)");
       ADD_ALINE();
       ADD_ATEXT("\\CStella is now DonationWare!");
@@ -301,9 +302,9 @@ void AboutDialog::handleCommand(CommandSender* sender, int cmd, int data, int id
 
     case StaticTextWidget::kOpenUrlCmd:
     {
-      const string url = myDesc[id]->getUrl();
+      const string& url = myDesc[id]->getUrl();
 
-      if(url != EmptyString)
+      if(url != EmptyString && MediaFactory::supportsURL())
         MediaFactory::openURL(url);
       break;
     }
@@ -314,15 +315,15 @@ void AboutDialog::handleCommand(CommandSender* sender, int cmd, int data, int id
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const string AboutDialog::getUrl(const string& str) const
+string AboutDialog::getUrl(string_view text)
 {
   bool isUrl = false;
   size_t start = 0, len = 0;
 
-  for(size_t i = 0; i < str.size(); ++i)
+  for(size_t i = 0; i < text.size(); ++i)
   {
-    string remainder = str.substr(i);
-    const char ch = str[i];
+    const string_view remainder = text.substr(i);
+    const char ch = text[i];
 
     if(!isUrl
        && (BSPF::startsWithIgnoreCase(remainder, "http://")
@@ -343,7 +344,7 @@ const string AboutDialog::getUrl(const string& str) const
     }
   }
   if(len)
-    return str.substr(start, len);
+    return string{text.substr(start, len)};
   else
     return EmptyString;
 }
