@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -75,15 +75,15 @@ BrowserDialog::BrowserDialog(GuiObject* boss, const GUI::Font& font,
                                  buttonWidth, buttonHeight, "Go up", kGoUpCmd);
   addFocusWidget(_goUpButton);
 
-  b = new ButtonWidget(this, font, _goUpButton->getRight() + BUTTON_GAP, _h - buttonHeight - VBORDER,
-                       buttonWidth, buttonHeight, "Base Dir", kBaseDirCmd);
-  b->setToolTip("Go to Stella's base directory.");
-  addFocusWidget(b);
+  _baseDirButton = new ButtonWidget(this, font, _goUpButton->getRight() + BUTTON_GAP, _h - buttonHeight - VBORDER,
+                                    buttonWidth, buttonHeight, "Base Dir", kBaseDirCmd);
+  _baseDirButton->setToolTip("Go to Stella's base directory.");
+  addFocusWidget(_baseDirButton);
 
-  b = new ButtonWidget(this, font, b->getRight() + BUTTON_GAP, _h - buttonHeight - VBORDER,
-                       buttonWidth, buttonHeight, "Home Dir", kHomeDirCmd);
-  b->setToolTip("Go to user's home directory.");
-  addFocusWidget(b);
+  _homeDirButton = new ButtonWidget(this, font, _baseDirButton->getRight() + BUTTON_GAP, _h - buttonHeight - VBORDER,
+                                    buttonWidth, buttonHeight, "Home Dir", kHomeDirCmd);
+  _homeDirButton->setToolTip("Go to user's home directory.");
+  addFocusWidget(_homeDirButton);
 
 #ifndef BSPF_MACOS
   b = new ButtonWidget(this, font, _w - (2 * buttonWidth + BUTTON_GAP + HBORDER), _h - buttonHeight - VBORDER,
@@ -111,32 +111,40 @@ BrowserDialog::BrowserDialog(GuiObject* boss, const GUI::Font& font,
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 // static
-void BrowserDialog::show(GuiObject* parent, const GUI::Font& font,
-                         const string& title, const string& startpath,
+void BrowserDialog::show(Dialog* parent, const GUI::Font& font,
+                         string_view title, string_view startpath,
                          BrowserDialog::Mode mode,
                          const Command& command,
-                         const FilesystemNode::NameFilter& namefilter)
+                         const FSNode::NameFilter& namefilter)
 {
   uInt32 w = 0, h = 0;
 
-  static_cast<Dialog*>(parent)->getDynamicBounds(w, h);
+  if (parent) {
+    parent->getDynamicBounds(w, h);
+  } else {
+    w = FBMinimum::Width;
+    h = FBMinimum::Height;
+  }
+
   if(w > static_cast<uInt32>(font.getMaxCharWidth() * 80))
     w = font.getMaxCharWidth() * 80;
 
-  if(ourBrowser == nullptr || &ourBrowser->parent() != &parent->parent())
+  if(ourBrowser == nullptr || &ourBrowser->parent() != &parent->parent()
+      || ourBrowser->_w > static_cast<int>(w) || ourBrowser->_h > static_cast<int>(h))
+  {
     ourBrowser = make_unique<BrowserDialog>(parent, font, w, h);
-
+  }
   ourBrowser->setTitle(title); // has to be always updated!
   ourBrowser->show(startpath, mode, command, namefilter);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 // static
-void BrowserDialog::show(GuiObject* parent,
-                         const string& title, const string& startpath,
+void BrowserDialog::show(Dialog* parent,
+                         string_view title, string_view startpath,
                          BrowserDialog::Mode mode,
                          const Command& command,
-                         const FilesystemNode::NameFilter& namefilter)
+                         const FSNode::NameFilter& namefilter)
 {
   show(parent, parent->instance().frameBuffer().font(), title, startpath,
        mode, command, namefilter);
@@ -150,10 +158,10 @@ void BrowserDialog::hide()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void BrowserDialog::show(const string& startpath,
+void BrowserDialog::show(string_view startpath,
                          BrowserDialog::Mode mode,
                          const Command& command,
-                         const FilesystemNode::NameFilter& namefilter)
+                         const FSNode::NameFilter& namefilter)
 {
   const int fontWidth = Dialog::fontWidth(),
             VGAP      = Dialog::vGap();
@@ -167,15 +175,26 @@ void BrowserDialog::show(const string& startpath,
   if(_mode != Mode::Directories)
   {
     // split startpath into path and filename
-    FilesystemNode fs = FilesystemNode(startpath);
+    const FSNode fs = FSNode(startpath);
     fileName = fs.getName();
     directory = fs.isDirectory() ? "" : fs.getParent().getPath();
   }
 
+  // Default navigation settings:
+  _navigationBar->setVisible(true);
+  _fileList->setListMode(FSNode::ListMode::All);
+  _fileList->setShowFileExtensions(true);
+  _goUpButton->clearFlags(Widget::FLAG_INVISIBLE);
+  _goUpButton->setEnabled(true);
+  _baseDirButton->clearFlags(Widget::FLAG_INVISIBLE);
+  _baseDirButton->setEnabled(true);
+  _homeDirButton->clearFlags(Widget::FLAG_INVISIBLE);
+  _homeDirButton->setEnabled(true);
+
   switch(_mode)
   {
     case Mode::FileLoad:
-      _fileList->setListMode(FilesystemNode::ListMode::All);
+      _fileList->setListMode(FSNode::ListMode::All);
       _fileList->setNameFilter(namefilter);
       _fileList->setHeight(_selected->getTop() - VGAP * 2 - _fileList->getTop());
       // Show "save" checkbox
@@ -191,8 +210,34 @@ void BrowserDialog::show(const string& startpath,
       _okWidget->setLabel("Load");
       break;
 
+    case Mode::FileLoadNoDirs:
+      _fileList->setListMode(FSNode::ListMode::FilesOnly);
+      _fileList->setNameFilter(namefilter);
+      _fileList->setHeight(_selected->getTop() - VGAP * 2 - _fileList->getTop());
+      _fileList->setShowFileExtensions(false);
+
+      _navigationBar->setVisible(false);
+      _navigationBar->setEnabled(false);
+      // Hide "save" checkbox
+      //_navigationBar->setWidth(_savePathBox->getRight() - _navigationBar->getLeft());
+      _savePathBox->setEnabled(false);
+      _savePathBox->setFlags(Widget::FLAG_INVISIBLE);
+
+      _name->clearFlags(Widget::FLAG_INVISIBLE);
+      _selected->clearFlags(Widget::FLAG_INVISIBLE);
+      _selected->setEditable(false);
+      _selected->setEnabled(false);
+      _goUpButton->setFlags(Widget::FLAG_INVISIBLE);
+      _goUpButton->setEnabled(false);
+      _baseDirButton->setFlags(Widget::FLAG_INVISIBLE);
+      _baseDirButton->setEnabled(false);
+      _homeDirButton->setFlags(Widget::FLAG_INVISIBLE);
+      _homeDirButton->setEnabled(false);
+      _okWidget->setLabel("Select");
+      break;
+
     case Mode::FileSave:
-      _fileList->setListMode(FilesystemNode::ListMode::All);
+      _fileList->setListMode(FSNode::ListMode::All);
       _fileList->setNameFilter(namefilter);
       _fileList->setHeight(_selected->getTop() - VGAP * 2 - _fileList->getTop());
       // Show "save" checkbox
@@ -211,8 +256,8 @@ void BrowserDialog::show(const string& startpath,
       break;
 
     case Mode::Directories:
-      _fileList->setListMode(FilesystemNode::ListMode::DirectoriesOnly);
-      _fileList->setNameFilter([](const FilesystemNode&) { return true; });
+      _fileList->setListMode(FSNode::ListMode::DirectoriesOnly);
+      _fileList->setNameFilter([](const FSNode&) { return true; });
       // TODO: scrollbar affected too!
       _fileList->setHeight(_selected->getBottom() - _fileList->getTop());
       // Hide "save" checkbox
@@ -226,29 +271,33 @@ void BrowserDialog::show(const string& startpath,
       _selected->setEnabled(false);
       _okWidget->setLabel("OK");
       break;
+
+    default:
+      break;  // Not supposed to get here
   }
 
   // Set start path
-  if(_mode != Mode::Directories)
-    _fileList->setDirectory(FilesystemNode(directory), fileName);
+  if(_mode != Mode::Directories && !directory.empty())
+    _fileList->setDirectory(FSNode(directory), fileName);
   else
-    _fileList->setDirectory(FilesystemNode(startpath));
+    _fileList->setDirectory(FSNode(startpath));
 
   updateUI(fileSelected);
 
   // Finally, open the dialog after it has been fully updated
   open();
+  setFocus(_fileList);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const FilesystemNode& BrowserDialog::getResult() const
+const FSNode& BrowserDialog::getResult() const
 {
-  if(_mode == Mode::FileLoad || _mode == Mode::FileSave)
+  if(_mode != Mode::Directories)
   {
-    static FilesystemNode node;
+    static FSNode node;
 
     return node
-      = FilesystemNode(_fileList->currentDir().getPath() + _selected->getText());
+      = FSNode(_fileList->currentDir().getPath() + _selected->getText());
   }
   else
     return _fileList->currentDir();
@@ -296,11 +345,11 @@ void BrowserDialog::handleCommand(CommandSender* sender, int cmd,
       break;
 
     case kBaseDirCmd:
-      _fileList->selectDirectory(FilesystemNode(instance().baseDir()));
+      _fileList->selectDirectory(FSNode(instance().baseDir()));
       break;
 
     case kHomeDirCmd:
-      _fileList->selectDirectory(FilesystemNode(instance().homeDir()));
+      _fileList->selectDirectory(FSNode(instance().homeDir()));
       break;
 
     case EditableWidget::kChangedCmd:
@@ -322,7 +371,8 @@ void BrowserDialog::handleCommand(CommandSender* sender, int cmd,
 void BrowserDialog::updateUI(bool fileSelected)
 {
   // Only hilite the 'up' button if there's a parent directory
-  _goUpButton->setEnabled(_fileList->currentDir().hasParent());
+  _goUpButton->setEnabled(_goUpButton->isVisible()
+                          && _fileList->currentDir().hasParent());
 
   // Update the path display
   _navigationBar->updateUI();
@@ -334,7 +384,8 @@ void BrowserDialog::updateUI(bool fileSelected)
     enable = !_selected->getText().empty();
   _okWidget->setEnabled(enable);
 
-  if(fileSelected && _fileList->getList().size() && !_fileList->selected().isDirectory())
+  if(fileSelected && !_fileList->getList().empty() &&
+     !_fileList->selected().isDirectory())
     _selected->setText(_fileList->getSelectedString());
 }
 
