@@ -1,103 +1,87 @@
 //============================================================================
 //
-//   SSSS    tt          lll  lll       
-//  SS  SS   tt           ll   ll        
-//  SS     tttttt  eeee   ll   ll   aaaa 
+//   SSSS    tt          lll  lll
+//  SS  SS   tt           ll   ll
+//  SS     tttttt  eeee   ll   ll   aaaa
 //   SSSS    tt   ee  ee  ll   ll      aa
 //      SS   tt   eeeeee  ll   ll   aaaaa  --  "An Atari 2600 VCS Emulator"
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2016 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
-//
-// $Id: ComboDialog.cxx 3304 2016-04-03 00:35:00Z stephena $
 //============================================================================
 
-#include <sstream>
-
 #include "bspf.hxx"
-
 #include "Control.hxx"
 #include "Dialog.hxx"
-#include "DialogContainer.hxx"
 #include "EventHandler.hxx"
 #include "OSystem.hxx"
-#include "EditTextWidget.hxx"
 #include "PopUpWidget.hxx"
 #include "Widget.hxx"
-
+#include "Font.hxx"
 #include "ComboDialog.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ComboDialog::ComboDialog(GuiObject* boss, const GUI::Font& font,
                          const VariantList& combolist)
-  : Dialog(boss->instance(), boss->parent()),
-    myComboEvent(Event::NoType)
+  : Dialog(boss->instance(), boss->parent(), font, "Add...")
 {
-  const int lineHeight   = font.getLineHeight(),
-            fontWidth    = font.getMaxCharWidth(),
-            fontHeight   = font.getFontHeight(),
-            buttonWidth  = font.getStringWidth("Defaults") + 20,
-            buttonHeight = font.getLineHeight() + 4;
-  int xpos, ypos;
+  const int lineHeight   = Dialog::lineHeight(),
+            fontWidth    = Dialog::fontWidth(),
+            buttonHeight = Dialog::buttonHeight(),
+            VBORDER      = Dialog::vBorder(),
+            HBORDER      = Dialog::hBorder(),
+            VGAP         = Dialog::vGap();
   WidgetArray wid;
 
-  // Set real dimensions
-  _w = 35 * fontWidth + 10;
-  _h = 11 * (lineHeight + 4) + 10;
-  xpos = ypos = 5;
-
   // Get maximum width of popupwidget
   int pwidth = 0;
-  for(const auto& s: combolist)
+  for (const auto& s : combolist)
     pwidth = std::max(font.getStringWidth(s.first), pwidth);
 
-  // Label for dialog, indicating which combo is being changed
-  myComboName = new StaticTextWidget(this, font, xpos, ypos, _w - xpos - 10,
-                                     fontHeight, "", kTextAlignCenter);
-  ypos += (lineHeight + 4) + 5;
+  // Set real dimensions
+  _w = 8 * fontWidth + pwidth + PopUpWidget::dropDownWidth(font) + HBORDER * 2;
+  _h = 8 * (lineHeight + VGAP) + VGAP + buttonHeight + VBORDER * 2 + _th;
+  int xpos = HBORDER, ypos = VBORDER + _th;
 
   // Add event popup for 8 events
-  auto ADD_EVENT_POPUP = [&](int idx, const string& label)
+  myEvents.fill(nullptr);
+  const auto ADD_EVENT_POPUP = [&](int idx, string_view label)
   {
     myEvents[idx] = new PopUpWidget(this, font, xpos, ypos,
                         pwidth, lineHeight, combolist, label);
     wid.push_back(myEvents[idx]);
-    ypos += lineHeight + 4;
+    ypos += lineHeight + VGAP;
   };
-
-  xpos = 10;
-  myEvents[0] = nullptr;  ADD_EVENT_POPUP(0, "Event 1: ");
-  myEvents[1] = nullptr;  ADD_EVENT_POPUP(1, "Event 2: ");
-  myEvents[2] = nullptr;  ADD_EVENT_POPUP(2, "Event 3: ");
-  myEvents[3] = nullptr;  ADD_EVENT_POPUP(3, "Event 4: ");
-  myEvents[4] = nullptr;  ADD_EVENT_POPUP(4, "Event 5: ");
-  myEvents[5] = nullptr;  ADD_EVENT_POPUP(5, "Event 6: ");
-  myEvents[6] = nullptr;  ADD_EVENT_POPUP(6, "Event 7: ");
-  myEvents[7] = nullptr;  ADD_EVENT_POPUP(7, "Event 8: ");
+  ADD_EVENT_POPUP(0, "Event 1 ");
+  ADD_EVENT_POPUP(1, "Event 2 ");
+  ADD_EVENT_POPUP(2, "Event 3 ");
+  ADD_EVENT_POPUP(3, "Event 4 ");
+  ADD_EVENT_POPUP(4, "Event 5 ");
+  ADD_EVENT_POPUP(5, "Event 6 ");
+  ADD_EVENT_POPUP(6, "Event 7 ");
+  ADD_EVENT_POPUP(7, "Event 8 ");
 
   // Add Defaults, OK and Cancel buttons
-  ButtonWidget* b;
-  b = new ButtonWidget(this, font, 10, _h - buttonHeight - 10,
-                       buttonWidth, buttonHeight, "Defaults", kDefaultsCmd);
-  wid.push_back(b);
-  addOKCancelBGroup(wid, font);
+  addDefaultsOKCancelBGroup(wid, font);
 
   addToFocusList(wid);
+
+  setHelpAnchor("Combo");
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void ComboDialog::show(Event::Type event, const string& name)
+void ComboDialog::show(Event::Type event, string_view name)
 {
   // Make sure the event is allowed
   if(event >= Event::Combo1 && event <= Event::Combo16)
   {
     myComboEvent = event;
-    myComboName->setLabel("Add events for " + name);
+    setTitle("Add events for " + string{name});
     open();
   }
   else
@@ -109,13 +93,13 @@ void ComboDialog::loadConfig()
 {
   StringList events = instance().eventHandler().getComboListForEvent(myComboEvent);
 
-  uInt32 size = std::min(uInt32(events.size()), 8u);
-  for(uInt32 i = 0; i < size; ++i)
+  const size_t size = std::min<size_t>(events.size(), 8);
+  for(size_t i = 0; i < size; ++i)
     myEvents[i]->setSelected("", events[i]);
 
   // Fill any remaining items to 'None'
   if(size < 8)
-    for(uInt32 i = size; i < 8; ++i)
+    for(size_t i = size; i < 8; ++i)
       myEvents[i]->setSelected("None", "-1");
 }
 
@@ -135,7 +119,7 @@ void ComboDialog::setDefaults()
   for(int i = 0; i < 8; ++i)
     myEvents[i]->setSelected("None", "-1");
 
-  _dirty = true;
+  setDirty();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -144,12 +128,12 @@ void ComboDialog::handleCommand(CommandSender* sender, int cmd,
 {
   switch(cmd)
   {
-    case kOKCmd:
+    case GuiObject::kOKCmd:
       saveConfig();
       close();
       break;
 
-    case kDefaultsCmd:
+    case GuiObject::kDefaultsCmd:
       setDefaults();
       break;
 
