@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -49,11 +49,11 @@ CommandDialog::CommandDialog(OSystem& osystem, DialogContainer& parent)
   WidgetArray wid;
   int xoffset = HBORDER, yoffset = VBORDER + _th;
 
-  const auto ADD_CD_BUTTON = [&](const string& label, int cmd,
+  const auto ADD_CD_BUTTON = [&](string_view label, int cmd,
     Event::Type event1 = Event::NoType, Event::Type event2 = Event::NoType)
   {
-    ButtonWidget* b = new ButtonWidget(this, _font, xoffset, yoffset,
-            buttonWidth, buttonHeight, label, cmd);
+    auto* b = new ButtonWidget(this, _font, xoffset, yoffset,
+        buttonWidth, buttonHeight, label, cmd);
     b->setToolTip(event1, event2);
     yoffset += buttonHeight + VGAP;
     return b;
@@ -224,7 +224,7 @@ void CommandDialog::handleCommand(CommandSender* sender, int cmd,
     }
     case kReloadRomCmd:
       instance().eventHandler().leaveMenuMode();
-      instance().reloadConsole();
+      instance().eventHandler().handleEvent(Event::ReloadConsole);
       break;
 
     default:
