@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -29,13 +29,10 @@
 #include "TabWidget.hxx"
 #include "ToolTip.hxx"
 
-#include "ContextMenu.hxx"
-#include "PopUpWidget.hxx"
 #include "Settings.hxx"
 #include "Console.hxx"
 
 #include "Vec.hxx"
-#include "TIA.hxx"
 #include "MediaFactory.hxx"
 
 /*
@@ -48,7 +45,7 @@
  */
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 Dialog::Dialog(OSystem& instance, DialogContainer& parent, const GUI::Font& font,
-               const string& title, int x, int y, int w, int h)
+               string_view title, int x, int y, int w, int h)
   : GuiObject(instance, parent, *this, x, y, w, h),
     _font{font},
     _title{title},
@@ -112,7 +109,7 @@ void Dialog::open()
 
   setPosition();
 
-  if(_myTabList.size())
+  if(!_myTabList.empty())
     // (Re)-build the focus list to use for all widgets of all tabs
     for(auto& tabfocus : _myTabList)
       buildCurrentFocusList(tabfocus.widget->getID());
@@ -148,7 +145,7 @@ void Dialog::close()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void Dialog::setTitle(const string& title)
+void Dialog::setTitle(string_view title)
 {
   _title = title;
   _h -= _th;
@@ -167,17 +164,19 @@ void Dialog::initHelp()
   {
     if(_helpWidget == nullptr)
     {
-      string key = instance().eventHandler().getMappingDesc(Event::UIHelp, EventMode::kMenuMode);
+      const string key = instance().eventHandler().getMappingDesc(
+        Event::UIHelp, EventMode::kMenuMode);
 
-      _helpWidget = new ButtonWidget(this, _font, _w - _font.getMaxCharWidth() * 3.5, 0,
-                                     _font.getMaxCharWidth() * 3.5 + 0.5, buttonHeight(), "?",
-                                     kHelpCmd);
+      _helpWidget = new ButtonWidget(this, _font,
+          _w - _font.getMaxCharWidth() * 3.5, 0,
+          _font.getMaxCharWidth() * 3.5 + 0.5, buttonHeight(), "?",  // NOLINT
+          kHelpCmd);
       _helpWidget->setBGColor(kColorTitleBar);
       _helpWidget->setTextColor(kColorTitleText);
       _helpWidget->setToolTip("Click or press " + key + " for help.");
     }
 
-    if(hasHelp())
+    if(hasHelp() && MediaFactory::supportsURL())
       _helpWidget->clearFlags(Widget::FLAG_INVISIBLE);
     else
       _helpWidget->setFlags(Widget::FLAG_INVISIBLE);
@@ -186,7 +185,7 @@ void Dialog::initHelp()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void Dialog::setHelpAnchor(const string& helpAnchor, bool debugger)
+void Dialog::setHelpAnchor(string_view helpAnchor, bool debugger)
 {
   _helpAnchor = helpAnchor;
   _debuggerHelp = debugger;
@@ -195,7 +194,7 @@ void Dialog::setHelpAnchor(const string& helpAnchor, bool debugger)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void Dialog::setHelpURL(const string& helpURL)
+void Dialog::setHelpURL(string_view helpURL)
 {
   _helpURL = helpURL;
 
@@ -203,7 +202,7 @@ void Dialog::setHelpURL(const string& helpURL)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const string Dialog::getHelpURL() const
+string Dialog::getHelpURL() const
 {
   // 1. check individual widget
   if(_focusedWidget && _focusedWidget->hasHelp())
@@ -244,7 +243,7 @@ const string Dialog::getHelpURL() const
 void Dialog::openHelp()
 {
   if(hasHelp() && !MediaFactory::openURL(getHelpURL()))
-    cerr << "error opening URL " << getHelpURL() << endl;
+    cerr << "error opening URL " << getHelpURL() << '\n';
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -337,7 +336,7 @@ void Dialog::redraw(bool force)
 void Dialog::render()
 {
 #ifdef DEBUG_BUILD
-  //cerr << "  render " << typeid(*this).name() << endl;
+  //cerr << "  render " << typeid(*this).name() << '\n';
 #endif
 
   // Update dialog surface; also render any extra surfaces
@@ -402,7 +401,7 @@ void Dialog::addFocusWidget(Widget* w)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void Dialog::addToFocusList(const WidgetArray& list)
+int Dialog::addToFocusList(const WidgetArray& list)
 {
   // All focusable widgets should retain focus
   for(const auto& w: list)
@@ -411,16 +410,18 @@ void Dialog::addToFocusList(const WidgetArray& list)
   Vec::append(_myFocus.list, list);
   _focusList = _myFocus.list;
 
-  if(list.size() > 0)
+  if(!list.empty())
     _myFocus.widget = list[0];
+
+  return static_cast<int>(_focusList.size());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void Dialog::addToFocusList(const WidgetArray& list, const TabWidget* w, int tabId)
+int Dialog::addToFocusList(const WidgetArray& list, const TabWidget* w, int tabId)
 {
   // Only add the list if the tab actually exists
   if(!w || w->getID() >= _myTabList.size())
-    return;
+    return 0;
 
   assert(w == _myTabList[w->getID()].widget);
 
@@ -439,13 +440,15 @@ void Dialog::addToFocusList(const WidgetArray& list, const TabWidget* w, int tab
   {
     // Make sure the array is large enough
     while(focus.size() <= id)
-      focus.push_back(Focus());
+      focus.emplace_back();
 
     Vec::append(focus[id].list, list);
   }
 
-  if(list.size() > 0)
+  if(!list.empty())
     focus[id].widget = list[0];
+
+  return static_cast<int>(focus.size());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -457,9 +460,9 @@ void Dialog::addTabWidget(TabWidget* w)
   // Make sure the array is large enough
   const uInt32 id = w->getID();
   while(_myTabList.size() < id)
-    _myTabList.push_back(TabFocus());
+    _myTabList.emplace_back();
 
-  _myTabList.push_back(TabFocus(w));
+  _myTabList.emplace_back(w);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -508,14 +511,14 @@ void Dialog::buildCurrentFocusList(int tabID)
   // Add button group at end of current focus list
   // We do it this way for TabWidget, so that buttons are scanned
   // *after* the widgets in the current tab
-  if(_buttonGroup.size() > 0)
+  if(!_buttonGroup.empty())
     Vec::append(_focusList, _buttonGroup);
 
   // Finally, the moment we've all been waiting for :)
   // Set the actual focus widget
   if(tabFocusWidget)
     _focusedWidget = tabFocusWidget;
-  else if(!_focusedWidget && _focusList.size() > 0)
+  else if(!_focusedWidget && !_focusList.empty())
     _focusedWidget = _focusList[0];
 }
 
@@ -536,13 +539,13 @@ void Dialog::drawDialog()
   if(isDirty())
   {
   #ifdef DEBUG_BUILD
-    //cerr << "*** draw dialog " << typeid(*this).name() << " ***" << endl;
-    cerr << endl << "d";
+    //cerr << "*** draw dialog " << typeid(*this).name() << " ***\n";
+    cerr << "\nd";
   #endif
 
     if(clearsBackground())
     {
-      //    cerr << "Dialog::drawDialog(): w = " << _w << ", h = " << _h << " @ " << &s << endl << endl;
+      //    cerr << "Dialog::drawDialog(): w = " << _w << ", h = " << _h << " @ " << &s << "\n\n";
 
       if(hasBackground())
         s.fillRect(_x, _y + _th, _w, _h - _th, kDlgColor);
@@ -558,7 +561,7 @@ void Dialog::drawDialog()
     else {
       s.invalidate();
     #ifdef DEBUG_BUILD
-      //cerr << "invalidate " << typeid(*this).name() << endl;
+      //cerr << "invalidate " << typeid(*this).name() << '\n';
     #endif
     }
     if(hasBorder()) // currently only used by Dialog itself
@@ -571,7 +574,7 @@ void Dialog::drawDialog()
   }
 #ifdef DEBUG_BUILD
   else
-    cerr << endl;
+    cerr << '\n';
 #endif
 
   // Draw all children
@@ -918,7 +921,7 @@ bool Dialog::handleNavEvent(Event::Type e, bool repeated)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void Dialog::getTabIdForWidget(const Widget* w)
 {
-  if(_myTabList.size() == 0 || !w)
+  if(_myTabList.empty() || !w)
     return;
 
   for(uInt32 id = 0; id < _myTabList.size(); ++id)
@@ -977,7 +980,7 @@ Widget* Dialog::findWidget(int x, int y) const
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void Dialog::addOKBGroup(WidgetArray& wid, const GUI::Font& font,
-                         const string& okText, int buttonWidth)
+                         string_view okText, int buttonWidth)
 {
   const int buttonHeight = Dialog::buttonHeight(),
             BUTTON_GAP   = Dialog::buttonGap(),
@@ -996,7 +999,7 @@ void Dialog::addOKBGroup(WidgetArray& wid, const GUI::Font& font,
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void Dialog::addOKCancelBGroup(WidgetArray& wid, const GUI::Font& font,
-                               const string& okText, const string& cancelText,
+                               string_view okText, string_view cancelText,
                                bool focusOKButton, int buttonWidth)
 {
   const int buttonHeight = Dialog::buttonHeight(),
@@ -1041,8 +1044,8 @@ void Dialog::addOKCancelBGroup(WidgetArray& wid, const GUI::Font& font,
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void Dialog::addDefaultsOKCancelBGroup(WidgetArray& wid, const GUI::Font& font,
-                                       const string& okText, const string& cancelText,
-                                       const string& defaultsText,
+                                       string_view okText, string_view cancelText,
+                                       string_view defaultsText,
                                        bool focusOKButton)
 {
   const int buttonHeight = Dialog::buttonHeight(),
@@ -1060,8 +1063,8 @@ void Dialog::addDefaultsOKCancelBGroup(WidgetArray& wid, const GUI::Font& font,
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void Dialog::addDefaultsExtraOKCancelBGroup(
       WidgetArray& wid, const GUI::Font& font,
-      const string& extraText, int extraCmd,
-      const string& okText, const string& cancelText, const string& defaultsText,
+      string_view extraText, int extraCmd,
+      string_view okText, string_view cancelText, string_view defaultsText,
       bool focusOKButton)
 {
   const int buttonHeight = Dialog::buttonHeight(),
