@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -28,7 +28,7 @@
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 EditableWidget::EditableWidget(GuiObject* boss, const GUI::Font& font,
-                               int x, int y, int w, int h, const string& str)
+                               int x, int y, int w, int h, string_view str)
   : Widget(boss, font, x, y, w, h),
     CommandSender(boss),
     _editString{str},
@@ -43,7 +43,7 @@ EditableWidget::EditableWidget(GuiObject* boss, const GUI::Font& font,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void EditableWidget::setText(const string& str, bool changed)
+void EditableWidget::setText(string_view str, bool changed)
 {
   const string oldEditString = _editString;
   _backupString = str;
@@ -182,7 +182,7 @@ ContextMenu& EditableWidget::mouseMenu()
 {
   // add mouse context menu
   if(myMouseMenu == nullptr)
-    myMouseMenu = make_unique<ContextMenu>(this, _font, EmptyVarList);
+    myMouseMenu = make_unique<ContextMenu>(this, _font);
 
   return *myMouseMenu;
 }
@@ -213,7 +213,7 @@ void EditableWidget::handleCommand(CommandSender* sender, int cmd, int data, int
 {
   if(cmd == ContextMenu::kItemSelectedCmd)
   {
-    const string& rmb = mouseMenu().getSelectedTag().toString();
+    const string_view rmb = mouseMenu().getSelectedTag().toString();
 
     if(rmb == "cut")
     {
@@ -412,7 +412,7 @@ bool EditableWidget::handleKeyDown(StellaKey key, StellaMod mod)
     case Event::Undo:
     case Event::Redo:
     {
-      string oldString = _editString;
+      const string oldString = _editString;
 
       myUndoHandler->endChars(_editString);
       // Reverse Y and Z for QWERTZ keyboards
@@ -593,7 +593,7 @@ bool EditableWidget::adjustOffset()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-int EditableWidget::scrollOffset()
+int EditableWidget::scrollOffset() const
 {
   return _editable ? -_editScrollOffset : 0;
 }
@@ -781,7 +781,7 @@ bool EditableWidget::markWord()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const string EditableWidget::selectString() const
+string EditableWidget::selectString() const
 {
   if(_selectSize)
   {
@@ -799,7 +799,7 @@ const string EditableWidget::selectString() const
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-int EditableWidget::selectStartPos()
+int EditableWidget::selectStartPos() const
 {
   if(_selectSize < 0)
     return _caretPos + _selectSize;
@@ -808,7 +808,7 @@ int EditableWidget::selectStartPos()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-int EditableWidget::selectEndPos()
+int EditableWidget::selectEndPos() const
 {
   if(_selectSize > 0)
     return _caretPos + _selectSize;
@@ -846,7 +846,7 @@ bool EditableWidget::cutSelectedText()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool EditableWidget::copySelectedText()
 {
-  string selected = selectString();
+  const string selected = selectString();
 
   // only copy if anything is selected, else keep old copied text
   if(!selected.empty())
@@ -860,7 +860,7 @@ bool EditableWidget::copySelectedText()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 bool EditableWidget::pasteSelectedText()
 {
-  bool selected = !selectString().empty();
+  const bool selected = !selectString().empty();
   string pasted;
 
   myUndoHandler->endChars(_editString);
@@ -886,9 +886,9 @@ bool EditableWidget::pasteSelectedText()
       lastOk = false;
     }
 
-  _editString.insert(_caretPos, buf.str());
+  _editString.insert(_caretPos, buf.view());
   // position cursor at the end of pasted text
-  setCaretPos(_caretPos + static_cast<int>(buf.str().length()));
+  setCaretPos(_caretPos + static_cast<int>(buf.view().length()));
 
   if(selected || !pasted.empty())
   {
