@@ -8,37 +8,34 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //============================================================================
 
-#include <cctype>
-
+#include "bspf.hxx"
 #include "ScrollBarWidget.hxx"
-#include "FileListWidget.hxx"
 #include "TimerManager.hxx"
 #include "ProgressDialog.hxx"
 #include "FBSurface.hxx"
 #include "Bankswitch.hxx"
 
-#include "bspf.hxx"
+#include "FileListWidget.hxx"
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 FileListWidget::FileListWidget(GuiObject* boss, const GUI::Font& font,
                                int x, int y, int w, int h)
   : StringListWidget(boss, font, x, y, w, h),
-    _filter{[](const FilesystemNode&) { return true; }}
+    _filter{[](const FSNode&) { return true; }}
 {
   // This widget is special, in that it catches signals and redirects them
   setTarget(this);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FileListWidget::setDirectory(const FilesystemNode& node,
-                                  const string& select)
+void FileListWidget::setDirectory(const FSNode& node, string_view select)
 {
   _node = node;
 
@@ -56,8 +53,8 @@ void FileListWidget::setDirectory(const FilesystemNode& node,
   }
 
   // Initialize history
-  FilesystemNode tmp = _node;
-  string name = select;
+  FSNode tmp = _node;
+  string name{select};
 
   _history.clear();
   while(tmp.hasParent())
@@ -77,12 +74,11 @@ void FileListWidget::setDirectory(const FilesystemNode& node,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FileListWidget::setLocation(const FilesystemNode& node,
-                                 const string select)
+void FileListWidget::setLocation(const FSNode& node, string_view select)
 {
   progress().resetProgress();
   progress().open();
-  FilesystemNode::CancelCheck isCancelled = [this]() {
+  FSNode::CancelCheck isCancelled = [this]() {
     return myProgressDialog->isCancelled();
   };
 
@@ -96,7 +92,7 @@ void FileListWidget::setLocation(const FilesystemNode& node,
   // Now fill the list widget with the names from the file list,
   // even if cancelled
   StringList list;
-  size_t orgLen = _node.getShortPath().length();
+  const size_t orgLen = _node.getShortPath().length();
 
   _dirList.clear();
   _iconTypeList.clear();
@@ -138,13 +134,13 @@ void FileListWidget::setLocation(const FilesystemNode& node,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-bool FileListWidget::isDirectory(const FilesystemNode& node) const
+bool FileListWidget::isDirectory(const FSNode& node) const
 {
   return node.isDirectory();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FileListWidget::getChildren(const FilesystemNode::CancelCheck& isCancelled)
+void FileListWidget::getChildren(const FSNode::CancelCheck& isCancelled)
 {
   if(_includeSubDirs)
   {
@@ -160,9 +156,9 @@ void FileListWidget::getChildren(const FilesystemNode::CancelCheck& isCancelled)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-FileListWidget::IconType FileListWidget::getIconType(const string& path) const
+FileListWidget::IconType FileListWidget::getIconType(string_view path) const
 {
-  const FilesystemNode node(path);
+  const FSNode node(path);
 
   if(node.isDirectory())
   {
@@ -182,7 +178,7 @@ void FileListWidget::selectDirectory()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FileListWidget::selectDirectory(const FilesystemNode& node)
+void FileListWidget::selectDirectory(const FSNode& node)
 {
   if(node.getPath() != _node.getPath())
     addHistory(node);
@@ -192,10 +188,10 @@ void FileListWidget::selectDirectory(const FilesystemNode& node)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void FileListWidget::selectParent()
 {
-  if(_node.hasParent())
+  if(_node.hasParent() && _fsmode != FSNode::ListMode::FilesOnly)
   {
     string name = _node.getName();
-    FilesystemNode parent(_node.getParent());
+    const FSNode parent(_node.getParent());
 
     _currentHistory->selected = selected().getName();
     addHistory(parent);
@@ -247,7 +243,7 @@ bool FileListWidget::hasNextHistory()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 string& FileListWidget::fixPath(string& path)
 {
-  if(path.length() > 0 && path.back() == FilesystemNode::PATH_SEPARATOR)
+  if(!path.empty() && path.back() == FSNode::PATH_SEPARATOR)
   {
     path.pop_back();
     if(path.length() == 2 && path.back() == ':')
@@ -257,9 +253,10 @@ string& FileListWidget::fixPath(string& path)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void FileListWidget::addHistory(const FilesystemNode& node)
+void FileListWidget::addHistory(const FSNode& node)
 {
-  if (_history.size() > 0) {
+  if(!_history.empty())
+  {
     while(_currentHistory != std::prev(_history.end(), 1))
       _history.pop_back();
 
@@ -284,9 +281,9 @@ void FileListWidget::reload()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-const FilesystemNode& FileListWidget::selected()
+const FSNode& FileListWidget::selected()
 {
-  if(_fileList.size() > 0)
+  if(!_fileList.empty())
   {
     _selected = BSPF::clamp(_selected, 0U, static_cast<uInt32>(_fileList.size()-1));
     return _fileList[_selected];
@@ -324,9 +321,6 @@ bool FileListWidget::handleKeyDown(StellaKey key, StellaMod mod)
   if(StellaModTest::isAlt(mod))
   {
     handled = true;
-#ifdef DEBUG_BUILD
-    cerr << "  " << mod << ", " << key << endl;
-#endif
     switch(key)
     {
       case KBDK_HOME:
@@ -358,6 +352,8 @@ bool FileListWidget::handleKeyDown(StellaKey key, StellaMod mod)
   _lastKey = key; _lastMod = mod;
   if(_quickSelectTime < TimerManager::getTicks() / 1000)
     _firstMod = mod;
+  else if(key == KBDK_SPACE) // allow searching ROMs with a space without selecting/starting
+    handled = true;
 
   return handled;
 }
@@ -372,7 +368,10 @@ bool FileListWidget::handleText(char text)
   const bool firstShift = StellaModTest::isShift(_firstMod);
 
   if(StellaModTest::isShift(_lastMod))
-    text = *StellaKeyName::forKey(_lastKey);
+  {
+    const string_view key = StellaKeyName::forKey(_lastKey);
+    text = !key.empty() ? key.front() : '\0';
+  }
 
   if(_quickSelectTime < time)
     _quickSelectStr = text;
@@ -431,6 +430,7 @@ void FileListWidget::handleCommand(CommandSender* sender, int cmd, int data, int
       break;
 
     case ListWidget::kActivatedCmd:
+      [[fallthrough]];
     case ListWidget::kDoubleClickedCmd:
       _selected = data;
       if(isDirectory(selected())/* || !selected().exists()*/)
@@ -685,16 +685,17 @@ const FileListWidget::Icon* FileListWidget::getIcon(int i) const
     0b11111111111'11111111110,
     0b11111111111'11111111110
   };
-  static const Icon* small_icons[int(IconType::numTypes)] = {
+  const int idx = static_cast<int>(IconType::numTypes);
+  static const Icon* const small_icons[idx] = {
     &unknown_small, &rom_small, &directory_small, &zip_small, &up_small
   };
-  static const Icon* large_icons[int(IconType::numTypes)] = {
+  static const Icon* const large_icons[idx] = {
     &unknown_large, &rom_large, &directory_large, &zip_large, &up_large,
   };
   const bool smallIcon = iconWidth() < 24;
-  const int iconType = int(_iconTypeList[i]);
+  const int iconType = static_cast<int>(_iconTypeList[i]);
 
-  assert(iconType < int(IconType::numTypes));
+  assert(iconType < idx);
 
   return smallIcon ? small_icons[iconType] : large_icons[iconType];
 }
@@ -731,4 +732,4 @@ string FileListWidget::getToolTip(const Common::Point& pos) const
 uInt64 FileListWidget::_QUICK_SELECT_DELAY = 300;
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-FilesystemNode FileListWidget::ourDefaultNode = FilesystemNode("~");
+FSNode FileListWidget::ourDefaultNode = FSNode("~");
