@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -49,7 +49,7 @@ int Font::getCharWidth(uInt8 chr) const
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-int Font::getStringWidth(const string& str) const
+int Font::getStringWidth(string_view str) const
 {
   // If no width table is specified, use the maximum width
   if(!myFontDesc.width)
@@ -59,4 +59,4 @@ int Font::getStringWidth(const string& str) const
         [&](int x, char c) { return x + getCharWidth(c); });
 }
 
-}  // namespace GUI
+} // namespace GUI
