@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -39,7 +39,6 @@
 #include "repository/KeyValueRepositoryPropertyFile.hxx"
 #include "FrameBuffer.hxx"
 #include "TIASurface.hxx"
-#include "TIA.hxx"
 #include "Switches.hxx"
 #include "AudioSettings.hxx"
 #include "bspf.hxx"
@@ -112,57 +111,56 @@ void GameInfoDialog::addEmulationTab()
             VGAP       = Dialog::vGap();
   WidgetArray wid;
   VariantList items;
-  StaticTextWidget* t = nullptr;
 
   // 1) Emulation properties
-  int tabID = myTab->addTab("Emulation", TabWidget::AUTO_WIDTH);
+  const int tabID = myTab->addTab("Emulation", TabWidget::AUTO_WIDTH);
 
   int ypos = VBORDER;
 
-  t = new StaticTextWidget(myTab, _font, HBORDER, ypos + 1, "Type (*)      ");
+  myBSTypeLabel = new StaticTextWidget(myTab, _font, HBORDER, ypos + 1, "Type (*)      ");
   int pwidth = _font.getStringWidth("CM (SpectraVideo CompuMate)");
   items.clear();
-  for(uInt32 i = 0; i < static_cast<uInt32>(Bankswitch::Type::NumSchemes); ++i)
-    VarList::push_back(items, Bankswitch::BSList[i].desc, Bankswitch::BSList[i].name);
-  myBSType = new PopUpWidget(myTab, _font, t->getRight() + fontWidth, ypos,
-                             pwidth, lineHeight, items);
+  myBSType = new PopUpWidget(myTab, _font, myBSTypeLabel->getRight() + fontWidth, ypos,
+                             pwidth, lineHeight, items, "", 0, kBSTypeChanged);
   wid.push_back(myBSType);
+  myBSFilter = new CheckboxWidget(myTab, _font, myBSType->getRight() + fontWidth, ypos + 1,
+                                  "Filter", kBSFilterChanged);
+  myBSFilter->setToolTip("Enable to filter types by ROM size");
+  wid.push_back(myBSFilter);
   ypos += lineHeight + VGAP;
 
-  myTypeDetected = new StaticTextWidget(myTab, ifont, t->getRight() + fontWidth, ypos,
+  myTypeDetected = new StaticTextWidget(myTab, ifont, myBSTypeLabel->getRight() + fontWidth, ypos,
                                         "CM (SpectraVideo CompuMate) detected");
   ypos += ifont.getLineHeight() + VGAP;
 
   // Start bank
-  myStartBankLabel = new StaticTextWidget(myTab, _font, HBORDER, ypos + 1, "Start bank (*) ");
   items.clear();
-  myStartBank = new PopUpWidget(myTab, _font, myStartBankLabel->getRight(), ypos,
-                                _font.getStringWidth("AUTO"), lineHeight, items);
+  myStartBank = new PopUpWidget(myTab, _font, HBORDER, ypos,
+                                _font.getStringWidth("AUTO"), lineHeight, items, "Start bank (*) ");
   wid.push_back(myStartBank);
   ypos += lineHeight + VGAP * 4;
 
   pwidth = _font.getStringWidth("Auto-detect");
-  t = new StaticTextWidget(myTab, _font, HBORDER, ypos + 1, "TV format      ");
   items.clear();
   VarList::push_back(items, "Auto-detect", "AUTO");
   VarList::push_back(items, "NTSC", "NTSC");
   VarList::push_back(items, "PAL", "PAL");
   VarList::push_back(items, "SECAM", "SECAM");
-  VarList::push_back(items, "NTSC50", "NTSC50");
-  VarList::push_back(items, "PAL60", "PAL60");
-  VarList::push_back(items, "SECAM60", "SECAM60");
-  myFormat = new PopUpWidget(myTab, _font, t->getRight(), ypos,
-                             pwidth, lineHeight, items);
+  VarList::push_back(items, "NTSC-50", "NTSC50");
+  VarList::push_back(items, "PAL-60", "PAL60");
+  VarList::push_back(items, "SECAM-60", "SECAM60");
+  myFormat = new PopUpWidget(myTab, _font, HBORDER, ypos,
+                             pwidth, lineHeight, items, "TV format      ");
   myFormat->setToolTip(Event::FormatDecrease, Event::FormatIncrease);
   wid.push_back(myFormat);
 
   myFormatDetected = new StaticTextWidget(myTab, ifont, myFormat->getRight() + fontWidth, ypos + 4,
-                                          "SECAM60 detected");
+                                          "SECAM-60 detected");
 
   // Phosphor
   ypos += lineHeight + VGAP;
   myPhosphor = new CheckboxWidget(myTab, _font, HBORDER, ypos + 1,
-                                  "Phosphor (enabled for all ROMs)", kPhosphorChanged);
+                                  "Phosphor (auto-enabled/disabled for all ROMs)", kPhosphorChanged);
   myPhosphor->setToolTip(Event::TogglePhosphor);
   wid.push_back(myPhosphor);
 
@@ -176,8 +174,7 @@ void GameInfoDialog::addEmulationTab()
   wid.push_back(myPPBlend);
 
   ypos += lineHeight + VGAP;
-  t = new StaticTextWidget(myTab, _font, HBORDER, ypos + 1, "V-Center ");
-  myVCenter = new SliderWidget(myTab, _font, t->getRight(), ypos, "",
+  myVCenter = new SliderWidget(myTab, _font, HBORDER, ypos, "V-Center ",
                                0, kVCenterChanged, 7 * fontWidth, "px", 0, true);
 
   myVCenter->setMinValue(TIAConstants::minVcenter);
@@ -211,16 +208,16 @@ void GameInfoDialog::addConsoleTab()
   WidgetArray wid;
 
   // 2) Console properties
-  int tabID = myTab->addTab(" Console ", TabWidget::AUTO_WIDTH);
+  const int tabID = myTab->addTab(" Console ", TabWidget::AUTO_WIDTH);
 
   const int xpos = HBORDER;
   int ypos = VBORDER;
-  int lwidth = _font.getStringWidth(GUI::RIGHT_DIFFICULTY + " ");
+  const int lwidth = _font.getStringWidth(GUI::RIGHT_DIFFICULTY + " ");
 
   new StaticTextWidget(myTab, _font, xpos, ypos + 1, "TV type");
   myTVTypeGroup = new RadioButtonGroup();
-  RadioButtonWidget* r = new RadioButtonWidget(myTab, _font, xpos + lwidth, ypos + 1,
-                                               "Color", myTVTypeGroup);
+  auto* r = new RadioButtonWidget(myTab, _font, xpos + lwidth, ypos + 1,
+                                  "Color", myTVTypeGroup);
   r->setToolTip(Event::ConsoleColor, Event::ConsoleColorToggle);
   wid.push_back(r);
   ypos += lineHeight;
@@ -277,7 +274,7 @@ void GameInfoDialog::addControllersTab()
 
   // 3) Controller properties
   wid.clear();
-  int tabID = myTab->addTab("Controllers", TabWidget::AUTO_WIDTH);
+  const int tabID = myTab->addTab("Controllers", TabWidget::AUTO_WIDTH);
 
   items.clear();
   VarList::push_back(items, "Auto-detect", "AUTO");
@@ -294,6 +291,7 @@ void GameInfoDialog::addControllersTab()
   VarList::push_back(items, "AtariVox", "ATARIVOX");
   VarList::push_back(items, "SaveKey", "SAVEKEY");
   VarList::push_back(items, "Sega Genesis", "GENESIS");
+  VarList::push_back(items, "Joy2B+", "JOY_2B+");
   VarList::push_back(items, "Kid Vid", "KIDVID");
   VarList::push_back(items, "Light Gun", "LIGHTGUN");
   VarList::push_back(items, "MindLink", "MINDLINK");
@@ -430,15 +428,14 @@ void GameInfoDialog::addCartridgeTab()
             VGAP       = Dialog::vGap(),
             HGAP       = Dialog::fontWidth() / 4;
   WidgetArray wid;
-  VariantList items;
 
   wid.clear();
-  int tabID = myTab->addTab("Cartridge", TabWidget::AUTO_WIDTH);
+  const int tabID = myTab->addTab("Cartridge", TabWidget::AUTO_WIDTH);
 
   const int xpos = HBORDER;
   int ypos = VBORDER;
-  int lwidth = _font.getStringWidth("Manufacturer ");
-  const int fwidth = _w - lwidth - HBORDER * 2 - 2;
+  const int lwidth = _font.getStringWidth("Manufacturer "),
+            fwidth = _w - lwidth - HBORDER * 2 - 2;
   new StaticTextWidget(myTab, _font, xpos, ypos + 1, lwidth, fontHeight, "Name");
   myName = new EditTextWidget(myTab, _font, xpos + lwidth, ypos - 1,
                               fwidth, lineHeight, "");
@@ -476,14 +473,36 @@ void GameInfoDialog::addCartridgeTab()
   wid.push_back(myNote);
 
   ypos += lineHeight + VGAP;
+  const int bw = buttonWidth(">");
   new StaticTextWidget(myTab, _font, xpos, ypos + 1, lwidth, fontHeight, "Link");
   myUrl = new EditTextWidget(myTab, _font, xpos + lwidth, ypos - 1,
-                             fwidth - buttonWidth(">>") - HGAP, lineHeight, "");
+                             fwidth - bw - HGAP, lineHeight, "");
   myUrl->setID(kLinkId);
-  myUrlButton = new ButtonWidget(myTab, _font, _w - HBORDER - 2 - buttonWidth(">>"), ypos - 1,
-                                 buttonWidth(">>"), myUrl->getHeight(), ">>", kLinkPressed);
   wid.push_back(myUrl);
 
+  myUrlButton = new ButtonWidget(myTab, _font, _w - HBORDER - 2 - bw, ypos - 1,
+                                 bw, myUrl->getHeight(), ">>", kLinkPressed);
+  wid.push_back(myUrlButton);
+
+#ifdef IMAGE_SUPPORT
+  const GUI::Font& ifont = instance().frameBuffer().infoFont();
+
+  ypos += lineHeight + VGAP;
+  new StaticTextWidget(myTab, _font, xpos, ypos + 1, lwidth, fontHeight, "Bezelname");
+  myBezelName = new EditTextWidget(myTab, _font, xpos + lwidth, ypos - 1,
+                                   fwidth - bw - HGAP, lineHeight, "");
+  myBezelName->setToolTip("Define the name of the bezel file.");
+  wid.push_back(myBezelName);
+
+  myBezelButton = new ButtonWidget(myTab, _font, _w - HBORDER - 2 - bw, ypos - 1,
+                                   bw, myBezelName->getHeight(), ELLIPSIS, kBezelFilePressed);
+  wid.push_back(myBezelButton);
+
+  ypos += lineHeight + VGAP;
+  myBezelDetected = new StaticTextWidget(myTab, ifont, xpos + lwidth, ypos,
+    "'1234567890123456789012345678901234567' selected");
+#endif
+
   // Add items for tab 3
   addToFocusList(wid, myTab, tabID);
 
@@ -504,21 +523,20 @@ void GameInfoDialog::addHighScoresTab()
   WidgetArray wid;
   VariantList items;
 
-  int tabID = myTab->addTab("High Scores", TabWidget::AUTO_WIDTH);
+  const int tabID = myTab->addTab("High Scores", TabWidget::AUTO_WIDTH);
 
-  EditableWidget::TextFilter fAddr = [](char c) {
+  const EditableWidget::TextFilter fAddr = [](char c) {
     return (c >= 'a' && c <= 'f') || (c >= '0' && c <= '9');
   };
-  EditableWidget::TextFilter fVars = [](char c) {
+  const EditableWidget::TextFilter fVars = [](char c) {
     return (c >= '0' && c <= '9');
   };
-
-  EditableWidget::TextFilter fText = [](char c) {
+  const EditableWidget::TextFilter fText = [](char c) {
     return (c >= 'a' && c <= 'z') || (c >= ' ' && c < ',') || (c > ',' && c < '@');
   };
 
   int xpos = HBORDER, ypos = VBORDER;
-  int lwidth = _font.getStringWidth("Variations ");
+  const int lwidth = _font.getStringWidth("Variations ");
 
   myHighScores = new CheckboxWidget(myTab, _font, xpos, ypos + 1, "Enable High Scores",
                                     kHiScoresChanged);
@@ -687,7 +705,7 @@ void GameInfoDialog::addHighScoresTab()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-GameInfoDialog::~GameInfoDialog()
+GameInfoDialog::~GameInfoDialog()  // NOLINT (we need an empty d'tor)
 {
 }
 
@@ -703,9 +721,14 @@ void GameInfoDialog::loadConfig()
   {
     const string& md5 = instance().launcher().selectedRomMD5();
     instance().propSet().getMD5(md5, myGameProperties);
-    myGameFile = FilesystemNode(instance().launcher().selectedRom());
+    myGameFile = FSNode(instance().launcher().selectedRom());
   }
 
+  string title = "Game properties - " + myGameProperties.get(PropType::Cart_Name);
+  if(_font.getStringWidth(title) > getWidth() - fontWidth() * 6)
+    title = title.substr(0, getWidth() / fontWidth() - 7) + ELLIPSIS;
+  setTitle(title);
+
   loadEmulationProperties(myGameProperties);
   loadConsoleProperties(myGameProperties);
   loadControllerProperties(myGameProperties);
@@ -718,7 +741,11 @@ void GameInfoDialog::loadConfig()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void GameInfoDialog::loadEmulationProperties(const Properties& props)
 {
-  string bsDetected = "";
+  myBSFilter->setState(instance().settings().getBool("filterbstypes"));
+  updateBSTypes();
+
+  VariantList items;
+  string bsDetected;
 
   myBSType->setSelected(props.get(PropType::Cart_Type), "AUTO");
   if(myBSType->getSelectedTag().toString() == "AUTO")
@@ -734,14 +761,12 @@ void GameInfoDialog::loadEmulationProperties(const Properties& props)
     }
     else
     {
-      const FilesystemNode& node = FilesystemNode(instance().launcher().selectedRom());
       ByteBuffer image;
       string md5 = props.get(PropType::Cart_MD5);
       size_t size = 0;
 
       // try to load the image for auto detection
-      if(!instance().hasConsole() &&
-        node.exists() && !node.isDirectory() && (image = instance().openROM(node, md5, size)) != nullptr)
+      if(myGameFile.exists() && !myGameFile.isDirectory() && (image = instance().openROM(myGameFile, md5, size)) != nullptr)
       {
         bsDetected = Bankswitch::typeToDesc(CartDetector::autodetectType(image, size)) + " detected";
       }
@@ -750,8 +775,6 @@ void GameInfoDialog::loadEmulationProperties(const Properties& props)
   myTypeDetected->setLabel(bsDetected);
 
   // Start bank
-  VariantList items;
-
   VarList::push_back(items, "Auto", "AUTO");
   if(instance().hasConsole())
   {
@@ -759,17 +782,15 @@ void GameInfoDialog::loadEmulationProperties(const Properties& props)
 
     for(uInt16 i = 0; i < numBanks; ++i)
       VarList::push_back(items, i, i);
-    myStartBank->setEnabled(true);
   }
   else
   {
     const string& startBank = props.get(PropType::Cart_StartBank);
 
     VarList::push_back(items, startBank, startBank);
-    myStartBank->setEnabled(false);
   }
   myStartBank->addItems(items);
-  myStartBank->setSelected(props.get(PropType::Cart_StartBank), "AUTO");
+  myStartBank->setSelected(props.get(PropType::Cart_StartBank), "Auto");
 
   myFormat->setSelected(props.get(PropType::Display_Format), "AUTO");
   if(instance().hasConsole() && myFormat->getSelectedTag().toString() == "AUTO")
@@ -786,28 +807,30 @@ void GameInfoDialog::loadEmulationProperties(const Properties& props)
     myFormatDetected->setLabel("");
 
   // if phosphor is always enabled, disable game specific phosphor settings
-  const bool alwaysPhosphor = instance().settings().getString("tv.phosphor") == "always";
+  const string mode = instance().settings().getString(PhosphorHandler::SETTING_MODE);
   const bool usePhosphor = props.get(PropType::Display_Phosphor) == "YES";
   myPhosphor->setState(usePhosphor);
-  myPhosphor->setEnabled(!alwaysPhosphor);
-  if (alwaysPhosphor)
-    myPhosphor->setLabel("Phosphor (enabled for all ROMs)");
+  if (mode == PhosphorHandler::VALUE_ALWAYS)
+    myPhosphor->setLabel("Phosphor (enabled for all ROMs");
+  else if (mode == PhosphorHandler::VALUE_AUTO)
+    myPhosphor->setLabel("Phosphor (auto-enabled/disabled for all ROMs)");
+  else if (mode == PhosphorHandler::VALUE_AUTO_ON)
+    myPhosphor->setLabel("Phosphor (auto-enabled for all ROMs)");
   else
     myPhosphor->setLabel("Phosphor");
-  myPPBlend->setEnabled(!alwaysPhosphor && usePhosphor);
 
   const string& blend = props.get(PropType::Display_PPBlend);
-  myPPBlend->setValue(stringToInt(blend));
+  myPPBlend->setValue(BSPF::stoi(blend));
 
   // set vertical center
-  const Int32 vcenter = stringToInt(props.get(PropType::Display_VCenter));
+  const Int32 vcenter = BSPF::stoi(props.get(PropType::Display_VCenter));
   myVCenter->setValueLabel(vcenter);
   myVCenter->setValue(vcenter);
   myVCenter->setValueUnit(vcenter ? "px" : "");
 
   mySound->setState(props.get(PropType::Cart_Sound) == "STEREO");
-  // if stereo is always enabled, disable game specific stereo setting
-  mySound->setEnabled(!instance().audioSettings().stereo());
+
+  updateMultiCart();
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -830,8 +853,8 @@ void GameInfoDialog::loadControllerProperties(const Properties& props)
   mySwapPaddles->setState(props.get(PropType::Controller_SwapPaddles) == "YES");
 
   // Paddle centers
-  myPaddleXCenter->setValue(BSPF::stringToInt(props.get(PropType::Controller_PaddlesXCenter)));
-  myPaddleYCenter->setValue(BSPF::stringToInt(props.get(PropType::Controller_PaddlesYCenter)));
+  myPaddleXCenter->setValue(BSPF::stoi(props.get(PropType::Controller_PaddlesXCenter)));
+  myPaddleYCenter->setValue(BSPF::stoi(props.get(PropType::Controller_PaddlesYCenter)));
 
   // MouseAxis property (potentially contains 'range' information)
   istringstream m_axis(props.get(PropType::Controller_MouseAxis));
@@ -853,7 +876,7 @@ void GameInfoDialog::loadControllerProperties(const Properties& props)
   myMouseY->setEnabled(!autoAxis);
   if(m_axis >> m_range)
   {
-    myMouseRange->setValue(stringToInt(m_range));
+    myMouseRange->setValue(BSPF::stoi(m_range));
   }
   else
   {
@@ -874,6 +897,25 @@ void GameInfoDialog::loadCartridgeProperties(const Properties& props)
   myNote->setText(props.get(PropType::Cart_Note));
   myUrl->setText(props.get(PropType::Cart_Url));
 
+#ifdef IMAGE_SUPPORT
+  bool autoSelected = false;
+  string bezelName = props.get(PropType::Bezel_Name);
+  if(bezelName.empty())
+  {
+    bezelName = Bezel::getName(instance().bezelDir().getPath(), props);
+    if(bezelName != "default")
+      autoSelected = true;
+    else
+      bezelName = "";
+  }
+  myBezelName->setText(bezelName);
+
+  if(autoSelected)
+    myBezelDetected->setLabel("auto-selected");
+  else
+    myBezelDetected->setLabel("");
+#endif
+
   updateLink();
 }
 
@@ -905,23 +947,23 @@ void GameInfoDialog::loadHighScoresProperties(const Properties& props)
   ss.str("");
   ss << hex << right // << setw(HSM::MAX_ADDR_CHARS) << setfill(' ')
     << uppercase << info.varsAddr;
-  myVarAddress->setText(ss.str());
+  myVarAddress->setText(ss.view());
 
   ss.str("");
   ss << hex << right // << setw(HSM::MAX_ADDR_CHARS) << setfill(' ')
     << uppercase << info.specialAddr;
-  mySpecialAddress->setText(ss.str());
+  mySpecialAddress->setText(ss.view());
 
 
   for (uInt32 a = 0; a < HSM::MAX_SCORE_ADDR; ++a)
   {
     ss.str("");
-    if(a < instance().highScores().numAddrBytes(info.numDigits, info.trailingZeroes))
+    if(a < HighScoresManager::numAddrBytes(info.numDigits, info.trailingZeroes))
     {
       ss << hex << right // << setw(HSM::MAX_ADDR_CHARS) << setfill(' ')
         << uppercase << info.scoreAddr[a];
     }
-    myScoreAddress[a]->setText(ss.str());
+    myScoreAddress[a]->setText(ss.view());
   }
   updateHighScoresWidgets();
 }
@@ -929,6 +971,8 @@ void GameInfoDialog::loadHighScoresProperties(const Properties& props)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void GameInfoDialog::saveProperties()
 {
+  instance().settings().setValue("filterbstypes", myBSFilter->getState());
+
   // Emulation properties
   myGameProperties.set(PropType::Cart_Type, myBSType->getSelectedTag().toString());
   myGameProperties.set(PropType::Cart_StartBank, myStartBank->getSelectedTag().toString());
@@ -975,7 +1019,7 @@ void GameInfoDialog::saveProperties()
   if(myMouseControl->getState())
     mcontrol = myMouseX->getSelectedTag().toString() +
                myMouseY->getSelectedTag().toString();
-  string range = myMouseRange->getValueLabel();
+  const string range = myMouseRange->getValueLabel();
   if(range != "100")
     mcontrol += " " + range;
   myGameProperties.set(PropType::Controller_MouseAxis, mcontrol);
@@ -987,6 +1031,13 @@ void GameInfoDialog::saveProperties()
   myGameProperties.set(PropType::Cart_Rarity, myRarity->getText());
   myGameProperties.set(PropType::Cart_Note, myNote->getText());
   myGameProperties.set(PropType::Cart_Url, myUrl->getText());
+#ifdef IMAGE_SUPPORT
+  // avoid saving auto-selected bezel names:
+  if(myBezelName->getText() == Bezel::getName(instance().bezelDir().getPath(), myGameProperties))
+    myGameProperties.reset(PropType::Bezel_Name);
+  else
+    myGameProperties.set(PropType::Bezel_Name, myBezelName->getText());
+#endif
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -1062,20 +1113,20 @@ void GameInfoDialog::saveHighScoresProperties()
     string strAddr;
 
     strAddr = myVarAddress->getText();
-    info.varsAddr = stringToIntBase16(strAddr, HSM::DEFAULT_ADDRESS);
+    info.varsAddr = BSPF::stoi<16>(strAddr, HSM::DEFAULT_ADDRESS);
     strAddr = mySpecialAddress->getText();
-    info.specialAddr = stringToIntBase16(strAddr, HSM::DEFAULT_ADDRESS);
+    info.specialAddr = BSPF::stoi<16>(strAddr, HSM::DEFAULT_ADDRESS);
 
     for (uInt32 a = 0; a < HSM::MAX_SCORE_ADDR; ++a)
     {
       strAddr = myScoreAddress[a]->getText();
-      info.scoreAddr[a] = stringToIntBase16(strAddr, HSM::DEFAULT_ADDRESS);
+      info.scoreAddr[a] = BSPF::stoi<16>(strAddr, HSM::DEFAULT_ADDRESS);
     }
 
-    string strVars = myVariations->getText();
+    const string strVars = myVariations->getText();
 
-    instance().highScores().set(myGameProperties, stringToInt(strVars, HSM::DEFAULT_VARIATION),
-                                info);
+    HighScoresManager::set(myGameProperties, BSPF::stoi(strVars,
+      HSM::DEFAULT_VARIATION), info);
   }
   else
   {
@@ -1096,6 +1147,7 @@ void GameInfoDialog::setDefaults()
   {
     case 0: // Emulation properties
       loadEmulationProperties(defaultProperties);
+      myBSFilter->setState(true);
       break;
 
     case 1: // Console properties
@@ -1119,6 +1171,68 @@ void GameInfoDialog::setDefaults()
   }
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void GameInfoDialog::updateMultiCart()
+{
+  const std::array<string, static_cast<size_t>(Bankswitch::Type::NumMulti)> MultiCart
+    = { "2IN1", "4IN1", "8IN1", "16IN1", "32IN1", "64IN1", "128IN1" };
+  const string& selected = myBSType->getSelectedTag().toString();
+  const string& detected = myTypeDetected->getLabel();
+
+  bool isMulti = false;
+  bool isInMulti = false;
+  for (const auto& entry: MultiCart)
+  {
+    if(entry == selected)
+    {
+      isMulti = true;
+      break;
+    }
+    if(detected.find(entry + " [") != string::npos)
+    {
+      isInMulti = true;
+      break;
+    }
+  }
+
+  // en/disable Emulation tab widgets
+  myBSTypeLabel->setEnabled(!isInMulti);
+  myBSType->setEnabled(!isInMulti); // TODO: currently only auto-detected, add using properties
+  myBSFilter->setEnabled(!isInMulti);
+  myStartBank->setEnabled(!isMulti && instance().hasConsole());
+  myFormat->setEnabled(!isMulti);
+
+  // if phosphor is always enabled, disable game specific phosphor settings
+  const bool globalPhosphor = isMulti
+    || instance().settings().getString(PhosphorHandler::SETTING_MODE) != PhosphorHandler::VALUE_BYROM;
+  myPhosphor->setEnabled(!globalPhosphor);
+  myPPBlend->setEnabled(!globalPhosphor && myPhosphor->getState());
+
+  myVCenter->setEnabled(!isMulti);
+  // if stereo is always enabled, disable game specific stereo setting
+  mySound->setEnabled(!instance().audioSettings().stereo() && !isMulti);
+
+  myTab->enableTab(1, !isMulti); // en/disable Console tab
+  myTab->enableTab(2, !isMulti); // en/disable Controller tab
+  myTab->enableTab(4, !isMulti); // en/disable Highscore tab
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void GameInfoDialog::updateBSTypes()
+{
+  VariantList items;
+
+  // Bankswitching type
+  for(uInt32 i = 0; i < static_cast<uInt32>(Bankswitch::Type::NumSchemes); ++i)
+    if(!myBSFilter->getState() ||
+      ((Bankswitch::Sizes[i].minSize == Bankswitch::any_KB || myGameFile.getSize() >= Bankswitch::Sizes[i].minSize) &&
+       (Bankswitch::Sizes[i].maxSize == Bankswitch::any_KB || myGameFile.getSize() <= Bankswitch::Sizes[i].maxSize)))
+    {
+      VarList::push_back(items, Bankswitch::BSList[i].desc, Bankswitch::BSList[i].name);
+    }
+  myBSType->addItems(items);
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void GameInfoDialog::updateControllerStates()
 {
@@ -1131,11 +1245,11 @@ void GameInfoDialog::updateControllerStates()
   // try to load the image for auto detection
   if(!instance().hasConsole())
   {
-    const FilesystemNode& node = FilesystemNode(instance().launcher().selectedRom());
+    const FSNode& node = FSNode(instance().launcher().selectedRom());
 
     autoDetect = node.exists() && !node.isDirectory() && (image = instance().openROM(node, md5, size)) != nullptr;
   }
-  string label = "";
+  string label;
   Controller::Type type = Controller::getType(myLeftPort->getSelectedTag().toString());
 
   if(type == Controller::Type::Unknown)
@@ -1244,14 +1358,14 @@ void GameInfoDialog::eraseEEPROM()
   if(lport.type() == Controller::Type::SaveKey ||
      lport.type() == Controller::Type::AtariVox)
   {
-    SaveKey& skey = static_cast<SaveKey&>(lport);
+    auto& skey = static_cast<SaveKey&>(lport);
     skey.eraseCurrent();
   }
 
   if(rport.type() == Controller::Type::SaveKey ||
      rport.type() == Controller::Type::AtariVox)
   {
-    SaveKey& skey = static_cast<SaveKey&>(rport);
+    auto& skey = static_cast<SaveKey&>(rport);
     skey.eraseCurrent();
   }
 }
@@ -1259,12 +1373,12 @@ void GameInfoDialog::eraseEEPROM()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void GameInfoDialog::updateLink()
 {
-  string link = myUrl->getText();
+  const string& link = myUrl->getText();
   const bool enable = startsWithIgnoreCase(link, "http://")
     || startsWithIgnoreCase(link, "https://")
     || startsWithIgnoreCase(link, "www.");
 
-  myUrlButton->setEnabled(enable);
+  myUrlButton->setEnabled(enable && MediaFactory::supportsURL());
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -1274,7 +1388,7 @@ void GameInfoDialog::updateHighScoresWidgets()
   const bool enableVars = enable && myVariations->getText() > "1";
   const bool enableSpecial = enable && !mySpecialName->getText().empty();
   const bool enableConsole = instance().hasConsole();
-  const uInt32 numAddr = instance().highScores().numAddrBytes(
+  const uInt32 numAddr = HighScoresManager::numAddrBytes(
       myScoreDigits->getSelected() + 1, myTrailingZeroes->getSelected());
 
   // enable widgets
@@ -1286,7 +1400,7 @@ void GameInfoDialog::updateHighScoresWidgets()
   myVarAddress->setEnabled(enableVars);
   myVarAddress->setEditable(enableVars);
   myVarAddressVal->setEnabled(enableVars && enableConsole);
-  myVarsBCD->setEnabled(enableVars && stringToInt(myVariations->getText(), 1) >= 10);
+  myVarsBCD->setEnabled(enableVars && BSPF::stoi(myVariations->getText(), 1) >= 10);
   myVarsZeroBased->setEnabled(enableVars);
 
   myScoreLabel->setEnabled(enable);
@@ -1325,7 +1439,7 @@ void GameInfoDialog::updateHighScoresWidgets()
 
   // update variations RAM value
   setAddressVal(myVarAddress, myVarAddressVal, myVarsBCD->getState(),
-                myVarsZeroBased->getState(), stringToInt(myVariations->getText(), 1));
+                myVarsZeroBased->getState(), BSPF::stoi(myVariations->getText(), 1));
 
   setAddressVal(mySpecialAddress, mySpecialAddressVal, mySpecialBCD->getState(),
                 mySpecialZeroBased->getState());
@@ -1338,8 +1452,8 @@ void GameInfoDialog::updateHighScoresWidgets()
     if(a < numAddr)
     {
       setAddressVal(myScoreAddress[a], myScoreAddressVal[a]);
-      string strAddr = myScoreAddress[a]->getText();
-      scoreAddr[a] = stringToIntBase16(strAddr, HSM::DEFAULT_ADDRESS);
+      const string strAddr = myScoreAddress[a]->getText();
+      scoreAddr[a] = BSPF::stoi<16>(strAddr, HSM::DEFAULT_ADDRESS);
     }
     else
       myScoreAddressVal[a]->setText("");
@@ -1366,23 +1480,23 @@ void GameInfoDialog::setAddressVal(const EditTextWidget* addressWidget, EditText
     ostringstream ss;
 
     // convert to number and read from memory
-    const uInt16 addr = stringToIntBase16(strAddr, HSM::DEFAULT_ADDRESS);
+    const uInt16 addr = BSPF::stoi<16>(strAddr, HSM::DEFAULT_ADDRESS);
     uInt8 val = instance().highScores().peek(addr);
-    val = instance().highScores().convert(val, maxVal, isBCD, zeroBased);
+    val = HighScoresManager::convert(val, maxVal, isBCD, zeroBased);
 
     // format output and display in value widget
     // if (isBCD)
     //  ss << hex;
     ss << right // << setw(2) << setfill(' ')
       << uppercase << static_cast<uInt16>(val);
-    valWidget->setText(ss.str());
+    valWidget->setText(ss.view());
   }
   else
     valWidget->setText("");
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void GameInfoDialog::exportCurrentPropertiesToDisk(const FilesystemNode& node)
+void GameInfoDialog::exportCurrentPropertiesToDisk(const FSNode& node)
 {
   saveProperties();
 
@@ -1414,7 +1528,7 @@ void GameInfoDialog::handleCommand(CommandSender* sender, int cmd,
                           instance().userDir().getPath() +
                             myGameFile.getNameWithExt(".pro"),
                           BrowserDialog::Mode::FileSave,
-                          [this](bool OK, const FilesystemNode& node) {
+                          [this](bool OK, const FSNode& node) {
                             if(OK) exportCurrentPropertiesToDisk(node);
                           });
       break;
@@ -1445,7 +1559,7 @@ void GameInfoDialog::handleCommand(CommandSender* sender, int cmd,
 
       if(!myQuadTariDialog)
         myQuadTariDialog = make_unique<QuadTariDialog>
-          (this, _font, _font.getMaxCharWidth() * 37, _font.getFontHeight() * 8,
+          (this, _font, _font.getMaxCharWidth() * 42, _font.getFontHeight() * 10,
            myGameProperties);
       myQuadTariDialog->show(enableLeft, enableRight);
       break;
@@ -1454,6 +1568,14 @@ void GameInfoDialog::handleCommand(CommandSender* sender, int cmd,
       eraseEEPROM();
       break;
 
+    case kBSTypeChanged:
+      updateMultiCart();
+      break;
+
+    case kBSFilterChanged:
+      updateBSTypes();
+      break;
+
     case kPhosphorChanged:
     {
       const bool status = myPhosphor->getState();
@@ -1501,6 +1623,24 @@ void GameInfoDialog::handleCommand(CommandSender* sender, int cmd,
       MediaFactory::openURL(myUrl->getText());
       break;
 
+#ifdef IMAGE_SUPPORT
+    case kBezelFilePressed:
+      BrowserDialog::show(this, _font, "Select bezel image",
+                          instance().bezelDir().getPath() + myBezelName->getText(),
+                          BrowserDialog::Mode::FileLoadNoDirs,
+                          [this](bool OK, const FSNode& node) {
+                            if(OK)
+                            {
+                              myBezelName->setText(node.getNameWithExt(""));
+                              myBezelDetected->setLabel("");
+                            }
+                          },
+                          [](const FSNode& node) {
+                            return BSPF::endsWithIgnoreCase(node.getName(), ".png");
+                          });
+      break;
+#endif
+
     case EditTextWidget::kChangedCmd:
       if(id == kLinkId)
       {
