@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -60,16 +60,16 @@ HelpDialog::HelpDialog(OSystem& osystem, DialogContainer& parent,
 
   xpos += buttonWidth + fontWidth;
 
-  int updButtonWidth = Dialog::buttonWidth("Check for Update" + ELLIPSIS);
+  const int updButtonWidth = Dialog::buttonWidth("Check for Update" + ELLIPSIS);
   myUpdateButton =
     new ButtonWidget(this, font, xpos, ypos, updButtonWidth, buttonHeight,
                      "Check for Update" + ELLIPSIS, kUpdateCmd);
+  myUpdateButton->setEnabled(MediaFactory::supportsURL());
   wid.push_back(myUpdateButton);
 
   xpos = _w - closeButtonWidth - HBORDER;
-  ButtonWidget* b =
-    new ButtonWidget(this, font, xpos, ypos, closeButtonWidth, buttonHeight,
-                     "Close", GuiObject::kCloseCmd);
+  auto* b = new ButtonWidget(this, font, xpos, ypos, closeButtonWidth,
+                             buttonHeight, "Close", GuiObject::kCloseCmd);
   wid.push_back(b);
   addCancelWidget(b);
 
@@ -99,18 +99,18 @@ HelpDialog::HelpDialog(OSystem& osystem, DialogContainer& parent,
 void HelpDialog::updateStrings(uInt8 page, uInt8 lines, string& title)
 {
   int i = 0;
-  const auto ADD_BIND = [&](const string& k, const string& d)
+  const auto ADD_BIND = [&](string_view k, string_view d)
   {
     myKeyStr[i] = k;  myDescStr[i] = d;  i++;
   };
   const auto ADD_EVENT = [&](const Event::Type e, const string & d)
   {
     string desc = instance().eventHandler().getMappingDesc(e, EventMode::kEmulationMode);
-    if(!desc.length())
+    if(desc.empty())
       desc = instance().eventHandler().getMappingDesc(e, EventMode::kMenuMode);
-    ADD_BIND(desc.length() ? desc : "None", d);
+    ADD_BIND(!desc.empty() ? desc : "None", d);
   };
-  const auto ADD_TEXT = [&](const string& d) { ADD_BIND("", d); };
+  const auto ADD_TEXT = [&](string_view d) { ADD_BIND("", d); };
   const auto ADD_LINE = [&]() { ADD_BIND("", ""); };
 
   setHelpAnchor("Hotkeys");
