@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -117,36 +117,37 @@ HighScoresDialog::HighScoresDialog(OSystem& osystem, DialogContainer& parent,
             HBORDER      = Dialog::hBorder(),
             VGAP         = Dialog::vGap();
   const int xposRank = HBORDER;
-  int xposScore = xposRank + _font.getStringWidth("Rank");
-  int xposSpecial = xposScore + _font.getStringWidth("   Score  ");
-  int xposName = xposSpecial + _font.getStringWidth("Round  ");
-  int xposDate = xposName + _font.getStringWidth("Name  ");
-  int xposDelete = xposDate + _font.getStringWidth("YY-MM-DD HH:MM  ");
-  int nWidth = _font.getStringWidth("ABC") + fontWidth * 0.75;
+  const int xposScore = xposRank + _font.getStringWidth("Rank");
+  const int xposSpecial = xposScore + _font.getStringWidth("   Score  ");
+  const int xposName = xposSpecial + _font.getStringWidth("Round  ");
+  const int xposDate = xposName + _font.getStringWidth("Name  ");
+  const int xposDelete = xposDate + _font.getStringWidth("YY-MM-DD HH:MM  ");
+  const int nWidth = _font.getStringWidth("ABC") + fontWidth * 0.75;
   const bool smallFont = _font.getFontHeight() < 24;
   const int buttonSize = smallFont ? BUTTON_GFX_H : BUTTON_GFX_H_LARGE;
   WidgetArray wid;
-  VariantList items;
+  const VariantList items;
 
   const int xpos = HBORDER;
   int ypos = VBORDER + _th;
   ypos += lineHeight + VGAP * 2; // space for game name
 
-  StaticTextWidget* s = new StaticTextWidget(this, _font, xpos, ypos + 1, "Variation ");
+  auto* s = new StaticTextWidget(this, _font, xpos, ypos + 1, "Variation ");
   myVariationPopup = new PopUpWidget(this, _font, s->getRight(), ypos,
-                                      _font.getStringWidth("256"), lineHeight, items, "", 0,
-                                      kVariationChanged);
+      _font.getStringWidth("256"), lineHeight, items, "", 0, kVariationChanged);
   wid.push_back(myVariationPopup);
   const int bWidth = fontWidth * 5;
-  myPrevVarButton = new ButtonWidget(this, _font, xposDelete + fontWidth * 2 - bWidth * 2 - BUTTON_GAP, ypos - 1,
-                                     bWidth, myVariationPopup->getHeight(),
-                                     smallFont ? PREV_GFX.data() : PREV_GFX_LARGE.data(),
-                                     buttonSize, buttonSize, kPrevVariation);
+  myPrevVarButton = new ButtonWidget(this, _font,
+      xposDelete + fontWidth * 2 - bWidth * 2 - BUTTON_GAP, ypos - 1,
+      bWidth, myVariationPopup->getHeight(),
+      smallFont ? PREV_GFX.data() : PREV_GFX_LARGE.data(),
+      buttonSize, buttonSize, kPrevVariation);
   wid.push_back(myPrevVarButton);
-  myNextVarButton = new ButtonWidget(this, _font, xposDelete + fontHeight - bWidth, ypos - 1,
-                                     bWidth, myVariationPopup->getHeight(),
-                                     smallFont ? NEXT_GFX.data() : NEXT_GFX_LARGE.data(),
-                                     buttonSize, buttonSize, kNextVariation);
+  myNextVarButton = new ButtonWidget(this, _font,
+      xposDelete + fontHeight - bWidth, ypos - 1,
+      bWidth, myVariationPopup->getHeight(),
+      smallFont ? NEXT_GFX.data() : NEXT_GFX_LARGE.data(),
+      buttonSize, buttonSize, kNextVariation);
   wid.push_back(myNextVarButton);
 
   ypos += lineHeight + VGAP * 4;
@@ -211,7 +212,7 @@ HighScoresDialog::HighScoresDialog(OSystem& osystem, DialogContainer& parent,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-HighScoresDialog::~HighScoresDialog()
+HighScoresDialog::~HighScoresDialog()  // NOLINT (we need an empty d'tor)
 {
 }
 
@@ -234,7 +235,7 @@ void HighScoresDialog::loadConfig()
   {
     ostringstream buf;
     buf << std::setw(3) << std::setfill(' ') << i;
-    VarList::push_back(items, buf.str(), i);
+    VarList::push_back(items, buf.view(), i);
   }
   myVariationPopup->addItems(items);
 
@@ -403,7 +404,7 @@ void HighScoresDialog::updateWidgets(bool init)
     if (myScores.scores[r].special > 0)
       buf << std::setw(HSM::MAX_SPECIAL_DIGITS) << std::setfill(' ')
       << myScores.scores[r].special;
-    mySpecialWidgets[r]->setLabel(buf.str());
+    mySpecialWidgets[r]->setLabel(buf.view());
 
     myNameWidgets[r]->setLabel(myScores.scores[r].name);
     myDateWidgets[r]->setLabel(myScores.scores[r].date);
@@ -508,9 +509,9 @@ bool HighScoresDialog::handleDirty()
     {
       StringList msg;
 
-      msg.push_back("Do you want to save the changes");
-      msg.push_back("for this variation?");
-      msg.push_back("");
+      msg.emplace_back("Do you want to save the changes");
+      msg.emplace_back("for this variation?");
+      msg.emplace_back("");
       myConfirmMsg = make_unique<GUI::MessageBox>
         (this, _font, msg, _max_w, _max_h, kConfirmSave, kCancelSave,
          "Yes", "No", "Save High Scores", false);
@@ -539,9 +540,9 @@ string HighScoresDialog::cartName() const
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-string HighScoresDialog::now() const
+string HighScoresDialog::now()
 {
-  std::tm now = BSPF::localTime();
+  const std::tm now = BSPF::localTime();
   ostringstream ss;
 
   ss << std::setfill('0') << std::right
