@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -19,7 +19,6 @@
 #include "OSystem.hxx"
 #include "Console.hxx"
 #include "EventHandler.hxx"
-#include "Joystick.hxx"
 #include "Paddles.hxx"
 #include "MindLink.hxx"
 #include "PointingDevice.hxx"
@@ -28,7 +27,6 @@
 #include "AtariVox.hxx"
 #include "Settings.hxx"
 #include "EventMappingWidget.hxx"
-#include "EditTextWidget.hxx"
 #include "JoystickDialog.hxx"
 #include "PopUpWidget.hxx"
 #include "TabWidget.hxx"
@@ -53,7 +51,7 @@ InputDialog::InputDialog(OSystem& osystem, DialogContainer& parent,
             VGAP         = Dialog::vGap();
 
   // Set real dimensions
-  setSize(48 * fontWidth + PopUpWidget::dropDownWidth(_font) + HBORDER * 2,
+  setSize(49 * fontWidth + PopUpWidget::dropDownWidth(_font) + HBORDER * 2,
           _th + VGAP * 3 + lineHeight + 13 * (lineHeight + VGAP) + VGAP * 9 + buttonHeight + VBORDER * 3,
           max_w, max_h);
 
@@ -66,7 +64,7 @@ InputDialog::InputDialog(OSystem& osystem, DialogContainer& parent,
   addTabWidget(myTab);
 
   // 1) Event mapper
-  int tabID = myTab->addTab(" Event Mappings ", TabWidget::AUTO_WIDTH);
+  const int tabID = myTab->addTab(" Event Mappings ", TabWidget::AUTO_WIDTH);
   myEventMapper = new EventMappingWidget(myTab, _font, 2, 2,
                                              myTab->getWidth(),
                                              myTab->getHeight() - VGAP);
@@ -93,7 +91,7 @@ InputDialog::InputDialog(OSystem& osystem, DialogContainer& parent,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-InputDialog::~InputDialog()
+InputDialog::~InputDialog()  // NOLINT (we need an empty d'tor)
 {
 }
 
@@ -110,7 +108,7 @@ void InputDialog::addDevicePortTab()
   WidgetArray wid;
 
   // Devices/ports
-  int tabID = myTab->addTab(" Devices & Ports ", TabWidget::AUTO_WIDTH);
+  const int tabID = myTab->addTab(" Devices & Ports ", TabWidget::AUTO_WIDTH);
 
   int xpos = HBORDER, ypos = VBORDER;
   int lwidth = _font.getStringWidth("Digital paddle sensitivity ");
@@ -256,8 +254,9 @@ void InputDialog::addDevicePortTab()
   ypos += lineHeight + VGAP * 3;
   lwidth = _font.getStringWidth("AtariVox serial port ");
   fwidth = _w - HBORDER * 2 - 2 - lwidth - PopUpWidget::dropDownWidth(_font);
-  myAVoxPort = new PopUpWidget(myTab, _font, HBORDER, ypos, fwidth, lineHeight, EmptyVarList,
-                               "AtariVox serial port ", lwidth, kCursorStateChanged);
+  myAVoxPort = new PopUpWidget(myTab, _font, HBORDER, ypos, fwidth, lineHeight,
+                  VariantList{}, "AtariVox serial port ", lwidth,
+                  kCursorStateChanged);
   myAVoxPort->setEditable(true);
   wid.push_back(myAVoxPort);
 
@@ -281,11 +280,11 @@ void InputDialog::addMouseTab()
   VariantList items;
 
   // Mouse
-  int tabID = myTab->addTab("  Mouse  ", TabWidget::AUTO_WIDTH);
+  const int tabID = myTab->addTab("  Mouse  ", TabWidget::AUTO_WIDTH);
 
   int xpos = HBORDER, ypos = VBORDER;
   int lwidth = _font.getStringWidth("Use mouse as a controller ");
-  int pwidth = _font.getStringWidth("-UI, -Emulation");
+  const int pwidth = _font.getStringWidth("-UI, -Emulation");
 
   // Use mouse as controller
   VarList::push_back(items, "Always", "always");
@@ -417,7 +416,7 @@ void InputDialog::loadConfig()
     VarList::push_back(items, port, port);
   if(avoxport != EmptyString && !BSPF::contains(ports, avoxport))
     VarList::push_back(items, avoxport, avoxport);
-  if(items.size() == 0)
+  if(items.empty())
     VarList::push_back(items, "None detected");
 
   myAVoxPort->addItems(items);
@@ -695,13 +694,13 @@ void InputDialog::eraseEEPROM()
 
   if(lport.type() == Controller::Type::SaveKey || lport.type() == Controller::Type::AtariVox)
   {
-    SaveKey& skey = static_cast<SaveKey&>(lport);
+    auto& skey = static_cast<SaveKey&>(lport);
     skey.eraseCurrent();
   }
 
   if(rport.type() == Controller::Type::SaveKey || rport.type() == Controller::Type::AtariVox)
   {
-    SaveKey& skey = static_cast<SaveKey&>(rport);
+    auto& skey = static_cast<SaveKey&>(rport);
     skey.eraseCurrent();
   }
 }
@@ -727,18 +726,20 @@ void InputDialog::handleCommand(CommandSender* sender, int cmd,
       break;
 
     case kDDeadzoneChanged:
-      myDigitalDeadzone->setValueLabel(std::round(Controller::digitalDeadZoneValue(myDigitalDeadzone->getValue()) * 100.f /
-                                       (Paddles::ANALOG_RANGE / 2)));
+      myDigitalDeadzone->setValueLabel(std::round(
+          Controller::digitalDeadZoneValue(myDigitalDeadzone->getValue()) *
+          100.F / (Paddles::ANALOG_RANGE / 2)));  // NOLINT
       break;
 
     case kADeadzoneChanged:
-      myAnalogDeadzone->setValueLabel(std::round(Controller::analogDeadZoneValue(myAnalogDeadzone->getValue()) * 100.f /
-                                      (Paddles::ANALOG_RANGE / 2)));
+      myAnalogDeadzone->setValueLabel(std::round(
+          Controller::analogDeadZoneValue(myAnalogDeadzone->getValue()) *
+          100.F / (Paddles::ANALOG_RANGE / 2)));  // NOLINT
       break;
 
     case kPSpeedChanged:
       myPaddleSpeed->setValueLabel(std::round(Paddles::setAnalogSensitivity(
-            myPaddleSpeed->getValue()) * 100.F));
+          myPaddleSpeed->getValue()) * 100.F));
       break;
 
     case kDejitterAvChanged:
@@ -780,13 +781,13 @@ void InputDialog::handleCommand(CommandSender* sender, int cmd,
       if(!myConfirmMsg)
       {
         StringList msg;
-        msg.push_back("This operation cannot be undone.");
-        msg.push_back("All data stored on your AtariVox");
-        msg.push_back("or SaveKey will be erased!");
-        msg.push_back("");
-        msg.push_back("If you are sure you want to erase");
-        msg.push_back("the data, click 'OK', otherwise ");
-        msg.push_back("click 'Cancel'.");
+        msg.emplace_back("This operation cannot be undone.");
+        msg.emplace_back("All data stored on your AtariVox");
+        msg.emplace_back("or SaveKey will be erased!");
+        msg.emplace_back("");
+        msg.emplace_back("If you are sure you want to erase");
+        msg.emplace_back("the data, click 'OK', otherwise ");
+        msg.emplace_back("click 'Cancel'.");
         myConfirmMsg = make_unique<GUI::MessageBox>
           (this, instance().frameBuffer().font(), msg,
            myMaxWidth, myMaxHeight, kConfirmEEEraseCmd,
