@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -29,7 +29,7 @@
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 InputTextDialog::InputTextDialog(GuiObject* boss, const GUI::Font& font,
-                                 const StringList& labels, const string& title)
+                                 const StringList& labels, string_view title)
   : Dialog(boss->instance(), boss->parent(), font, title),
     CommandSender(boss)
 {
@@ -39,7 +39,7 @@ InputTextDialog::InputTextDialog(GuiObject* boss, const GUI::Font& font,
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 InputTextDialog::InputTextDialog(GuiObject* boss, const GUI::Font& lfont,
                                  const GUI::Font& nfont,
-                                 const StringList& labels, const string& title)
+                                 const StringList& labels, string_view title)
   : Dialog(boss->instance(), boss->parent(), lfont, title),
     CommandSender(boss)
 {
@@ -48,22 +48,18 @@ InputTextDialog::InputTextDialog(GuiObject* boss, const GUI::Font& lfont,
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 InputTextDialog::InputTextDialog(OSystem& osystem, DialogContainer& parent,
-                                 const GUI::Font& font, const string& label,
-                                 const string& title, int numInput)
+                                 const GUI::Font& font, const StringList& labels,
+                                 string_view title, int widthChars)
   : Dialog(osystem, parent, font, title),
     CommandSender(nullptr)
 {
-  StringList labels;
-
   clear();
-  labels.push_back(label);
-  initialize(font, font, labels,
-             static_cast<int>(label.length()) + (numInput ? numInput : 24) + 2, numInput);
+  initialize(font, font, labels, widthChars);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void InputTextDialog::initialize(const GUI::Font& lfont, const GUI::Font& nfont,
-                                 const StringList& labels, int widthChars, int numInput)
+                                 const StringList& labels, int widthChars)
 {
   const int lineHeight   = Dialog::lineHeight(),
             fontHeight   = Dialog::fontHeight(),
@@ -77,7 +73,9 @@ void InputTextDialog::initialize(const GUI::Font& lfont, const GUI::Font& nfont,
 
   // Calculate real dimensions
   _w = HBORDER * 2 + fontWidth * widthChars;
-  _h = buttonHeight + lineHeight + VGAP + static_cast<int>(labels.size()) * (lineHeight + VGAP) + _th + VBORDER * 2;
+  _h = buttonHeight + lineHeight + VGAP
+    + static_cast<int>(labels.size()) * (lineHeight + VGAP)
+    + _th + VBORDER * 2;
 
   // Determine longest label
   size_t maxIdx = 0;
@@ -89,24 +87,21 @@ void InputTextDialog::initialize(const GUI::Font& lfont, const GUI::Font& nfont,
       maxIdx = i;
     }
   }
-  if(labels.size())
+  if(!labels.empty())
     lwidth = lfont.getStringWidth(labels[maxIdx]);
 
   // Create editboxes for all labels
   int ypos = VBORDER + _th;
-  for(size_t i = 0; i < labels.size(); ++i)
+  for(const auto& label: labels)
   {
     xpos = HBORDER;
-    StaticTextWidget* s = new StaticTextWidget(this, lfont, xpos, ypos + 2,
-                                               lwidth, fontHeight,
-                                               labels[i]);
+    auto* s = new StaticTextWidget(this, lfont, xpos, ypos + 2,
+                                   lwidth, fontHeight, label);
     myLabel.push_back(s);
 
     xpos += lwidth + fontWidth;
-    EditTextWidget* w = new EditTextWidget(this, nfont, xpos, ypos,
-                                           _w - xpos - HBORDER, lineHeight, "");
-    if(numInput)
-      w->setMaxLen(numInput);
+    auto* w = new EditTextWidget(this, nfont, xpos, ypos,
+                                 _w - xpos - HBORDER, lineHeight);
     wid.push_back(w);
 
     myInput.push_back(w);
@@ -114,8 +109,7 @@ void InputTextDialog::initialize(const GUI::Font& lfont, const GUI::Font& nfont,
   }
 
   xpos = HBORDER; ypos += VGAP;
-  myMessage = new StaticTextWidget(this, lfont, xpos, ypos, _w - 2 * xpos, fontHeight,
-                                 "", TextAlign::Left);
+  myMessage = new StaticTextWidget(this, lfont, xpos, ypos, _w - 2 * xpos, fontHeight);
   myMessage->setTextColor(kTextColorEm);
 
   addToFocusList(wid);
@@ -167,7 +161,7 @@ void InputTextDialog::setPosition()
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void InputTextDialog::setMessage(const string& title)
+void InputTextDialog::setMessage(string_view title)
 {
   myMessage->setLabel(title);
   myErrorFlag = true;
@@ -183,7 +177,7 @@ const string& InputTextDialog::getResult(int idx)
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void InputTextDialog::setText(const string& str, int idx)
+void InputTextDialog::setText(string_view str, int idx)
 {
   if(static_cast<uInt32>(idx) < myInput.size())
     myInput[idx]->setText(str);
@@ -197,7 +191,14 @@ void InputTextDialog::setTextFilter(const EditableWidget::TextFilter& f, int idx
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void InputTextDialog::setToolTip(const string& str, int idx)
+void InputTextDialog::setMaxLen(int len, int idx)
+{
+  myInput[idx]->setMaxLen(len);
+  myInput[idx]->setWidth((len + 1) * Dialog::fontWidth());
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void InputTextDialog::setToolTip(string_view str, int idx)
 {
   if(static_cast<uInt32>(idx) < myLabel.size())
     myLabel[idx]->setToolTip(str);
@@ -210,6 +211,12 @@ void InputTextDialog::setFocus(int idx)
     Dialog::setFocus(getFocusList()[idx]);
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void InputTextDialog::setEditable(bool editable, int idx)
+{
+  myInput[idx]->setEditable(editable);
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void InputTextDialog::handleCommand(CommandSender* sender, int cmd,
                                     int data, int id)
