@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -21,8 +21,6 @@
 #include "Dialog.hxx"
 #include "DialogContainer.hxx"
 #include "Widget.hxx"
-#include "Font.hxx"
-#include "Control.hxx"
 #include "EmulationDialog.hxx"
 #include "VideoAudioDialog.hxx"
 #include "InputDialog.hxx"
@@ -53,7 +51,8 @@ OptionsDialog::OptionsDialog(OSystem& osystem, DialogContainer& parent,
     myMode{mode}
 {
   // do not show basic settings options in debugger
-  bool minSettings = osystem.settings().getBool("minimal_ui") && mode != AppMode::debugger;
+  const bool minSettings = osystem.settings().getBool("minimal_ui")
+    && mode != AppMode::debugger;
   const int buttonHeight = Dialog::buttonHeight(),
             VBORDER      = Dialog::vBorder(),
             HBORDER      = Dialog::hBorder(),
@@ -66,67 +65,83 @@ OptionsDialog::OptionsDialog(OSystem& osystem, DialogContainer& parent,
 
   int xoffset = HBORDER, yoffset = VBORDER + _th;
   WidgetArray wid;
-  ButtonWidget* b = nullptr;
+  ButtonWidget* b{nullptr};
 
   if (minSettings)
   {
-    ButtonWidget* bw = new ButtonWidget(this, _font, xoffset, yoffset,
-      _w - HBORDER * 2, buttonHeight, "Use Basic Settings", kBasSetCmd);
+    auto* bw = new ButtonWidget(this, _font, xoffset, yoffset,
+        _w - HBORDER * 2, buttonHeight, "Use Basic Settings", kBasSetCmd);
     wid.push_back(bw);
     yoffset += rowHeight + VGAP * 2;
     _h += rowHeight + VGAP * 2;
   }
 
-  const auto ADD_OD_BUTTON = [&](const string& label, int cmd)
+  const auto ADD_OD_BUTTON = [&](string_view label, int cmd, string_view toolTip = EmptyString)
   {
-    ButtonWidget* bw = new ButtonWidget(this, _font, xoffset, yoffset,
-            buttonWidth, buttonHeight, label, cmd);
+    auto* bw = new ButtonWidget(this, _font, xoffset, yoffset,
+                                buttonWidth, buttonHeight, label, cmd);
+    bw->setToolTip(toolTip);
     yoffset += rowHeight;
     return bw;
   };
 
-  b = ADD_OD_BUTTON("Video & Audio" + ELLIPSIS, kVidCmd);
+  b = ADD_OD_BUTTON("Video & Audio" + ELLIPSIS, kVidCmd,
+    "Change display modes, colors, TV effects,\n"
+    "volume, stereo mode" + ELLIPSIS);
   wid.push_back(b);
 
-  b = ADD_OD_BUTTON("Emulation" + ELLIPSIS, kEmuCmd);
+  b = ADD_OD_BUTTON("Emulation" + ELLIPSIS, kEmuCmd,
+    "Change emulation speed, save state settings" + ELLIPSIS);
   wid.push_back(b);
 
-  b = ADD_OD_BUTTON("Input" + ELLIPSIS, kInptCmd);
+  b = ADD_OD_BUTTON("Input" + ELLIPSIS, kInptCmd,
+    "Map and configure keyboard, mouse and controllers.");
   wid.push_back(b);
 
-  b = ADD_OD_BUTTON("User Interface" + ELLIPSIS, kUsrIfaceCmd);
+  b = ADD_OD_BUTTON("User Interface" + ELLIPSIS, kUsrIfaceCmd,
+    "Change themes, fonts, launcher layout\n"
+    "and paths for ROMs and images.");
   wid.push_back(b);
 
-  b = ADD_OD_BUTTON("Snapshots" + ELLIPSIS, kSnapCmd);
+  b = ADD_OD_BUTTON("Snapshots" + ELLIPSIS, kSnapCmd,
+    "Define snapshot save location, format" + ELLIPSIS);
   wid.push_back(b);
 
   //yoffset += rowHeight;
-  b = ADD_OD_BUTTON("Developer" + ELLIPSIS, kDevelopCmd);
+  b = ADD_OD_BUTTON("Developer" + ELLIPSIS, kDevelopCmd,
+    "Change options which support programming Atari 2600 games.");
   wid.push_back(b);
 
   // Move to second column
   xoffset += buttonWidth + HGAP;
   yoffset = minSettings ? VBORDER + _th + rowHeight + VGAP * 2 : VBORDER + _th;
 
-  myGameInfoButton = ADD_OD_BUTTON("Game Properties" + ELLIPSIS, kInfoCmd);
+  myGameInfoButton = ADD_OD_BUTTON("Game Properties" + ELLIPSIS, kInfoCmd,
+    "Change game-specific info and options (TV format,\n"
+    "console switches, controllers" + ELLIPSIS + ")");
   wid.push_back(myGameInfoButton);
 
-  myCheatCodeButton = ADD_OD_BUTTON("Cheat Codes" + ELLIPSIS, kCheatCmd);
+  myCheatCodeButton = ADD_OD_BUTTON("Cheat Codes" + ELLIPSIS, kCheatCmd,
+    "Use and manage cheat codes.");
 #ifndef CHEATCODE_SUPPORT
   myCheatCodeButton->clearFlags(Widget::FLAG_ENABLED);
 #endif
   wid.push_back(myCheatCodeButton);
 
-  myRomAuditButton = ADD_OD_BUTTON("Audit ROMs" + ELLIPSIS, kAuditCmd);
+  myRomAuditButton = ADD_OD_BUTTON("Audit ROMs" + ELLIPSIS, kAuditCmd,
+    "Rename your ROMs according to Stella's internal database.");
   wid.push_back(myRomAuditButton);
 
-  b = ADD_OD_BUTTON("System Logs" + ELLIPSIS, kLoggerCmd);
+  b = ADD_OD_BUTTON("System Logs" + ELLIPSIS, kLoggerCmd,
+    "Configure, view and save Stella's system log.");
   wid.push_back(b);
 
-  b = ADD_OD_BUTTON("Help" + ELLIPSIS, kHelpCmd);
+  b = ADD_OD_BUTTON("Help" + ELLIPSIS, kHelpCmd,
+    "Display Stella's essential keyboard commands.");
   wid.push_back(b);
 
-  b = ADD_OD_BUTTON("About" + ELLIPSIS, kAboutCmd);
+  b = ADD_OD_BUTTON("About" + ELLIPSIS, kAboutCmd,
+    "Display info about the installed Stella version.");
   wid.push_back(b);
 
   buttonWidth = Dialog::buttonWidth("   Close   ");
@@ -151,7 +166,7 @@ OptionsDialog::OptionsDialog(OSystem& osystem, DialogContainer& parent,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-OptionsDialog::~OptionsDialog()
+OptionsDialog::~OptionsDialog()  // NOLINT (we need an empty d'tor)
 {
 }
 
@@ -167,7 +182,7 @@ void OptionsDialog::loadConfig()
       myGameInfoButton->setFlags(Widget::FLAG_ENABLED);
       break;
     case EventHandlerState::LAUNCHER:
-      if(instance().launcher().selectedRomMD5() != "")
+      if(!instance().launcher().selectedRomMD5().empty())
         myGameInfoButton->setFlags(Widget::FLAG_ENABLED);
       else
         myGameInfoButton->clearFlags(Widget::FLAG_ENABLED);
@@ -279,7 +294,7 @@ void OptionsDialog::handleCommand(CommandSender* sender, int cmd,
     case kLoggerCmd:
     {
       uInt32 w = 0, h = 0;
-      bool uselargefont = getDynamicBounds(w, h);
+      const bool uselargefont = getDynamicBounds(w, h);
 
       myDialog = make_unique<LoggerDialog>(instance(), parent(), _font, w, h, uselargefont);
       myDialog->open();
