@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -28,7 +28,7 @@
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 ProgressDialog::ProgressDialog(GuiObject* boss, const GUI::Font& font,
-                               const string& message)
+                               string_view message)
   : Dialog(boss->instance(), boss->parent(), font)
 {
   const int lineHeight   = Dialog::lineHeight(),
@@ -58,16 +58,16 @@ ProgressDialog::ProgressDialog(GuiObject* boss, const GUI::Font& font,
   mySlider->setMaxValue(100);
 
   ypos += lineHeight + VGAP * 4;
-  ButtonWidget* b = new ButtonWidget(this, font, (_w - buttonWidth) / 2, ypos,
-                                     buttonWidth, buttonHeight, "Cancel",
-                                     Event::UICancel);
+  auto* b = new ButtonWidget(this, font, (_w - buttonWidth) / 2, ypos,
+                             buttonWidth, buttonHeight, "Cancel",
+                             Event::UICancel);
   wid.push_back(b);
   addCancelWidget(b);
   addToFocusList(wid);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void ProgressDialog::setMessage(const string& message)
+void ProgressDialog::setMessage(string_view message)
 {
   const int buttonWidth  = Dialog::buttonWidth("Cancel"),
             HBORDER      = Dialog::hBorder();
