@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -27,7 +27,6 @@
 #include "MessageBox.hxx"
 #include "OSystem.hxx"
 #include "FrameBuffer.hxx"
-#include "MD5.hxx"
 #include "Props.hxx"
 #include "PropsSet.hxx"
 #include "Settings.hxx"
@@ -57,9 +56,8 @@ RomAuditDialog::RomAuditDialog(OSystem& osystem, DialogContainer& parent,
   _h = _th + VBORDER * 2 + buttonHeight * 2 + lineHeight * 3 + VGAP * 10;
 
   // Audit path
-  ButtonWidget* romButton =
-    new ButtonWidget(this, font, HBORDER, ypos, buttonWidth, buttonHeight,
-                     "Audit path" + ELLIPSIS, kChooseAuditDirCmd);
+  auto* romButton = new ButtonWidget(this, font, HBORDER, ypos,
+      buttonWidth, buttonHeight, "Audit path" + ELLIPSIS, kChooseAuditDirCmd);
   wid.push_back(romButton);
   myRomPath = new EditTextWidget(this, font, xpos, ypos + (buttonHeight - lineHeight) / 2 - 1,
                                  _w - xpos - HBORDER, lineHeight);
@@ -88,7 +86,7 @@ RomAuditDialog::RomAuditDialog(OSystem& osystem, DialogContainer& parent,
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-RomAuditDialog::~RomAuditDialog()
+RomAuditDialog::~RomAuditDialog()  // NOLINT (we need an empty d'tor)
 {
 }
 
@@ -97,7 +95,7 @@ void RomAuditDialog::loadConfig()
 {
   const string& currentdir =
     instance().launcher().currentDir().getShortPath();
-  const string& path = currentdir == "" ?
+  const string& path = currentdir.empty() ?
     instance().settings().getString("romdir") : currentdir;
 
   myRomPath->setText(path);
@@ -112,21 +110,25 @@ void RomAuditDialog::auditRoms()
   myResults1->setText("");
   myResults2->setText("");
 
-  FilesystemNode node(auditPath);
-  FSList files;
+  const FSNode node(auditPath);
+  FSList files;  // NOLINT (files is not a const)
   files.reserve(2048);
-  node.getChildren(files, FilesystemNode::ListMode::FilesOnly);
+  node.getChildren(files, FSNode::ListMode::FilesOnly);
 
   // Create a progress dialog box to show the progress of processing
   // the ROMs, since this is usually a time-consuming operation
+  // NOLINTBEGIN (the following are not a const)
   ostringstream buf;
   ProgressDialog progress(this, instance().frameBuffer().font());
+  // NOLINTEND
 
   buf << "Auditing ROM files" << ELLIPSIS;
-  progress.setMessage(buf.str());
+  progress.setMessage(buf.view());
   progress.setRange(0, static_cast<int>(files.size()) - 1, 5);
   progress.open();
 
+  // NOLINTBEGIN: several variables are tagged as const by clang-tidy,
+  //              but they obviously cannot be; suspect a bug in the tool
   Properties props;
   uInt32 renamed = 0, notfound = 0;
   for(uInt32 idx = 0; idx < files.size() && !progress.isCancelled(); ++idx)
@@ -139,13 +141,13 @@ void RomAuditDialog::auditRoms()
 
       // Calculate the MD5 so we can get the rest of the info
       // from the PropertiesSet (stella.pro)
-      const string& md5 = instance().getROMMD5(files[idx]);
+      const string& md5 = OSystem::getROMMD5(files[idx]);
       if(instance().propSet().getMD5(md5, props))
       {
         const string& name = props.get(PropType::Cart_Name);
 
         // Only rename the file if we found a valid properties entry
-        if(name != "" && name != files[idx].getName())
+        if(!name.empty() && name != files[idx].getName())
         {
           string newfile = node.getPath();
           newfile.append(name).append(".").append(extension);
@@ -162,6 +164,8 @@ void RomAuditDialog::auditRoms()
     // Update the progress bar, indicating one more ROM has been processed
     progress.incProgress();
   }
+  // NOLINTEND
+
   progress.close();
 
   myResults1->setText(std::to_string(renamed));
@@ -177,14 +181,14 @@ void RomAuditDialog::handleCommand(CommandSender* sender, int cmd,
     case GuiObject::kOKCmd:
       if(!myConfirmMsg)
       {
-        StringList msg;
-        msg.push_back("This operation cannot be undone.  Your ROMs");
-        msg.push_back("will be modified, and as such there is a chance");
-        msg.push_back("that files may be lost.  You are recommended");
-        msg.push_back("to back up your files before proceeding.");
-        msg.push_back("");
-        msg.push_back("If you're sure you want to proceed with the");
-        msg.push_back("audit, click 'OK', otherwise click 'Cancel'.");
+        StringList msg;  // NOLINT (msg is not a const)
+        msg.emplace_back("This operation cannot be undone.  Your ROMs");
+        msg.emplace_back("will be modified, and as such there is a chance");
+        msg.emplace_back("that files may be lost.  You are recommended");
+        msg.emplace_back("to back up your files before proceeding.");
+        msg.emplace_back("");
+        msg.emplace_back("If you're sure you want to proceed with the");
+        msg.emplace_back("audit, click 'OK', otherwise click 'Cancel'.");
         myConfirmMsg = make_unique<GUI::MessageBox>
           (this, _font, msg, myMaxWidth, myMaxHeight, kConfirmAuditCmd,
           "OK", "Cancel", "ROM Audit", false);
@@ -201,7 +205,7 @@ void RomAuditDialog::handleCommand(CommandSender* sender, int cmd,
       BrowserDialog::show(this, _font, "Select ROM Directory to Audit",
                           myRomPath->getText(),
                           BrowserDialog::Mode::Directories,
-                          [this](bool OK, const FilesystemNode& node) {
+                          [this](bool OK, const FSNode& node) {
                             if(OK) {
                               myRomPath->setText(node.getShortPath());
                               myResults1->setText("");
