@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -45,8 +45,8 @@ SnapshotDialog::SnapshotDialog(OSystem& osystem, DialogContainer& parent,
   int xpos = HBORDER, ypos = VBORDER + _th;
 
   // Snapshot path (save files)
-  ButtonWidget* b = new ButtonWidget(this, font, xpos, ypos, buttonWidth, buttonHeight,
-                                     "Save path" + ELLIPSIS, kChooseSnapSaveDirCmd);
+  auto* b = new ButtonWidget(this, font, xpos, ypos, buttonWidth, buttonHeight,
+                             "Save path" + ELLIPSIS, kChooseSnapSaveDirCmd);
   wid.push_back(b);
   xpos += buttonWidth + fontWidth;
   mySnapSavePath = new EditTextWidget(this, font, xpos, ypos + (buttonHeight - lineHeight) / 2 - 1,
@@ -148,7 +148,7 @@ void SnapshotDialog::handleCommand(CommandSender* sender, int cmd,
       BrowserDialog::show(this, _font, "Select Snapshot Save Directory",
                           mySnapSavePath->getText(),
                           BrowserDialog::Mode::Directories,
-                          [this](bool OK, const FilesystemNode& node) {
+                          [this](bool OK, const FSNode& node) {
                             if(OK) mySnapSavePath->setText(node.getShortPath());
                           });
       break;
