@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -46,7 +46,6 @@ StellaSettingsDialog::StellaSettingsDialog(OSystem& osystem, DialogContainer& pa
   ButtonWidget* bw = nullptr;
 
   WidgetArray wid;
-  VariantList items;
 
   // Set real dimensions
   setSize(35 * fontWidth + HBORDER * 2 + 5,
@@ -88,7 +87,7 @@ StellaSettingsDialog::StellaSettingsDialog(OSystem& osystem, DialogContainer& pa
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-StellaSettingsDialog::~StellaSettingsDialog()
+StellaSettingsDialog::~StellaSettingsDialog() // NOLINT (we need an empty d'tor)
 {
 }
 
@@ -98,7 +97,7 @@ void StellaSettingsDialog::addUIOptions(WidgetArray& wid, int xpos, int& ypos)
   const int lineHeight = Dialog::lineHeight(),
             VGAP       = Dialog::vGap();
   VariantList items;
-  int pwidth = _font.getStringWidth("Right bottom"); // align width with other popup
+  const int pwidth = _font.getStringWidth("Right bottom"); // align width with other popup
 
   ypos += 1;
   VarList::push_back(items, "Standard", "standard");
@@ -139,8 +138,8 @@ void StellaSettingsDialog::addVideoOptions(WidgetArray& wid, int xpos, int& ypos
   VarList::push_back(items, "S-Video", static_cast<uInt32>(NTSCFilter::Preset::SVIDEO));
   VarList::push_back(items, "Composite", static_cast<uInt32>(NTSCFilter::Preset::COMPOSITE));
   VarList::push_back(items, "Bad adjust", static_cast<uInt32>(NTSCFilter::Preset::BAD));
-  int pwidth = _font.getStringWidth("Right bottom");
-  int lwidth = _font.getStringWidth("Scanline intensity ");
+  const int pwidth = _font.getStringWidth("Right bottom");
+  const int lwidth = _font.getStringWidth("Scanline intensity ");
 
   myTVMode = new PopUpWidget(this, _font, xpos, ypos, pwidth, lineHeight,
     items, "TV mode            ");
@@ -193,9 +192,10 @@ void StellaSettingsDialog::addGameOptions(WidgetArray& wid, int xpos, int& ypos)
   VarList::push_back(ctrls, "Atari mouse", "ATARIMOUSE");
   VarList::push_back(ctrls, "Trak-Ball", "TRAKBALL");
   VarList::push_back(ctrls, "Sega Genesis", "GENESIS");
+  VarList::push_back(ctrls, "Joy2B+", "JOY_2B+"); // TODO: should work, but needs testing with real hardware
   VarList::push_back(ctrls, "QuadTari", "QUADTARI");
 
-  int pwidth = _font.getStringWidth("Sega Genesis");
+  const int pwidth = _font.getStringWidth("Sega Genesis");
   myLeftPortLabel = new StaticTextWidget(this, _font, xpos, ypos + 1, "Left port  ");
   myLeftPort = new PopUpWidget(this, _font, myLeftPortLabel->getRight(),
     myLeftPortLabel->getTop() - 1, pwidth, lineHeight, ctrls, "", 0, kLeftCChanged);
@@ -235,7 +235,7 @@ void StellaSettingsDialog::loadConfig()
   myTVScanIntense->setValue(valueToLevel(settings.getInt("tv.scanlines")));
 
   // TV phosphor blend
-  myTVPhosLevel->setValue(valueToLevel(settings.getInt("tv.phosblend")));
+  myTVPhosLevel->setValue(valueToLevel(settings.getInt(PhosphorHandler::SETTING_BLEND)));
 
   // TV overscan
   myTVOverscan->setValue(settings.getInt("tia.fs_overscan"));
@@ -243,8 +243,6 @@ void StellaSettingsDialog::loadConfig()
   handleOverscanChange();
 
   // Controllers
-  Properties props;
-
   if (instance().hasConsole())
   {
     myGameProperties = instance().console().properties();
@@ -276,10 +274,10 @@ void StellaSettingsDialog::saveConfig()
     myTVMode->getSelectedTag().toString());
 
   // TV phosphor mode
-  instance().settings().setValue("tv.phosphor",
-    myTVPhosLevel->getValue() > 0 ? "always" : "byrom");
+  instance().settings().setValue(PhosphorHandler::SETTING_MODE,
+    myTVPhosLevel->getValue() > 0 ? PhosphorHandler::VALUE_ALWAYS : PhosphorHandler::VALUE_BYROM);
   // TV phosphor blend
-  instance().settings().setValue("tv.phosblend",
+  instance().settings().setValue(PhosphorHandler::SETTING_BLEND,
     levelToValue(myTVPhosLevel->getValue()));
 
   // TV scanline intensity and interpolation
@@ -414,15 +412,15 @@ void StellaSettingsDialog::switchSettingsMode()
 {
   StringList msg;
 
-  msg.push_back("Warning!");
-  msg.push_back("");
-  msg.push_back("Advanced settings should be");
-  msg.push_back("handled with care! When in");
-  msg.push_back("doubt, read the manual.");
-  msg.push_back("");
-  msg.push_back("If you are sure you want to");
-  msg.push_back("proceed with the switch, click");
-  msg.push_back("'OK', otherwise click 'Cancel'.");
+  msg.emplace_back("Warning!");
+  msg.emplace_back("");
+  msg.emplace_back("Advanced settings should be");
+  msg.emplace_back("handled with care! When in");
+  msg.emplace_back("doubt, read the manual.");
+  msg.emplace_back("");
+  msg.emplace_back("If you are sure you want to");
+  msg.emplace_back("proceed with the switch, click");
+  msg.emplace_back("'OK', otherwise click 'Cancel'.");
 
   myConfirmMsg = make_unique<GUI::MessageBox>(this, _font, msg,
       _w-16, _h, kConfirmSwitchCmd, "OK", "Cancel", "Switch settings mode", false);
@@ -445,7 +443,7 @@ void StellaSettingsDialog::loadControllerProperties(const Properties& props)
       enable = true;
       break;
     case EventHandlerState::LAUNCHER:
-      enable = (instance().launcher().selectedRomMD5() != "");
+      enable = !instance().launcher().selectedRomMD5().empty();
       break;
     default:
       break;
@@ -480,7 +478,7 @@ void StellaSettingsDialog::loadControllerProperties(const Properties& props)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 int StellaSettingsDialog::levelToValue(int level)
 {
-  constexpr int NUM_LEVELS = 11;
+  static constexpr int NUM_LEVELS = 11;
   static constexpr std::array<uInt8, NUM_LEVELS> values = {
     0, 5, 11, 18, 26, 35, 45, 56, 68, 81, 95
   };
@@ -491,7 +489,7 @@ int StellaSettingsDialog::levelToValue(int level)
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 int StellaSettingsDialog::valueToLevel(int value)
 {
-  constexpr int NUM_LEVELS = 11;
+  static constexpr int NUM_LEVELS = 11;
   static constexpr std::array<uInt8, NUM_LEVELS> values = {
     0, 5, 11, 18, 26, 35, 45, 56, 68, 81, 95
   };
@@ -528,11 +526,11 @@ void StellaSettingsDialog::updateControllerStates()
   // try to load the image for auto detection
   if(!instance().hasConsole())
   {
-    const FilesystemNode& node = FilesystemNode(instance().launcher().selectedRom());
+    const FSNode& node = FSNode(instance().launcher().selectedRom());
 
     autoDetect = node.exists() && !node.isDirectory() && (image = instance().openROM(node, md5, size)) != nullptr;
   }
-  string label = "";
+  string label;
   Controller::Type type = Controller::getType(myLeftPort->getSelectedTag().toString());
 
   if(type == Controller::Type::Unknown)
