@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -141,5 +141,8 @@ void StringListWidget::drawWidget(bool hilite)
 Common::Rect StringListWidget::getEditRect() const
 {
   const int offset = std::max(0, (_selectedItem - _currentPos) * _lineHeight);
-  return Common::Rect(_textOfs, 1 + offset, _w - _textOfs, _lineHeight + offset);
+  return {
+    static_cast<uInt32>(_textOfs), static_cast<uInt32>(1 + offset),
+    static_cast<uInt32>(_w - _textOfs), static_cast<uInt32>(_lineHeight + offset)
+  };
 }
