@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -20,7 +20,6 @@
 #include "FBSurface.hxx"
 #include "Font.hxx"
 #include "GuiObject.hxx"
-#include "OSystem.hxx"
 #include "Widget.hxx"
 #include "TabWidget.hxx"
 
@@ -28,7 +27,8 @@
 TabWidget::TabWidget(GuiObject* boss, const GUI::Font& font,
                      int x, int y, int w, int h)
   : Widget(boss, font, x, y, w, h),
-    CommandSender(boss)
+    CommandSender(boss),
+    _tabHeight{font.getLineHeight() + 4}
 {
   _id = 0;  // For dialogs with multiple tab widgets, they should specifically
             // call ::setID to differentiate among them
@@ -37,8 +37,6 @@ TabWidget::TabWidget(GuiObject* boss, const GUI::Font& font,
   _bgcolorhi = kDlgColor;
   _textcolor = kTextColor;
   _textcolorhi = kTextColor;
-
-  _tabHeight = font.getLineHeight() + 4;
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -60,24 +58,24 @@ int TabWidget::getChildY() const
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-int TabWidget::addTab(const string& title, int tabWidth)
+int TabWidget::addTab(string_view title, int tabWidth)
 {
   // Add a new tab page
   const int newWidth = _font.getStringWidth(title) + 2 * kTabPadding;
 
   if(tabWidth == AUTO_WIDTH)
-    _tabs.push_back(Tab(title, newWidth));
+    _tabs.emplace_back(title, newWidth);
   else
-    _tabs.push_back(Tab(title, tabWidth));
+    _tabs.emplace_back(title, tabWidth);
   const int numTabs = static_cast<int>(_tabs.size());
 
   // Determine the new tab width
   int fixedWidth = 0, fixedTabs = 0;
-  for(int i = 0; i < static_cast<int>(_tabs.size()); ++i)
+  for(const auto& tab: _tabs)
   {
-    if(_tabs[i].tabWidth != NO_WIDTH)
+    if(tab.tabWidth != NO_WIDTH)
     {
-      fixedWidth += _tabs[i].tabWidth;
+      fixedWidth += tab.tabWidth;
       fixedTabs++;
     }
   }
@@ -121,16 +119,15 @@ void TabWidget::setActiveTab(int tabID, bool show)
     sendCommand(TabWidget::kTabChangedCmd, _activeTab, _id);
 }
 
-#if 0 // FIXME
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void TabWidget::disableTab(int tabID)
+void TabWidget::enableTab(int tabID, bool enable)
 {
   assert(0 <= tabID && tabID < int(_tabs.size()));
 
-  _tabs[tabID].enabled = false;
-  // TODO - also disable all widgets belonging to this tab
+  _tabs[tabID].enabled = enable;
+  // Note: We do not have to disable the widgets because the tab is disabled
+  //   and therefore cannot be selected.
 }
-#endif
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void TabWidget::updateActiveTab()
@@ -163,15 +160,19 @@ void TabWidget::cycleTab(int direction)
 
   if(direction == -1)  // Go to the previous tab, wrap around at beginning
   {
-    tabID--;
-    if(tabID == -1)
-      tabID = static_cast<int>(_tabs.size()) - 1;
+    do {
+      tabID--;
+      if(tabID == -1)
+        tabID = static_cast<int>(_tabs.size()) - 1;
+    } while(!_tabs[tabID].enabled);
   }
   else if(direction == 1)  // Go to the next tab, wrap around at end
   {
-    tabID++;
-    if(tabID == static_cast<int>(_tabs.size()))
-      tabID = 0;
+    do {
+      tabID++;
+      if(tabID == static_cast<int>(_tabs.size()))
+        tabID = 0;
+    } while(!_tabs[tabID].enabled);
   }
 
   // Finally, select the active tab
@@ -193,8 +194,8 @@ Widget* TabWidget::parentWidget(int tabID)
 
   if(!_tabs[tabID].parentWidget)
   {
-    // create dummy widget if not existing
-    Widget* w = new Widget(_boss, _font, 0, 0, 0, 0);
+    // Create dummy widget if not existing
+    auto* w = new Widget(_boss, _font, 0, 0, 0, 0);
 
     setParentWidget(tabID, w);
   }
@@ -222,7 +223,7 @@ void TabWidget::handleMouseDown(int x, int y, MouseButton b, int clickCount)
   }
 
   // If a tab was clicked, switch to that pane
-  if (tabID >= 0)
+  if (tabID >= 0 && _tabs[tabID].enabled)
   {
     setActiveTab(tabID, true);
     updateActiveTab();
