@@ -8,7 +8,7 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
@@ -33,7 +33,6 @@
 
 #include "TimeMachineDialog.hxx"
 #include "Base.hxx"
-using Common::Base;
 
 static constexpr int BUTTON_W = 14, BUTTON_H = 14;
 
@@ -481,7 +480,7 @@ void TimeMachineDialog::handleCommand(CommandSender* sender, int cmd,
 void TimeMachineDialog::initBar()
 {
   const RewindManager& r = instance().state().rewindManager();
-  IntArray cycles = r.cyclesList();
+  const IntArray cycles = r.cyclesList();
 
   // Set range and intervals for timeline
   const uInt32 maxValue = cycles.size() > 1 ? static_cast<uInt32>(cycles.size() - 1) : 0;
@@ -498,17 +497,18 @@ void TimeMachineDialog::initBar()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 string TimeMachineDialog::getTimeString(uInt64 cycles) const
 {
-  const Int32 scanlines = std::max<Int32>(instance().console().tia().scanlinesLastFrame(), 240);
+  const size_t scanlines =
+      std::max<size_t>(instance().console().tia().scanlinesLastFrame(), 240);
   const bool isNTSC = scanlines <= 287;
-  constexpr Int32 NTSC_FREQ = 1193182; // ~76*262*60
-  constexpr Int32 PAL_FREQ  = 1182298; // ~76*312*50
-  const Int32 freq = isNTSC ? NTSC_FREQ : PAL_FREQ; // = cycles/second
+  constexpr size_t NTSC_FREQ = 1193182; // ~76*262*60
+  constexpr size_t PAL_FREQ  = 1182298; // ~76*312*50
+  const size_t freq = isNTSC ? NTSC_FREQ : PAL_FREQ; // = cycles/second
 
-  const uInt32 minutes = static_cast<uInt32>(cycles / (freq * 60));
+  const auto minutes = static_cast<uInt32>(cycles / (freq * 60));
   cycles -= minutes * (freq * 60);
-  const uInt32 seconds = static_cast<uInt32>(cycles / freq);
+  const auto seconds = static_cast<uInt32>(cycles / freq);
   cycles -= seconds * freq;
-  const uInt32 frames = static_cast<uInt32>(cycles / (scanlines * 76));
+  const auto frames  = static_cast<uInt32>(cycles / (scanlines * 76));
 
   stringstream time;
   time << Common::Base::toString(minutes, Common::Base::Fmt::_10_02) << ":";
@@ -532,7 +532,7 @@ void TimeMachineDialog::handleWinds(Int32 numWinds)
     const uInt64 elapsed = instance().console().tia().cycles() - startCycles;
     if(elapsed > 0)
     {
-      string message = r.getUnitString(elapsed);
+      const string message = r.getUnitString(elapsed);
 
       // TODO: add message text from addState()
       myMessageWidget->setLabel((numWinds < 0 ? "(-" : "(+") + message + ")");
