@@ -8,21 +8,20 @@
 //  SS  SS   tt   ee      ll   ll  aa  aa
 //   SSSS     ttt  eeeee llll llll  aaaaa
 //
-// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony
+// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony
 // and the Stella Team
 //
 // See the file "License.txt" for information on usage and redistribution of
 // this file, and for a DISCLAIMER OF ALL WARRANTIES.
 //============================================================================
 
-#include <cmath>
-
 #include "bspf.hxx"
 #include "Base.hxx"
 #include "Control.hxx"
 #include "Cart.hxx"
 #include "CartDPC.hxx"
 #include "Dialog.hxx"
+#include "BrowserDialog.hxx"
 #include "OSystem.hxx"
 #include "EditTextWidget.hxx"
 #include "PopUpWidget.hxx"
@@ -65,7 +64,7 @@ VideoAudioDialog::VideoAudioDialog(OSystem& osystem, DialogContainer& parent,
 
   // Set real dimensions
   setSize(44 * fontWidth + HBORDER * 2 + PopUpWidget::dropDownWidth(font) * 2,
-          _th + VGAP * 3 + lineHeight + 11 * (lineHeight + VGAP) + buttonHeight + VBORDER * 3,
+          _th + VGAP * 5 + lineHeight + 11 * (lineHeight + VGAP) + buttonHeight + VBORDER * 3,
           max_w, max_h);
 
   // The tab widget
@@ -79,6 +78,9 @@ VideoAudioDialog::VideoAudioDialog(OSystem& osystem, DialogContainer& parent,
   addDisplayTab();
   addPaletteTab();
   addTVEffectsTab();
+#ifdef IMAGE_SUPPORT
+  addBezelTab();
+#endif
   addAudioTab();
 
   // Add Defaults, OK and Cancel buttons
@@ -111,11 +113,10 @@ void VideoAudioDialog::addDisplayTab()
             VGAP       = Dialog::vGap();
   const int INDENT = CheckboxWidget::prefixSize(_font);
   const int lwidth = _font.getStringWidth("V-Size adjust "),
-            pwidth = _font.getStringWidth("OpenGLES2");
+            pwidth = _font.getStringWidth("Direct3D 12");
   const int xpos = HBORDER;
   int ypos = VBORDER;
   WidgetArray wid;
-  VariantList items;
   const int tabID = myTab->addTab(" Display ", TabWidget::AUTO_WIDTH);
 
   // Video renderer
@@ -192,7 +193,8 @@ void VideoAudioDialog::addDisplayTab()
 
   // Add message concerning usage
   ypos = myTab->getHeight() - fontHeight - ifont.getFontHeight() - VGAP - VBORDER;
-  int iwidth = ifont.getStringWidth("(*) Change may require an application restart");
+  const int iwidth =
+    ifont.getStringWidth("(*) Change may require an application restart");
   new StaticTextWidget(myTab, ifont, xpos, ypos,
                        std::min(iwidth, _w - HBORDER * 2), ifont.getFontHeight(),
                        "(*) Change may require an application restart");
@@ -312,12 +314,23 @@ void VideoAudioDialog::addPaletteTab()
   CREATE_CUSTOM_SLIDERS(Bright, "Brightness ", kPaletteUpdated)
   CREATE_CUSTOM_SLIDERS(Gamma, "Gamma ", kPaletteUpdated)
 
+  ypos += VGAP;
+  auto* s = new StaticTextWidget(myTab, _font, xpos, ypos + 1, "Autodetection");
+
+  myDetectPal60 = new CheckboxWidget(myTab, _font, s->getRight() + fontWidth * 2, ypos + 1, "PAL-60");
+  myDetectPal60 ->setToolTip("Enable autodetection of PAL-60 based on colors used.");
+  wid.push_back(myDetectPal60 );
+
+  myDetectNtsc50 = new CheckboxWidget(myTab, _font, myDetectPal60->getRight() + fontWidth * 2, ypos + 1, "NTSC-50");
+  myDetectNtsc50 ->setToolTip("Enable autodetection of NTSC-50 based on colors used.");
+  wid.push_back(myDetectNtsc50 );
+
   // The resulting palette
   xpos = myPhaseShift->getRight() + fontWidth * 2;
   addPalette(xpos, VBORDER, _w - 2 * 2 - HBORDER - xpos,
              myTVGamma->getBottom() -  myTIAPalette->getTop());
 
-  // Add items for tab 2
+  // Add items for tab 1
   addToFocusList(wid, myTab, tabID);
 
   myTab->parentWidget(tabID)->setHelpAnchor("VideoAudioPalettes");
@@ -340,7 +353,7 @@ void VideoAudioDialog::addTVEffectsTab()
   int pwidth = _font.getStringWidth("Bad adjust  ");
   WidgetArray wid;
   VariantList items;
-  const int tabID = myTab->addTab(" TV Effects ", TabWidget::AUTO_WIDTH);
+  const int tabID = myTab->addTab("TV Effects", TabWidget::AUTO_WIDTH);
 
   items.clear();
   VarList::push_back(items, "Disabled", static_cast<uInt32>(NTSCFilter::Preset::OFF));
@@ -366,11 +379,18 @@ void VideoAudioDialog::addTVEffectsTab()
   CREATE_CUSTOM_SLIDERS(Bleed, "Bleeding ", 0)
 
   ypos += VGAP * 3;
-
   xpos = HBORDER;
 
   // TV Phosphor effect
-  myTVPhosphor = new CheckboxWidget(myTab, _font, xpos, ypos + 1, "Phosphor for all ROMs", kPhosphorChanged);
+  items.clear();
+  VarList::push_back(items, "by ROM", PhosphorHandler::VALUE_BYROM);
+  VarList::push_back(items, "always", PhosphorHandler::VALUE_ALWAYS);
+  VarList::push_back(items, "auto on", PhosphorHandler::VALUE_AUTO_ON);
+  VarList::push_back(items, "auto on/off", PhosphorHandler::VALUE_AUTO);
+  myTVPhosphor = new PopUpWidget(myTab, _font, xpos, ypos,
+                                 _font.getStringWidth("auto on/off"), lineHeight,
+                                 items, "Phosphor ", 0, kPhosphorChanged);
+  myTVPhosphor->setToolTip(Event::PhosphorModeDecrease, Event::PhosphorModeIncrease);
   wid.push_back(myTVPhosphor);
   ypos += lineHeight + VGAP / 2;
 
@@ -421,12 +441,96 @@ void VideoAudioDialog::addTVEffectsTab()
   CREATE_CLONE_BUTTON(Bad, "Clone Bad adjust")
   CREATE_CLONE_BUTTON(Custom, "Revert")
 
-  // Add items for tab 3
+  // Add items for tab 2
   addToFocusList(wid, myTab, tabID);
 
   myTab->parentWidget(tabID)->setHelpAnchor("VideoAudioEffects");
 }
 
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void VideoAudioDialog::addBezelTab()
+{
+  const int lineHeight = Dialog::lineHeight(),
+            buttonHeight = Dialog::buttonHeight(),
+            fontWidth = Dialog::fontWidth(),
+            VBORDER = Dialog::vBorder(),
+            HBORDER = Dialog::hBorder(),
+            VGAP = Dialog::vGap();
+  const int INDENT = CheckboxWidget::prefixSize(_font);
+  int xpos = HBORDER,
+      ypos = VBORDER;
+  WidgetArray wid;
+  const int tabID = myTab->addTab(" Bezels ", TabWidget::AUTO_WIDTH);
+
+  // Enable bezels
+  myBezelEnableCheckbox = new CheckboxWidget(myTab, _font, xpos, ypos,
+                                             "Enable bezels", kBezelEnableChanged);
+  myBezelEnableCheckbox->setToolTip(Event::ToggleBezel);
+  wid.push_back(myBezelEnableCheckbox);
+  xpos += INDENT;
+  ypos += lineHeight + VGAP;
+
+  // Bezel path
+  const int bwidth = _font.getStringWidth("Bezel path" + ELLIPSIS) + fontWidth * 2 + 1;
+  myOpenBrowserButton = new ButtonWidget(myTab, _font, xpos, ypos, bwidth, buttonHeight,
+                                         "Bezel path" + ELLIPSIS, kChooseBezelDirCmd);
+  myOpenBrowserButton->setToolTip("Select path for bezels.");
+  wid.push_back(myOpenBrowserButton);
+
+  myBezelPath = new EditTextWidget(myTab, _font, xpos + bwidth + fontWidth,
+                                   ypos + (buttonHeight - lineHeight) / 2 - 1,
+                                   _w - xpos - bwidth - fontWidth - HBORDER - 2, lineHeight, "");
+  wid.push_back(myBezelPath);
+
+  ypos += lineHeight + VGAP * 3;
+  myBezelShowWindowed = new CheckboxWidget(myTab, _font, xpos, ypos,
+                                           "Windowed modes");
+  myBezelShowWindowed->setToolTip("Enable bezels in windowed modes as well.");
+  wid.push_back(myBezelShowWindowed);
+
+  // Disable auto borders
+  ypos += lineHeight + VGAP * 1;
+  myManualWindow = new CheckboxWidget(myTab, _font, xpos, ypos,
+                                      "Manual emulation window", kAutoWindowChanged);
+  myManualWindow->setToolTip("Enable if automatic window detection fails.");
+  wid.push_back(myManualWindow);
+  xpos += INDENT;
+
+  const int lWidth = _font.getStringWidth("Bottom ");
+  const int sWidth = myBezelPath->getRight() - xpos - lWidth - 4.5 * fontWidth; // _w - HBORDER - xpos - lwidth;
+  ypos += lineHeight + VGAP * 1;
+  myWinLeftSlider = new SliderWidget(myTab, _font, xpos, ypos, sWidth, lineHeight,
+                                     "Left   ", 0, 0, 4 * fontWidth, "%");
+  myWinLeftSlider->setMinValue(0); myWinLeftSlider->setMaxValue(40);
+  myWinLeftSlider->setTickmarkIntervals(4);
+  wid.push_back(myWinLeftSlider);
+
+  ypos += lineHeight + VGAP * 1;
+  myWinRightSlider = new SliderWidget(myTab, _font, xpos, ypos, sWidth, lineHeight,
+                                      "Right  ", 0, 0, 4 * fontWidth, "%");
+  myWinRightSlider->setMinValue(0); myWinRightSlider->setMaxValue(40);
+  myWinRightSlider->setTickmarkIntervals(4);
+  wid.push_back(myWinRightSlider);
+
+  ypos += lineHeight + VGAP * 1;
+  myWinTopSlider = new SliderWidget(myTab, _font, xpos, ypos, sWidth, lineHeight,
+                                    "Top    ", 0, 0, 4 * fontWidth, "%");
+  myWinTopSlider->setMinValue(0); myWinTopSlider->setMaxValue(40);
+  myWinTopSlider->setTickmarkIntervals(4);
+  wid.push_back(myWinTopSlider);
+
+  ypos += lineHeight + VGAP;
+  myWinBottomSlider = new SliderWidget(myTab, _font, xpos, ypos, sWidth, lineHeight,
+                                       "Bottom ", 0, 0, 4 * fontWidth, "%");
+  myWinBottomSlider->setMinValue(0); myWinBottomSlider->setMaxValue(40);
+  myWinBottomSlider->setTickmarkIntervals(4);
+  wid.push_back(myWinBottomSlider);
+
+  // Add items for tab 3
+
+  myTab->parentWidget(tabID)->setHelpAnchor("VideoAudioBezels");
+}
+
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void VideoAudioDialog::addAudioTab()
 {
@@ -439,7 +543,7 @@ void VideoAudioDialog::addAudioTab()
   int lwidth = _font.getStringWidth("Volume "), pwidth = 0;
   WidgetArray wid;
   VariantList items;
-  const int tabID = myTab->addTab("  Audio  ", TabWidget::AUTO_WIDTH);
+  const int tabID = myTab->addTab(" Audio ", TabWidget::AUTO_WIDTH);
 
   int xpos = HBORDER, ypos = VBORDER;
 
@@ -449,7 +553,7 @@ void VideoAudioDialog::addAudioTab()
   mySoundEnableCheckbox->setToolTip(Event::SoundToggle);
   wid.push_back(mySoundEnableCheckbox);
   ypos += lineHeight + VGAP;
-  xpos += CheckboxWidget::prefixSize(_font);
+  xpos += INDENT;
 
   // Volume
   myVolumeSlider = new SliderWidget(myTab, _font, xpos, ypos,
@@ -476,7 +580,7 @@ void VideoAudioDialog::addAudioTab()
   VarList::push_back(items, "Ultra quality, minimal lag", static_cast<int>(AudioSettings::Preset::ultraQualityMinimalLag));
   VarList::push_back(items, "Custom", static_cast<int>(AudioSettings::Preset::custom));
   myModePopup = new PopUpWidget(myTab, _font, xpos, ypos,
-                                _font.getStringWidth("Ultry quality, minimal lag"), lineHeight,
+                                _font.getStringWidth("Ultra quality, minimal lag"), lineHeight,
                                 items, "Mode", lwidth, kModeChanged);
   wid.push_back(myModePopup);
   ypos += lineHeight + VGAP;
@@ -511,7 +615,7 @@ void VideoAudioDialog::addAudioTab()
 
   // Resampling quality
   items.clear();
-  VarList::push_back(items, "Low", static_cast<int>(AudioSettings::ResamplingQuality::nearestNeightbour));
+  VarList::push_back(items, "Low", static_cast<int>(AudioSettings::ResamplingQuality::nearestNeighbour));
   VarList::push_back(items, "High", static_cast<int>(AudioSettings::ResamplingQuality::lanczos_2));
   VarList::push_back(items, "Ultra", static_cast<int>(AudioSettings::ResamplingQuality::lanczos_3));
   myResamplingPopup = new PopUpWidget(myTab, _font, xpos, ypos,
@@ -619,7 +723,6 @@ void VideoAudioDialog::loadConfig()
     myPhaseShift->setTickmarkIntervals(4);
     myPhaseShift->setToolTip("Adjust PAL phase shift of 'Custom' palette.");
     myPhaseShift->setValue(myPaletteAdj.phasePal);
-
   }
   else
   {
@@ -644,26 +747,44 @@ void VideoAudioDialog::loadConfig()
   handlePaletteChange();
   colorPalette();
 
+  // Autodetection
+  myDetectPal60->setState(settings.getBool("detectpal60"));
+  myDetectNtsc50->setState(settings.getBool("detectntsc50"));
+
   /////////////////////////////////////////////////////////////////////////////
   // TV Effects tab
   // TV Mode
   myTVMode->setSelected(
     settings.getString("tv.filter"), "0");
-  int preset = settings.getInt("tv.filter");
+  const int preset = settings.getInt("tv.filter");
   handleTVModeChange(static_cast<NTSCFilter::Preset>(preset));
 
   // TV Custom adjustables
   loadTVAdjustables(NTSCFilter::Preset::CUSTOM);
 
   // TV phosphor mode & blend
-  myTVPhosphor->setState(settings.getString("tv.phosphor") == "always");
-  myTVPhosLevel->setValue(settings.getInt("tv.phosblend"));
+  myTVPhosphor->setSelected(settings.getString(PhosphorHandler::SETTING_MODE), PhosphorHandler::VALUE_BYROM);
+  myTVPhosLevel->setValue(settings.getInt(PhosphorHandler::SETTING_BLEND));
   handlePhosphorChange();
 
   // TV scanline intensity & mask
   myTVScanIntense->setValue(settings.getInt("tv.scanlines"));
   myTVScanMask->setSelected(settings.getString("tv.scanmask"), TIASurface::SETTING_STANDARD);
 
+  /////////////////////////////////////////////////////////////////////////////
+#ifdef IMAGE_SUPPORT
+  // Bezel tab
+  myBezelEnableCheckbox->setState(settings.getBool("bezel.show"));
+  myBezelPath->setText(settings.getString("bezel.dir"));
+  myBezelShowWindowed->setState(settings.getBool("bezel.windowed"));
+  myManualWindow->setState(!settings.getBool("bezel.win.auto"));
+  myWinLeftSlider->setValue(settings.getInt("bezel.win.left"));
+  myWinRightSlider->setValue(settings.getInt("bezel.win.right"));
+  myWinTopSlider->setValue(settings.getInt("bezel.win.top"));
+  myWinBottomSlider->setValue(settings.getInt("bezel.win.bottom"));
+  handleBezelChange();
+#endif
+
   /////////////////////////////////////////////////////////////////////////////
   // Audio tab
   AudioSettings& audioSettings = instance().audioSettings();
@@ -694,7 +815,7 @@ void VideoAudioDialog::loadConfig()
 
   updateSettingsWithPreset(instance().audioSettings());
 
-  updateEnabledState();
+  updateAudioEnabledState();
 
   myTab->loadConfig();
 }
@@ -758,6 +879,10 @@ void VideoAudioDialog::saveConfig()
   Logger::debug("Saving palette settings...");
   instance().frameBuffer().tiaSurface().paletteHandler().saveConfig(settings);
 
+  // Autodetection
+  settings.setValue("detectpal60", myDetectPal60->getState());
+  settings.setValue("detectntsc50", myDetectNtsc50->getState());
+
   /////////////////////////////////////////////////////////////////////////////
   // TV Effects tab
   // TV Mode
@@ -769,22 +894,34 @@ void VideoAudioDialog::saveConfig()
   ntscAdj.artifacts = myTVArtifacts->getValue();
   ntscAdj.fringing = myTVFringe->getValue();
   ntscAdj.bleed = myTVBleed->getValue();
-  instance().frameBuffer().tiaSurface().ntsc().setCustomAdjustables(ntscAdj);
+  NTSCFilter::setCustomAdjustables(ntscAdj);
 
   Logger::debug("Saving TV effects options ...");
-  instance().frameBuffer().tiaSurface().ntsc().saveConfig(settings);
-
+  NTSCFilter::saveConfig(settings);
 
   // TV phosphor mode & blend
-  settings.setValue("tv.phosphor",
-                                 myTVPhosphor->getState() ? "always" : "byrom");
-  settings.setValue("tv.phosblend", myTVPhosLevel->getValueLabel() == "Off"
-                                 ? "0" : myTVPhosLevel->getValueLabel());
+  settings.setValue(PhosphorHandler::SETTING_MODE, myTVPhosphor->getSelectedTag());
+  settings.setValue(PhosphorHandler::SETTING_BLEND, myTVPhosLevel->getValueLabel() == "Off"
+                    ? "0" : myTVPhosLevel->getValueLabel());
 
   // TV scanline intensity & mask
   settings.setValue("tv.scanlines", myTVScanIntense->getValueLabel());
   settings.setValue("tv.scanmask", myTVScanMask->getSelectedTag());
 
+  /////////////////////////////////////////////////////////////////////////////
+#ifdef IMAGE_SUPPORT
+  // Bezel tab
+  settings.setValue("bezel.show", myBezelEnableCheckbox->getState());
+  settings.setValue("bezel.dir", myBezelPath->getText());
+  settings.setValue("bezel.windowed", myBezelShowWindowed->getState());
+  settings.setValue("bezel.win.auto", !myManualWindow->getState());
+  settings.setValue("bezel.win.left", myWinLeftSlider->getValueLabel());
+  settings.setValue("bezel.win.right", myWinRightSlider->getValueLabel());
+  settings.setValue("bezel.win.top", myWinTopSlider->getValueLabel());
+  settings.setValue("bezel.win.bottom", myWinBottomSlider->getValueLabel());
+#endif
+
+  // Note: The following has to happen after all video related setting have been saved
   if(instance().hasConsole())
   {
     instance().console().setTIAProperties();
@@ -823,13 +960,15 @@ void VideoAudioDialog::saveConfig()
   // DPC Pitch
   audioSettings.setDpcPitch(myDpcPitch->getValue());
   // update if current cart is Pitfall II
-  if (instance().hasConsole() && instance().console().cartridge().name() == "CartridgeDPC")
+  if (instance().hasConsole() &&
+      instance().console().cartridge().name() == "CartridgeDPC")
   {
-    CartridgeDPC& cart = static_cast<CartridgeDPC&>(instance().console().cartridge());
+    auto& cart = static_cast<CartridgeDPC&>(instance().console().cartridge());
     cart.setDpcPitch(myDpcPitch->getValue());
   }
 
-  const AudioSettings::Preset preset = static_cast<AudioSettings::Preset>(myModePopup->getSelectedTag().toInt());
+  const auto preset = static_cast<AudioSettings::Preset>
+      (myModePopup->getSelectedTag().toInt());
   audioSettings.setPreset(preset);
 
   if (preset == AudioSettings::Preset::custom) {
@@ -893,6 +1032,8 @@ void VideoAudioDialog::setDefaults()
       myTVGamma->setValue(50);
       handlePaletteChange();
       handlePaletteUpdate();
+      myDetectPal60->setState(false);
+      myDetectNtsc50->setState(false);
       break;
     }
 
@@ -901,7 +1042,7 @@ void VideoAudioDialog::setDefaults()
       myTVMode->setSelected("0", "0");
 
       // TV phosphor mode & blend
-      myTVPhosphor->setState(false);
+      myTVPhosphor->setSelected(PhosphorHandler::VALUE_BYROM);
       myTVPhosLevel->setValue(50);
 
       // TV scanline intensity & mask
@@ -914,7 +1055,17 @@ void VideoAudioDialog::setDefaults()
       loadTVAdjustables(NTSCFilter::Preset::CUSTOM);
       break;
     }
-    case 3:  // Audio
+    case 3: // Bezels
+#ifdef IMAGE_SUPPORT
+      myBezelEnableCheckbox->setState(true);
+      myBezelPath->setText(instance().userDir().getShortPath());
+      myBezelShowWindowed->setState(false);
+      myManualWindow->setState(false);
+      handleBezelChange();
+      break;
+
+    case 4:  // Audio
+#endif
       mySoundEnableCheckbox->setState(AudioSettings::DEFAULT_ENABLED);
       myVolumeSlider->setValue(AudioSettings::DEFAULT_VOLUME);
       myDevicePopup->setSelected(AudioSettings::DEFAULT_DEVICE);
@@ -931,7 +1082,7 @@ void VideoAudioDialog::setDefaults()
       }
       else updatePreset();
 
-      updateEnabledState();
+      updateAudioEnabledState();
       break;
 
     default:  // satisfy compiler
@@ -960,8 +1111,7 @@ void VideoAudioDialog::handleTVModeChange(NTSCFilter::Preset preset)
 void VideoAudioDialog::loadTVAdjustables(NTSCFilter::Preset preset)
 {
   NTSCFilter::Adjustable adj;
-  instance().frameBuffer().tiaSurface().ntsc().getAdjustables(
-      adj, NTSCFilter::Preset(preset));
+  NTSCFilter::getAdjustables(adj, preset);
   myTVSharp->setValue(adj.sharpness);
   myTVRes->setValue(adj.resolution);
   myTVArtifacts->setValue(adj.artifacts);
@@ -997,7 +1147,7 @@ void VideoAudioDialog::handleShiftChanged(SliderWidget* widget)
 
   ss << std::setw(4) << std::fixed << std::setprecision(1)
     << (0.1 * (widget->getValue())) << DEGREE;
-  widget->setValueLabel(ss.str());
+  widget->setValueLabel(ss.view());
   handlePaletteUpdate();
 }
 
@@ -1042,8 +1192,8 @@ void VideoAudioDialog::handlePaletteUpdate()
     constexpr int NUM_LUMA = 8;
     constexpr int NUM_CHROMA = 16;
 
-    for(int idx = 0; idx < NUM_CHROMA; ++idx)
-      for(int lum = 0; lum < NUM_LUMA; ++lum)
+    for(int idx = 0; idx < NUM_CHROMA; ++idx)  // NOLINT
+      for(int lum = 0; lum < NUM_LUMA; ++lum)  // NOLINT
         myColor[idx][lum]->setDirty();
   }
 }
@@ -1074,12 +1224,27 @@ void VideoAudioDialog::handleOverscanChange()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void VideoAudioDialog::handlePhosphorChange()
 {
-  myTVPhosLevel->setEnabled(myTVPhosphor->getState());
+  myTVPhosLevel->setEnabled(myTVPhosphor->getSelectedTag() != PhosphorHandler::VALUE_BYROM);
+}
+
+// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
+void VideoAudioDialog::handleBezelChange()
+{
+  const bool enable = myBezelEnableCheckbox->getState();
+  const bool nonAuto = myManualWindow->getState();
+
+  myOpenBrowserButton->setEnabled(enable);
+  myBezelPath->setEnabled(enable);
+  myBezelShowWindowed->setEnabled(enable);
+  myWinLeftSlider->setEnabled(enable && nonAuto);
+  myWinRightSlider->setEnabled(enable && nonAuto);
+  myWinTopSlider->setEnabled(enable && nonAuto);
+  myWinBottomSlider->setEnabled(enable && nonAuto);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void VideoAudioDialog::handleCommand(CommandSender* sender, int cmd,
-                                int data, int id)
+                                     int data, int id)
 {
   switch (cmd)
   {
@@ -1192,27 +1357,41 @@ void VideoAudioDialog::handleCommand(CommandSender* sender, int cmd,
         myTVPhosLevel->setValueUnit("%");
       break;
 
+    case kBezelEnableChanged:
+    case kAutoWindowChanged:
+      handleBezelChange();
+      break;
+
+    case kChooseBezelDirCmd:
+      BrowserDialog::show(this, _font, "Select Bezel Directory",
+                          myBezelPath->getText(),
+                          BrowserDialog::Mode::Directories,
+                          [this](bool OK, const FSNode& node) {
+                            if(OK) myBezelPath->setText(node.getShortPath());
+                          });
+      break;
+
     case kSoundEnableChanged:
-      updateEnabledState();
+      updateAudioEnabledState();
       break;
 
     case kModeChanged:
       updatePreset();
-      updateEnabledState();
+      updateAudioEnabledState();
       break;
 
     case kHeadroomChanged:
     {
-      std::ostringstream ss;
+      std::ostringstream ss;  // NOLINT (ss is not a const)
       ss << std::fixed << std::setprecision(1) << (0.5 * myHeadroomSlider->getValue()) << " frames";
-      myHeadroomSlider->setValueLabel(ss.str());
+      myHeadroomSlider->setValueLabel(ss.view());
       break;
     }
     case kBufferSizeChanged:
     {
-      std::ostringstream ss;
+      std::ostringstream ss;  // NOLINT (ss is not a const)
       ss << std::fixed << std::setprecision(1) << (0.5 * myBufferSizeSlider->getValue()) << " frames";
-      myBufferSizeSlider->setValueLabel(ss.str());
+      myBufferSizeSlider->setValueLabel(ss.view());
       break;
     }
 
@@ -1253,7 +1432,7 @@ void VideoAudioDialog::colorPalette()
 
   if(instance().hasConsole())
   {
-    const int order[2][NUM_CHROMA] =
+    static constexpr int order[2][NUM_CHROMA] =
     {
       {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15},
       {0, 1, 2, 4, 6, 8, 10, 12, 13, 11, 9, 7, 5, 3, 14, 15}
@@ -1266,23 +1445,24 @@ void VideoAudioDialog::colorPalette()
       const int color = order[type][idx];
 
       ss << Common::Base::HEX1 << std::uppercase << color;
-      myColorLbl[idx]->setLabel(ss.str());
+      myColorLbl[idx]->setLabel(ss.view());
       for(int lum = 0; lum < NUM_LUMA; ++lum)
         myColor[idx][lum]->setColor(color * NUM_CHROMA + lum * 2); // skip grayscale colors
     }
   }
   else
     // disable palette
-    for(int idx = 0; idx < NUM_CHROMA; ++idx)
-      for(int lum = 0; lum < NUM_LUMA; ++lum)
+    for(int idx = 0; idx < NUM_CHROMA; ++idx)  // NOLINT
+      for(int lum = 0; lum < NUM_LUMA; ++lum)  // NOLINT
         myColor[idx][lum]->setEnabled(false);
 }
 
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
-void VideoAudioDialog::updateEnabledState()
+void VideoAudioDialog::updateAudioEnabledState()
 {
   const bool active = mySoundEnableCheckbox->getState();
-  const AudioSettings::Preset preset = static_cast<AudioSettings::Preset>(myModePopup->getSelectedTag().toInt());
+  const auto preset = static_cast<AudioSettings::Preset>
+      (myModePopup->getSelectedTag().toInt());
   const bool userMode = preset == AudioSettings::Preset::custom;
 
   myVolumeSlider->setEnabled(active);
@@ -1290,7 +1470,8 @@ void VideoAudioDialog::updateEnabledState()
   myStereoSoundCheckbox->setEnabled(active);
   myModePopup->setEnabled(active);
   // enable only for Pitfall II cart
-  myDpcPitch->setEnabled(active && instance().hasConsole() && instance().console().cartridge().name() == "CartridgeDPC");
+  myDpcPitch->setEnabled(active && instance().hasConsole() &&
+      instance().console().cartridge().name() == "CartridgeDPC");
 
   myFragsizePopup->setEnabled(active && userMode);
   myFreqPopup->setEnabled(active && userMode);
@@ -1302,7 +1483,8 @@ void VideoAudioDialog::updateEnabledState()
 // - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 void VideoAudioDialog::updatePreset()
 {
-  const AudioSettings::Preset preset = static_cast<AudioSettings::Preset>(myModePopup->getSelectedTag().toInt());
+  const auto preset = static_cast<AudioSettings::Preset>
+      (myModePopup->getSelectedTag().toInt());
 
   // Make a copy that does not affect the actual settings...
   AudioSettings audioSettings = instance().audioSettings();
