@@ -50,7 +50,7 @@ print OUTFILE "//      SS   tt   eeeeee  ll   ll   aaaaa  --  \"An Atari 2600 VC
 print OUTFILE "//  SS  SS   tt   ee      ll   ll  aa  aa\n";
 print OUTFILE "//   SSSS     ttt  eeeee llll llll  aaaaa\n";
 print OUTFILE "//\n";
-print OUTFILE "// Copyright (c) 1995-2022 by Bradford W. Mott, Stephen Anthony\n";
+print OUTFILE "// Copyright (c) 1995-2024 by Bradford W. Mott, Stephen Anthony\n";
 print OUTFILE "// and the Stella Team\n";
 print OUTFILE "//\n";
 print OUTFILE "// See the file \"License.txt\" for information on usage and redistribution of\n";
@@ -66,8 +66,18 @@ print OUTFILE "  located in the src/tools directory.  All properties changes\n";
 print OUTFILE "  should be made in stella.pro, and then this file should be\n";
 print OUTFILE "  regenerated and the application recompiled.\n";
 print OUTFILE "*/\n";
+print OUTFILE "\n// NOLINTBEGIN: static analyzer can't tell the following is data\n";
 print OUTFILE "\nstatic constexpr uInt32 DEF_PROPS_SIZE = " . $setsize . ";";
 print OUTFILE "\n\n";
+print OUTFILE "/**\n";
+# FIXME: Remove this once clang properly supports constexpr string_view
+print OUTFILE "  FIXME\n";
+print OUTFILE "  We need to use 'const char*' instead of 'string_view' here,\n";
+print OUTFILE "  since clang is not optimized to create so many constexpr\n";
+print OUTFILE "  'string_view's.  It *can* do it by using\n";
+print OUTFILE "  -fconstexpr-steps=2710000, which increases binary size.\n";
+print OUTFILE "*/\n";
+#######################################################################
 print OUTFILE "static constexpr BSPF::array2D<const char*, DEF_PROPS_SIZE, " . $typesize . "> DefProps = {{\n";
 
 # Walk the hash map and print each item in order of md5sum
@@ -84,7 +94,7 @@ for my $key ( sort keys %propset )
 }
 
 print OUTFILE "}};\n";
-print OUTFILE "\n";
+print OUTFILE "\n// NOLINTEND\n\n";
 print OUTFILE "#endif\n";
 
 close(OUTFILE);
