@@ -2,15 +2,12 @@
   Simple program that produces a hex list of a binary object file
 
   @author  Bradford W. Mott
-  @version $Id: romtohex.cxx 3174 2015-06-14 20:48:06Z stephena $
 */
 
 #include <iomanip>
 #include <fstream>
 #include <iostream>
 #include <cstdlib>
-
-#include "../common/UniquePtr.hxx"
 using namespace std;
 
 using uInt8 = unsigned char;
@@ -20,11 +17,9 @@ int main(int ac, char* av[])
 {
   if(ac < 2)
   {
-    cout << av[0] << " <INPUT_FILE> [values per line = 8] [startpos = 0]" << endl
-         << endl
-         << "  Read data from INPUT_FILE, and convert to unsigned char" << endl
-         << "  (in hex format), writing to standard output." << endl
-         << endl;
+    cout << av[0] << " <INPUT_FILE> [values per line = 8] [startpos = 0]\n\n"
+         << "  Read data from INPUT_FILE, and convert to unsigned char\n"
+         << "  (in hex format), writing to standard output.\n\n";
     return 0;
   }
 
@@ -38,11 +33,11 @@ int main(int ac, char* av[])
     int len = (int)in.tellg();
     in.seekg(0, ios::beg);
 
-    unique_ptr<uInt8[]> data = make_ptr<uInt8[]>(len);
+    unique_ptr<uInt8[]> data = make_unique<uInt8[]>(len);
     in.read((char*)data.get(), len);
     in.close();
 
-    cout << "SIZE = " << len << endl << "  ";
+    cout << "SIZE = " << len << "\n  ";
 
     // Skip first 'offset' bytes; they shouldn't be used
     for(int t = offset; t < len; ++t)
@@ -51,8 +46,8 @@ int main(int ac, char* av[])
       if(t < len - 1)
         cout << ", ";
       if(((t-offset) % values_per_line) == (values_per_line-1))
-        cout << endl << "  ";
+        cout << "\n  ";
     }
-    cout << endl;
+    cout << '\n';
   }
 }
